# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: admin/v1/admin.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from ...validate.v1 import validate_pb2 as validate_dot_v1_dot_validate__pb2
from .types.v1 import list_metadata_pb2 as admin_dot_v1_dot_types_dot_v1_dot_list__metadata__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14\x61\x64min/v1/admin.proto\x12\x08\x61\x64min.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1avalidate/v1/validate.proto\x1a%admin/v1/types/v1/list_metadata.proto\"m\n\x11GetApiKeysRequest\x12\x14\n\x05limit\x18\x01 \x01(\x05R\x05limit\x12\x14\n\x05\x61\x66ter\x18\x02 \x01(\tR\x05\x61\x66ter\x12\x16\n\x06\x62\x65\x66ore\x18\x03 \x01(\tR\x06\x62\x65\x66ore\x12\x14\n\x05order\x18\x04 \x01(\tR\x05order\"y\n\x06\x41piKey\x12\x17\n\x02id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x02id\x12\x1b\n\x04name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04name\x12\x39\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\"\x87\x01\n\x12GetApiKeysResponse\x12+\n\x08\x61pi_keys\x18\x01 \x03(\x0b\x32\x10.admin.v1.ApiKeyR\x07\x61piKeys\x12\x44\n\rlist_metadata\x18\x02 \x01(\x0b\x32\x1f.admin.v1.types.v1.ListMetadataR\x0clistMetadata\"2\n\x13\x43reateApiKeyRequest\x12\x1b\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04name\"\xa8\x01\n\x14\x43reateApiKeyResponse\x12\x17\n\x02id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x02id\x12\x1b\n\x04name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04name\x12\x1f\n\x06secret\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x06secret\x12\x39\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\".\n\x13\x44\x65leteApiKeyRequest\x12\x17\n\x02id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x02id\"\x16\n\x14\x44\x65leteApiKeyResponse2\xf9\x01\n\nDevService\x12I\n\nGetApiKeys\x12\x1b.admin.v1.GetApiKeysRequest\x1a\x1c.admin.v1.GetApiKeysResponse\"\x00\x12O\n\x0c\x43reateApiKey\x12\x1d.admin.v1.CreateApiKeyRequest\x1a\x1e.admin.v1.CreateApiKeyResponse\"\x00\x12O\n\x0c\x44\x65leteApiKey\x12\x1d.admin.v1.DeleteApiKeyRequest\x1a\x1e.admin.v1.DeleteApiKeyResponse\"\x00\x42\xa5\x01\n\x0c\x63om.admin.v1B\nAdminProtoP\x01ZHgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1;adminv1\xa2\x02\x03\x41XX\xaa\x02\x08\x41\x64min.V1\xca\x02\x08\x41\x64min\\V1\xe2\x02\x14\x41\x64min\\V1\\GPBMetadata\xea\x02\tAdmin::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.admin_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\014com.admin.v1B\nAdminProtoP\001ZHgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1;adminv1\242\002\003AXX\252\002\010Admin.V1\312\002\010Admin\\V1\342\002\024Admin\\V1\\GPBMetadata\352\002\tAdmin::V1'
  _globals['_APIKEY'].fields_by_name['id']._options = None
  _globals['_APIKEY'].fields_by_name['id']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_APIKEY'].fields_by_name['name']._options = None
  _globals['_APIKEY'].fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_CREATEAPIKEYREQUEST'].fields_by_name['name']._options = None
  _globals['_CREATEAPIKEYREQUEST'].fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_CREATEAPIKEYRESPONSE'].fields_by_name['id']._options = None
  _globals['_CREATEAPIKEYRESPONSE'].fields_by_name['id']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_CREATEAPIKEYRESPONSE'].fields_by_name['name']._options = None
  _globals['_CREATEAPIKEYRESPONSE'].fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_CREATEAPIKEYRESPONSE'].fields_by_name['secret']._options = None
  _globals['_CREATEAPIKEYRESPONSE'].fields_by_name['secret']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_DELETEAPIKEYREQUEST'].fields_by_name['id']._options = None
  _globals['_DELETEAPIKEYREQUEST'].fields_by_name['id']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_GETAPIKEYSREQUEST']._serialized_start=134
  _globals['_GETAPIKEYSREQUEST']._serialized_end=243
  _globals['_APIKEY']._serialized_start=245
  _globals['_APIKEY']._serialized_end=366
  _globals['_GETAPIKEYSRESPONSE']._serialized_start=369
  _globals['_GETAPIKEYSRESPONSE']._serialized_end=504
  _globals['_CREATEAPIKEYREQUEST']._serialized_start=506
  _globals['_CREATEAPIKEYREQUEST']._serialized_end=556
  _globals['_CREATEAPIKEYRESPONSE']._serialized_start=559
  _globals['_CREATEAPIKEYRESPONSE']._serialized_end=727
  _globals['_DELETEAPIKEYREQUEST']._serialized_start=729
  _globals['_DELETEAPIKEYREQUEST']._serialized_end=775
  _globals['_DELETEAPIKEYRESPONSE']._serialized_start=777
  _globals['_DELETEAPIKEYRESPONSE']._serialized_end=799
  _globals['_DEVSERVICE']._serialized_start=802
  _globals['_DEVSERVICE']._serialized_end=1051
# @@protoc_insertion_point(module_scope)
