# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: admin/v1/types/v1/coderepo.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n admin/v1/types/v1/coderepo.proto\x12\x11\x61\x64min.v1.types.v1\"\xba\x02\n\x08\x43odeRepo\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x33\n\x16\x63loud_provider_repo_id\x18\x02 \x01(\x05R\x13\x63loudProviderRepoId\x12\x1d\n\ncreated_by\x18\x03 \x01(\tR\tcreatedBy\x12\x12\n\x04type\x18\x04 \x01(\tR\x04type\x12\x12\n\x04name\x18\x05 \x01(\tR\x04name\x12\x17\n\x07hook_id\x18\x06 \x01(\x05R\x06hookId\x12\x16\n\x06status\x18\x07 \x01(\tR\x06status\x12\x16\n\x06\x61\x63tive\x18\x08 \x01(\x08R\x06\x61\x63tive\x12\x1d\n\ncreated_at\x18\t \x01(\tR\tcreatedAt\x12\x1d\n\nupdated_at\x18\n \x01(\tR\tupdatedAt\x12\x1b\n\texpire_at\x18\x0b \x01(\tR\x08\x65xpireAtB\xe0\x01\n\x15\x63om.admin.v1.types.v1B\rCoderepoProtoP\x01ZQgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1/types/v1;typesv1\xa2\x02\x03\x41VT\xaa\x02\x11\x41\x64min.V1.Types.V1\xca\x02\x11\x41\x64min\\V1\\Types\\V1\xe2\x02\x1d\x41\x64min\\V1\\Types\\V1\\GPBMetadata\xea\x02\x14\x41\x64min::V1::Types::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.types.v1.coderepo_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.admin.v1.types.v1B\rCoderepoProtoP\001ZQgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1/types/v1;typesv1\242\002\003AVT\252\002\021Admin.V1.Types.V1\312\002\021Admin\\V1\\Types\\V1\342\002\035Admin\\V1\\Types\\V1\\GPBMetadata\352\002\024Admin::V1::Types::V1'
  _globals['_CODEREPO']._serialized_start=56
  _globals['_CODEREPO']._serialized_end=370
# @@protoc_insertion_point(module_scope)
