# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import integration_datahub_pb2 as admin_dot_v1_dot_integration__datahub__pb2


class DatahubServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateDatahubIntegration = channel.unary_unary(
                '/admin.v1.DatahubService/CreateDatahubIntegration',
                request_serializer=admin_dot_v1_dot_integration__datahub__pb2.CreateDatahubIntegrationRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__datahub__pb2.CreateDatahubIntegrationResponse.FromString,
                )
        self.GetDatahubIntegration = channel.unary_unary(
                '/admin.v1.DatahubService/GetDatahubIntegration',
                request_serializer=admin_dot_v1_dot_integration__datahub__pb2.GetDatahubIntegrationRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__datahub__pb2.GetDatahubIntegrationResponse.FromString,
                )
        self.UpdateDatahubIntegration = channel.unary_unary(
                '/admin.v1.DatahubService/UpdateDatahubIntegration',
                request_serializer=admin_dot_v1_dot_integration__datahub__pb2.UpdateDatahubIntegrationRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__datahub__pb2.UpdateDatahubIntegrationResponse.FromString,
                )
        self.RefreshWebhookToken = channel.unary_unary(
                '/admin.v1.DatahubService/RefreshWebhookToken',
                request_serializer=admin_dot_v1_dot_integration__datahub__pb2.RefreshWebhookTokenRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__datahub__pb2.RefreshWebhookTokenResponse.FromString,
                )
        self.DeleteDatahubIntegration = channel.unary_unary(
                '/admin.v1.DatahubService/DeleteDatahubIntegration',
                request_serializer=admin_dot_v1_dot_integration__datahub__pb2.DeleteDatahubIntegrationRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__datahub__pb2.DeleteDatahubIntegrationResponse.FromString,
                )


class DatahubServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateDatahubIntegration(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDatahubIntegration(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateDatahubIntegration(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RefreshWebhookToken(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteDatahubIntegration(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DatahubServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateDatahubIntegration': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateDatahubIntegration,
                    request_deserializer=admin_dot_v1_dot_integration__datahub__pb2.CreateDatahubIntegrationRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__datahub__pb2.CreateDatahubIntegrationResponse.SerializeToString,
            ),
            'GetDatahubIntegration': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDatahubIntegration,
                    request_deserializer=admin_dot_v1_dot_integration__datahub__pb2.GetDatahubIntegrationRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__datahub__pb2.GetDatahubIntegrationResponse.SerializeToString,
            ),
            'UpdateDatahubIntegration': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateDatahubIntegration,
                    request_deserializer=admin_dot_v1_dot_integration__datahub__pb2.UpdateDatahubIntegrationRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__datahub__pb2.UpdateDatahubIntegrationResponse.SerializeToString,
            ),
            'RefreshWebhookToken': grpc.unary_unary_rpc_method_handler(
                    servicer.RefreshWebhookToken,
                    request_deserializer=admin_dot_v1_dot_integration__datahub__pb2.RefreshWebhookTokenRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__datahub__pb2.RefreshWebhookTokenResponse.SerializeToString,
            ),
            'DeleteDatahubIntegration': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteDatahubIntegration,
                    request_deserializer=admin_dot_v1_dot_integration__datahub__pb2.DeleteDatahubIntegrationRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__datahub__pb2.DeleteDatahubIntegrationResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'admin.v1.DatahubService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class DatahubService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateDatahubIntegration(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.DatahubService/CreateDatahubIntegration',
            admin_dot_v1_dot_integration__datahub__pb2.CreateDatahubIntegrationRequest.SerializeToString,
            admin_dot_v1_dot_integration__datahub__pb2.CreateDatahubIntegrationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDatahubIntegration(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.DatahubService/GetDatahubIntegration',
            admin_dot_v1_dot_integration__datahub__pb2.GetDatahubIntegrationRequest.SerializeToString,
            admin_dot_v1_dot_integration__datahub__pb2.GetDatahubIntegrationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateDatahubIntegration(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.DatahubService/UpdateDatahubIntegration',
            admin_dot_v1_dot_integration__datahub__pb2.UpdateDatahubIntegrationRequest.SerializeToString,
            admin_dot_v1_dot_integration__datahub__pb2.UpdateDatahubIntegrationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RefreshWebhookToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.DatahubService/RefreshWebhookToken',
            admin_dot_v1_dot_integration__datahub__pb2.RefreshWebhookTokenRequest.SerializeToString,
            admin_dot_v1_dot_integration__datahub__pb2.RefreshWebhookTokenResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteDatahubIntegration(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.DatahubService/DeleteDatahubIntegration',
            admin_dot_v1_dot_integration__datahub__pb2.DeleteDatahubIntegrationRequest.SerializeToString,
            admin_dot_v1_dot_integration__datahub__pb2.DeleteDatahubIntegrationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
