# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: admin/v1/inventory.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .types.v1 import domain_pb2 as admin_dot_v1_dot_types_dot_v1_dot_domain__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from ...validate.v1 import validate_pb2 as validate_dot_v1_dot_validate__pb2
from .types.v1 import list_metadata_pb2 as admin_dot_v1_dot_types_dot_v1_dot_list__metadata__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x61\x64min/v1/inventory.proto\x12\x08\x61\x64min.v1\x1a\x1e\x61\x64min/v1/types/v1/domain.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1avalidate/v1/validate.proto\x1a%admin/v1/types/v1/list_metadata.proto\"\x1c\n\x1aGetInventoryFlatOldRequest\"\xa6\x04\n\tColumnOld\x12\x1d\n\ncreated_at\x18\x01 \x01(\x03R\tcreatedAt\x12\x1d\n\nupdated_at\x18\x02 \x01(\x03R\tupdatedAt\x12!\n\x0c\x64\x61tastore_id\x18\x03 \x01(\tR\x0b\x64\x61tastoreId\x12%\n\x0e\x64\x61tastore_name\x18\x04 \x01(\tR\rdatastoreName\x12\x12\n\x04path\x18\x05 \x01(\tR\x04path\x12*\n\x11table_physical_id\x18\x06 \x01(\tR\x0ftablePhysicalId\x12\x34\n\x16table_attribute_number\x18\x07 \x01(\x04R\x14tableAttributeNumber\x12\x12\n\x04name\x18\x08 \x01(\tR\x04name\x12\x14\n\x05\x61lias\x18\t \x01(\tR\x05\x61lias\x12\x1d\n\ntable_path\x18\n \x01(\tR\ttablePath\x12\x1d\n\ndata_label\x18\x0b \x01(\tR\tdataLabel\x12\x1b\n\tdata_type\x18\x0c \x01(\tR\x08\x64\x61taType\x12\"\n\rdata_type_oid\x18\r \x01(\rR\x0b\x64\x61taTypeOid\x12@\n\x1d\x64\x61ta_label_locked_for_sidecar\x18\x0e \x01(\x08R\x19\x64\x61taLabelLockedForSidecar\x12\x12\n\x04tags\x18\x0f \x03(\tR\x04tags\x12\x1c\n\tencrypted\x18\x10 \x01(\x08R\tencrypted\"P\n\x1bGetInventoryFlatOldResponse\x12\x31\n\tinventory\x18\x01 \x03(\x0b\x32\x13.admin.v1.ColumnOldR\tinventory\"\x94\x03\n\"UpdateColumnFieldEncryptionRequest\x12*\n\x0c\x64\x61tastore_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x0b\x64\x61tastoreId\x12\x1b\n\x04path\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04path\x12l\n\x16\x65ncryption_key_storage\x18\x03 \x01(\tB6\xfa\x42\x33r1R\x12\x63ontrol_plane_onlyR\x1b\x63ontrol_plane_and_with_dataR\x14\x65ncryptionKeyStorage\x12*\n\x11\x65ncryption_key_id\x18\x04 \x01(\tR\x0f\x65ncryptionKeyId\x12W\n\x14\x65ncryption_algorithm\x18\x05 \x01(\tB$\xfa\x42!r\x1fR\x11\x61\x65s_deterministicR\naes_randomR\x13\x65ncryptionAlgorithm\x12\x32\n\x15\x65ncrypt_existing_data\x18\x06 \x01(\x08R\x13\x65ncryptExistingData\"%\n#UpdateColumnFieldEncryptionResponse\"d\n\x19GetInventoryObjectRequest\x12*\n\x0c\x64\x61tastore_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x0b\x64\x61tastoreId\x12\x1b\n\x04path\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04path\"F\n\x1aGetInventoryObjectResponse\x12(\n\x06\x63olumn\x18\x01 \x01(\x0b\x32\x10.admin.v1.ColumnR\x06\x63olumn\"!\n\x1fGetInventoryHierarchicalRequest\"\x92\x07\n GetInventoryHierarchicalResponse\x12R\n\tinventory\x18\x01 \x03(\x0b\x32\x34.admin.v1.GetInventoryHierarchicalResponse.DatastoreR\tinventory\x1a\x90\x01\n\tDatastore\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x1e\n\ntechnology\x18\x03 \x01(\tR\ntechnology\x12?\n\x03\x64\x62s\x18\x04 \x03(\x0b\x32-.admin.v1.GetInventoryHierarchicalResponse.DbR\x03\x64\x62s\x1a\xe6\x01\n\x02\x44\x62\x12\x12\n\x04path\x18\x01 \x01(\tR\x04path\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12!\n\x0c\x64\x61tastore_id\x18\x03 \x01(\tR\x0b\x64\x61tastoreId\x12K\n\x07schemas\x18\x04 \x03(\x0b\x32\x31.admin.v1.GetInventoryHierarchicalResponse.SchemaR\x07schemas\x12H\n\x06tables\x18\x05 \x03(\x0b\x32\x30.admin.v1.GetInventoryHierarchicalResponse.TableR\x06tables\x1a\x93\x01\n\x06Schema\x12\x12\n\x04path\x18\x01 \x01(\tR\x04path\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x17\n\x07\x64\x62_path\x18\x03 \x01(\tR\x06\x64\x62Path\x12H\n\x06tables\x18\x04 \x03(\x0b\x32\x30.admin.v1.GetInventoryHierarchicalResponse.TableR\x06tables\x1a\xb6\x01\n\x05Table\x12\x12\n\x04path\x18\x01 \x01(\tR\x04path\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x17\n\x07\x64\x62_path\x18\x03 \x01(\tR\x06\x64\x62Path\x12\x1f\n\x0bschema_path\x18\x04 \x01(\tR\nschemaPath\x12K\n\x07\x63olumns\x18\x05 \x03(\x0b\x32\x31.admin.v1.GetInventoryHierarchicalResponse.ColumnR\x07\x63olumns\x1aO\n\x06\x43olumn\x12\x12\n\x04path\x18\x01 \x01(\tR\x04path\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x1d\n\ntable_path\x18\x03 \x01(\tR\ttablePath\"\xbf\x01\n\x13GetInventoryRequest\x12\x14\n\x05limit\x18\x01 \x01(\x05R\x05limit\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor\x12\x14\n\x05order\x18\x04 \x01(\tR\x05order\x12\x12\n\x04path\x18\x05 \x01(\tR\x04path\x12%\n\x0e\x65xcluded_paths\x18\x06 \x03(\tR\rexcludedPaths\x12)\n\x10included_objects\x18\x07 \x03(\tR\x0fincludedObjects\"\x95\x01\n\x14GetInventoryResponse\x12\x37\n\tinventory\x18\x01 \x03(\x0b\x32\x19.admin.v1.InventoryObjectR\tinventory\x12\x44\n\rlist_metadata\x18\x02 \x01(\x0b\x32\x1f.admin.v1.types.v1.ListMetadataR\x0clistMetadata\"s\n\x17GetInventoryFlatRequest\x12\x14\n\x05limit\x18\x01 \x01(\x05R\x05limit\x12\x14\n\x05\x61\x66ter\x18\x02 \x01(\tR\x05\x61\x66ter\x12\x16\n\x06\x62\x65\x66ore\x18\x03 \x01(\tR\x06\x62\x65\x66ore\x12\x14\n\x05order\x18\x04 \x01(\tR\x05order\"\xb3\x04\n\x06\x43olumn\x12\x1d\n\ncreated_at\x18\x01 \x01(\x03R\tcreatedAt\x12\x1d\n\nupdated_at\x18\x02 \x01(\x03R\tupdatedAt\x12!\n\x0c\x64\x61tastore_id\x18\x03 \x01(\tR\x0b\x64\x61tastoreId\x12%\n\x0e\x64\x61tastore_name\x18\x04 \x01(\tR\rdatastoreName\x12\x12\n\x04path\x18\x05 \x01(\tR\x04path\x12*\n\x11table_physical_id\x18\x06 \x01(\tR\x0ftablePhysicalId\x12\x34\n\x16table_attribute_number\x18\x07 \x01(\x04R\x14tableAttributeNumber\x12\x12\n\x04name\x18\x08 \x01(\tR\x04name\x12\x14\n\x05\x61lias\x18\t \x01(\tR\x05\x61lias\x12\x1d\n\ntable_path\x18\n \x01(\tR\ttablePath\x12\x1d\n\ndata_label\x18\x0b \x01(\tR\tdataLabel\x12\x1b\n\tdata_type\x18\x0c \x01(\tR\x08\x64\x61taType\x12\"\n\rdata_type_oid\x18\r \x01(\rR\x0b\x64\x61taTypeOid\x12@\n\x1d\x64\x61ta_label_locked_for_sidecar\x18\x0e \x01(\x08R\x19\x64\x61taLabelLockedForSidecar\x12\x12\n\x04tags\x18\x0f \x03(\tR\x04tags\x12\x1c\n\tencrypted\x18\x10 \x01(\x08R\tencrypted\x12\x0e\n\x02id\x18\x11 \x01(\tR\x02id\"h\n\x02\x44s\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x1e\n\ntechnology\x18\x03 \x01(\tR\ntechnology\x12\x1e\n\x03\x64\x62s\x18\x04 \x03(\x0b\x32\x0c.admin.v1.DbR\x03\x64\x62s\"\xb4\x01\n\x02\x44\x62\x12\x12\n\x04path\x18\x01 \x01(\tR\x04path\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12!\n\x0c\x64\x61tastore_id\x18\x03 \x01(\tR\x0b\x64\x61tastoreId\x12*\n\x07schemas\x18\x04 \x03(\x0b\x32\x10.admin.v1.SchemaR\x07schemas\x12\'\n\x06tables\x18\x05 \x03(\x0b\x32\x0f.admin.v1.TableR\x06tables\x12\x0e\n\x02id\x18\x06 \x01(\tR\x02id\"\xa5\x01\n\x06Schema\x12\x12\n\x04path\x18\x01 \x01(\tR\x04path\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x17\n\x07\x64\x62_path\x18\x03 \x01(\tR\x06\x64\x62Path\x12\'\n\x06tables\x18\x04 \x03(\x0b\x32\x0f.admin.v1.TableR\x06tables\x12\x0e\n\x02id\x18\x05 \x01(\tR\x02id\x12!\n\x0c\x64\x61tastore_id\x18\x06 \x01(\tR\x0b\x64\x61tastoreId\"\xc8\x01\n\x05Table\x12\x12\n\x04path\x18\x01 \x01(\tR\x04path\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x17\n\x07\x64\x62_path\x18\x03 \x01(\tR\x06\x64\x62Path\x12\x1f\n\x0bschema_path\x18\x04 \x01(\tR\nschemaPath\x12*\n\x07\x63olumns\x18\x05 \x03(\x0b\x32\x10.admin.v1.ColumnR\x07\x63olumns\x12\x0e\n\x02id\x18\x06 \x01(\tR\x02id\x12!\n\x0c\x64\x61tastore_id\x18\x07 \x01(\tR\x0b\x64\x61tastoreId\"\xbe\x03\n\tSubColumn\x12\x1d\n\ncreated_at\x18\x01 \x01(\x03R\tcreatedAt\x12\x1d\n\nupdated_at\x18\x02 \x01(\x03R\tupdatedAt\x12!\n\x0c\x64\x61tastore_id\x18\x03 \x01(\tR\x0b\x64\x61tastoreId\x12%\n\x0e\x64\x61tastore_name\x18\x04 \x01(\tR\rdatastoreName\x12\x12\n\x04path\x18\x05 \x01(\tR\x04path\x12\x12\n\x04name\x18\x08 \x01(\tR\x04name\x12\x1d\n\ntable_path\x18\n \x01(\tR\ttablePath\x12\x1d\n\ndata_label\x18\x0b \x01(\tR\tdataLabel\x12\x1b\n\tdata_type\x18\x0c \x01(\tR\x08\x64\x61taType\x12\"\n\rdata_type_oid\x18\r \x01(\rR\x0b\x64\x61taTypeOid\x12@\n\x1d\x64\x61ta_label_locked_for_sidecar\x18\x0e \x01(\x08R\x19\x64\x61taLabelLockedForSidecar\x12\x12\n\x04tags\x18\x0f \x03(\tR\x04tags\x12\x1c\n\tencrypted\x18\x10 \x01(\x08R\tencrypted\x12\x0e\n\x02id\x18\x11 \x01(\tR\x02id\"\xa0\x02\n\x0fInventoryObject\x12,\n\tdatastore\x18\x01 \x01(\x0b\x32\x0c.admin.v1.DsH\x00R\tdatastore\x12\x1e\n\x02\x64\x62\x18\x02 \x01(\x0b\x32\x0c.admin.v1.DbH\x00R\x02\x64\x62\x12*\n\x06schema\x18\x03 \x01(\x0b\x32\x10.admin.v1.SchemaH\x00R\x06schema\x12\'\n\x05table\x18\x04 \x01(\x0b\x32\x0f.admin.v1.TableH\x00R\x05table\x12*\n\x06\x63olumn\x18\x05 \x01(\x0b\x32\x10.admin.v1.ColumnH\x00R\x06\x63olumn\x12\x34\n\nsub_column\x18\x06 \x01(\x0b\x32\x13.admin.v1.SubColumnH\x00R\tsubColumnB\x08\n\x06object\"\x99\x01\n\x18GetInventoryFlatResponse\x12\x37\n\tinventory\x18\x01 \x03(\x0b\x32\x19.admin.v1.InventoryObjectR\tinventory\x12\x44\n\rlist_metadata\x18\x02 \x01(\x0b\x32\x1f.admin.v1.types.v1.ListMetadataR\x0clistMetadata\"\x86\x01\n\x1dUpdateColumnLockStatusRequest\x12*\n\x0c\x64\x61tastore_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x0b\x64\x61tastoreId\x12\x1b\n\x04path\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04path\x12\x1c\n\tvalidated\x18\x03 \x01(\x08R\tvalidated\" \n\x1eUpdateColumnLockStatusResponse\"\x86\x01\n\x1cUpdateColumnDataLabelRequest\x12*\n\x0c\x64\x61tastore_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x0b\x64\x61tastoreId\x12\x1b\n\x04path\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04path\x12\x1d\n\ndata_label\x18\x03 \x01(\tR\tdataLabel\"\x1f\n\x1dUpdateColumnDataLabelResponse\"\x9f\x07\n\x1c\x43reateInventoryObjectRequest\x12*\n\x0c\x64\x61tastore_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x0b\x64\x61tastoreId\x12M\n\x0bobject_type\x18\x02 \x01(\tB,\xfa\x42)r\'R\x02\x64\x62R\x06schemaR\x05tableR\x06\x63olumnR\nsub-columnR\nobjectType\x12\x39\n\x02\x64\x62\x18\x03 \x01(\x0b\x32).admin.v1.CreateInventoryObjectRequest.DbR\x02\x64\x62\x12\x45\n\x06schema\x18\x04 \x01(\x0b\x32-.admin.v1.CreateInventoryObjectRequest.SchemaR\x06schema\x12\x42\n\x05table\x18\x05 \x01(\x0b\x32,.admin.v1.CreateInventoryObjectRequest.TableR\x05table\x12\x45\n\x06\x63olumn\x18\x06 \x01(\x0b\x32-.admin.v1.CreateInventoryObjectRequest.ColumnR\x06\x63olumn\x12O\n\nsub_column\x18\x07 \x01(\x0b\x32\x30.admin.v1.CreateInventoryObjectRequest.SubColumnR\tsubColumn\x1a>\n\x02\x44\x62\x12\x1b\n\x04path\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04path\x12\x1b\n\x04name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04name\x1a\x42\n\x06Schema\x12\x1b\n\x04path\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04path\x12\x1b\n\x04name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04name\x1a\x41\n\x05Table\x12\x1b\n\x04path\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04path\x12\x1b\n\x04name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04name\x1ah\n\x06\x43olumn\x12\x1b\n\x04path\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04path\x12\x1b\n\x04name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04name\x12$\n\tdata_type\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x08\x64\x61taType\x1au\n\tSubColumn\x12\x1b\n\x04path\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04path\x12\x1b\n\x04name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04name\x12.\n\x08sub_type\x18\x03 \x01(\tB\x13\xfa\x42\x10r\x0eR\x06hstoreR\x04jsonR\x07subType\"\x1f\n\x1d\x43reateInventoryObjectResponse\"g\n\x1c\x44\x65leteInventoryObjectRequest\x12*\n\x0c\x64\x61tastore_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x0b\x64\x61tastoreId\x12\x1b\n\x04path\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04path\"\x1f\n\x1d\x44\x65leteInventoryObjectResponse\"w\n\x03Tag\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x1b\n\x04name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04name\x12\x43\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xfa\x42\x05\xb2\x01\x02\x08\x01R\tcreatedAt\"8\n\x19\x43reateInventoryTagRequest\x12\x1b\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04name\"=\n\x1a\x43reateInventoryTagResponse\x12\x1f\n\x03tag\x18\x01 \x01(\x0b\x32\r.admin.v1.TagR\x03tag\"s\n\x17GetInventoryTagsRequest\x12\x14\n\x05limit\x18\x01 \x01(\x05R\x05limit\x12\x14\n\x05\x61\x66ter\x18\x02 \x01(\tR\x05\x61\x66ter\x12\x16\n\x06\x62\x65\x66ore\x18\x03 \x01(\tR\x06\x62\x65\x66ore\x12\x14\n\x05order\x18\x04 \x01(\tR\x05order\"\x83\x01\n\x18GetInventoryTagsResponse\x12!\n\x04tags\x18\x01 \x03(\x0b\x32\r.admin.v1.TagR\x04tags\x12\x44\n\rlist_metadata\x18\x02 \x01(\x0b\x32\x1f.admin.v1.types.v1.ListMetadataR\x0clistMetadata\"\x7f\n UpdateInventoryObjectTagsRequest\x12*\n\x0c\x64\x61tastore_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x0b\x64\x61tastoreId\x12\x1b\n\x04path\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04path\x12\x12\n\x04tags\x18\x03 \x03(\tR\x04tags\"\xce\x04\n!UpdateInventoryObjectTagsResponse\x12S\n\x06object\x18\x01 \x01(\x0b\x32;.admin.v1.UpdateInventoryObjectTagsResponse.InventoryObjectR\x06object\x1a\xd3\x03\n\x0fInventoryObject\x12!\n\x0c\x64\x61tastore_id\x18\x01 \x01(\tR\x0b\x64\x61tastoreId\x12\x12\n\x04type\x18\x02 \x01(\tR\x04type\x12\x12\n\x04path\x18\x03 \x01(\tR\x04path\x12\x17\n\x07\x64\x62_path\x18\x04 \x01(\tR\x06\x64\x62Path\x12\x1d\n\ntable_path\x18\x05 \x01(\tR\ttablePath\x12\x1f\n\x0bschema_path\x18\x06 \x01(\tR\nschemaPath\x12\x34\n\x16table_attribute_number\x18\x07 \x01(\x04R\x14tableAttributeNumber\x12\x1b\n\tdata_type\x18\x08 \x01(\tR\x08\x64\x61taType\x12\x1d\n\ndata_label\x18\t \x01(\tR\tdataLabel\x12\x1d\n\nupdated_at\x18\n \x01(\x03R\tupdatedAt\x12\x1d\n\ncreated_at\x18\x0b \x01(\x03R\tcreatedAt\x12&\n\x0f\x64\x61ta_store_name\x18\x0c \x01(\tR\rdataStoreName\x12\x12\n\x04name\x18\r \x01(\tR\x04name\x12\x1c\n\tvalidated\x18\x0e \x01(\x08R\tvalidated\x12\x12\n\x04tags\x18\x0f \x03(\tR\x04tags\"4\n\x19\x44\x65leteInventoryTagRequest\x12\x17\n\x02id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x02id\"?\n\x1a\x44\x65leteInventoryTagResponse\x12!\n\x04tags\x18\x01 \x03(\x0b\x32\r.admin.v1.TagR\x04tags\"\xd8\x01\n\x1aGetInventoryMetricsRequest\x12 \n\x07user_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x06userId\x12*\n\x0c\x64\x61tastore_id\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x0b\x64\x61tastoreId\x12\x1b\n\x04path\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04path\x12(\n\x0bobject_type\x18\x04 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\nobjectType\x12%\n\ttimeframe\x18\x05 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\ttimeframe\"\xeb\x06\n\x1bGetInventoryMetricsResponse\x12\x46\n\x07metrics\x18\x01 \x03(\x0b\x32,.admin.v1.GetInventoryMetricsResponse.MetricR\x07metrics\x1a\x83\x06\n\x06Metric\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x12\n\x04path\x18\x02 \x01(\tR\x04path\x12\x1f\n\x0b\x63olumn_name\x18\x03 \x01(\tR\ncolumnName\x12\x1f\n\x0b\x63olumn_path\x18\x04 \x01(\tR\ncolumnPath\x12\x1d\n\ntable_name\x18\x05 \x01(\tR\ttableName\x12\x1d\n\ntable_path\x18\x06 \x01(\tR\ttablePath\x12\x1f\n\x0bschema_name\x18\x07 \x01(\tR\nschemaName\x12\x1f\n\x0bschema_path\x18\x08 \x01(\tR\nschemaPath\x12\x17\n\x07\x64\x62_name\x18\t \x01(\tR\x06\x64\x62Name\x12\x17\n\x07user_id\x18\n \x01(\tR\x06userId\x12\x17\n\x07\x64\x62_user\x18\x0b \x01(\tR\x06\x64\x62User\x12\x1e\n\x0b\x65nd_user_id\x18\x0c \x01(\tR\tendUserId\x12/\n\x14\x65nd_user_db_username\x18\r \x01(\tR\x11\x65ndUserDbUsername\x12\x19\n\x08\x61pp_type\x18\x0e \x01(\tR\x07\x61ppType\x12\x15\n\x06org_id\x18\x0f \x01(\tR\x05orgId\x12!\n\x0c\x64\x61tastore_id\x18\x10 \x01(\tR\x0b\x64\x61tastoreId\x12%\n\x0e\x64\x61tastore_name\x18\x11 \x01(\tR\rdatastoreName\x12\x0e\n\x02ts\x18\x12 \x01(\tR\x02ts\x12\x18\n\x07\x63ounter\x18\x13 \x01(\x05R\x07\x63ounter\x12#\n\rreturned_rows\x18\x14 \x01(\x05R\x0creturnedRows\x12\x1d\n\nip_address\x18\x15 \x01(\tR\tipAddress\x12\x1d\n\ndata_label\x18\x16 \x01(\tR\tdataLabel\x12\x1f\n\x0b\x64\x61ta_labels\x18\x17 \x03(\tR\ndataLabels\x12\x31\n\x14\x64\x61tastore_technology\x18\x18 \x01(\tR\x13\x64\x61tastoreTechnology\x12\x16\n\x06\x62ucket\x18\x19 \x01(\tR\x06\x62ucket\"\xcf\x01\n\x17\x43reateDataDomainRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\x12\x30\n\x06owners\x18\x03 \x03(\x0b\x32\x18.admin.v1.types.v1.OwnerR\x06owners\x12%\n\x0e\x65xcluded_paths\x18\x04 \x03(\tR\rexcludedPaths\x12%\n\x0eincluded_paths\x18\x05 \x03(\tR\rincludedPaths\"*\n\x18\x43reateDataDomainResponse\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"\x17\n\x15GetDataDomainsRequest\"M\n\x16GetDataDomainsResponse\x12\x33\n\x07\x64omains\x18\x01 \x03(\x0b\x32\x19.admin.v1.types.v1.DomainR\x07\x64omains\"*\n\x18GetDataDomainByIdRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"N\n\x19GetDataDomainByIdResponse\x12\x31\n\x06\x64omain\x18\x01 \x01(\x0b\x32\x19.admin.v1.types.v1.DomainR\x06\x64omain\"\xdf\x01\n\x17UpdateDataDomainRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12\x30\n\x06owners\x18\x04 \x03(\x0b\x32\x18.admin.v1.types.v1.OwnerR\x06owners\x12%\n\x0e\x65xcluded_paths\x18\x05 \x03(\tR\rexcludedPaths\x12%\n\x0eincluded_paths\x18\x06 \x03(\tR\rincludedPaths\"M\n\x18UpdateDataDomainResponse\x12\x31\n\x06\x64omain\x18\x01 \x01(\x0b\x32\x19.admin.v1.types.v1.DomainR\x06\x64omain\")\n\x17\x44\x65leteDataDomainRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"\x1a\n\x18\x44\x65leteDataDomainResponse2\xf4\x0f\n\x10InventoryService\x12s\n\x18GetInventoryHierarchical\x12).admin.v1.GetInventoryHierarchicalRequest\x1a*.admin.v1.GetInventoryHierarchicalResponse\"\x00\x12O\n\x0cGetInventory\x12\x1d.admin.v1.GetInventoryRequest\x1a\x1e.admin.v1.GetInventoryResponse\"\x00\x12[\n\x10GetInventoryFlat\x12!.admin.v1.GetInventoryFlatRequest\x1a\".admin.v1.GetInventoryFlatResponse\"\x00\x12\x64\n\x13GetInventoryFlatOld\x12$.admin.v1.GetInventoryFlatOldRequest\x1a%.admin.v1.GetInventoryFlatOldResponse\"\x00\x12\x61\n\x12GetInventoryObject\x12#.admin.v1.GetInventoryObjectRequest\x1a$.admin.v1.GetInventoryObjectResponse\"\x00\x12m\n\x16UpdateColumnLockStatus\x12\'.admin.v1.UpdateColumnLockStatusRequest\x1a(.admin.v1.UpdateColumnLockStatusResponse\"\x00\x12j\n\x15UpdateColumnDataLabel\x12&.admin.v1.UpdateColumnDataLabelRequest\x1a\'.admin.v1.UpdateColumnDataLabelResponse\"\x00\x12|\n\x1bUpdateColumnFieldEncryption\x12,.admin.v1.UpdateColumnFieldEncryptionRequest\x1a-.admin.v1.UpdateColumnFieldEncryptionResponse\"\x00\x12v\n\x19UpdateInventoryObjectTags\x12*.admin.v1.UpdateInventoryObjectTagsRequest\x1a+.admin.v1.UpdateInventoryObjectTagsResponse\"\x00\x12j\n\x15\x43reateInventoryObject\x12&.admin.v1.CreateInventoryObjectRequest\x1a\'.admin.v1.CreateInventoryObjectResponse\"\x00\x12j\n\x15\x44\x65leteInventoryObject\x12&.admin.v1.DeleteInventoryObjectRequest\x1a\'.admin.v1.DeleteInventoryObjectResponse\"\x00\x12\x61\n\x12\x43reateInventoryTag\x12#.admin.v1.CreateInventoryTagRequest\x1a$.admin.v1.CreateInventoryTagResponse\"\x00\x12[\n\x10GetInventoryTags\x12!.admin.v1.GetInventoryTagsRequest\x1a\".admin.v1.GetInventoryTagsResponse\"\x00\x12\x61\n\x12\x44\x65leteInventoryTag\x12#.admin.v1.DeleteInventoryTagRequest\x1a$.admin.v1.DeleteInventoryTagResponse\"\x00\x12\x64\n\x13GetInventoryMetrics\x12$.admin.v1.GetInventoryMetricsRequest\x1a%.admin.v1.GetInventoryMetricsResponse\"\x00\x12Y\n\x10\x43reateDataDomain\x12!.admin.v1.CreateDataDomainRequest\x1a\".admin.v1.CreateDataDomainResponse\x12S\n\x0eGetDataDomains\x12\x1f.admin.v1.GetDataDomainsRequest\x1a .admin.v1.GetDataDomainsResponse\x12\\\n\x11GetDataDomainById\x12\".admin.v1.GetDataDomainByIdRequest\x1a#.admin.v1.GetDataDomainByIdResponse\x12Y\n\x10UpdateDataDomain\x12!.admin.v1.UpdateDataDomainRequest\x1a\".admin.v1.UpdateDataDomainResponse\x12Y\n\x10\x44\x65leteDataDomain\x12!.admin.v1.DeleteDataDomainRequest\x1a\".admin.v1.DeleteDataDomainResponseB\xa9\x01\n\x0c\x63om.admin.v1B\x0eInventoryProtoP\x01ZHgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1;adminv1\xa2\x02\x03\x41XX\xaa\x02\x08\x41\x64min.V1\xca\x02\x08\x41\x64min\\V1\xe2\x02\x14\x41\x64min\\V1\\GPBMetadata\xea\x02\tAdmin::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.inventory_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\014com.admin.v1B\016InventoryProtoP\001ZHgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1;adminv1\242\002\003AXX\252\002\010Admin.V1\312\002\010Admin\\V1\342\002\024Admin\\V1\\GPBMetadata\352\002\tAdmin::V1'
  _globals['_UPDATECOLUMNFIELDENCRYPTIONREQUEST'].fields_by_name['datastore_id']._options = None
  _globals['_UPDATECOLUMNFIELDENCRYPTIONREQUEST'].fields_by_name['datastore_id']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_UPDATECOLUMNFIELDENCRYPTIONREQUEST'].fields_by_name['path']._options = None
  _globals['_UPDATECOLUMNFIELDENCRYPTIONREQUEST'].fields_by_name['path']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_UPDATECOLUMNFIELDENCRYPTIONREQUEST'].fields_by_name['encryption_key_storage']._options = None
  _globals['_UPDATECOLUMNFIELDENCRYPTIONREQUEST'].fields_by_name['encryption_key_storage']._serialized_options = b'\372B3r1R\022control_plane_onlyR\033control_plane_and_with_data'
  _globals['_UPDATECOLUMNFIELDENCRYPTIONREQUEST'].fields_by_name['encryption_algorithm']._options = None
  _globals['_UPDATECOLUMNFIELDENCRYPTIONREQUEST'].fields_by_name['encryption_algorithm']._serialized_options = b'\372B!r\037R\021aes_deterministicR\naes_random'
  _globals['_GETINVENTORYOBJECTREQUEST'].fields_by_name['datastore_id']._options = None
  _globals['_GETINVENTORYOBJECTREQUEST'].fields_by_name['datastore_id']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_GETINVENTORYOBJECTREQUEST'].fields_by_name['path']._options = None
  _globals['_GETINVENTORYOBJECTREQUEST'].fields_by_name['path']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_UPDATECOLUMNLOCKSTATUSREQUEST'].fields_by_name['datastore_id']._options = None
  _globals['_UPDATECOLUMNLOCKSTATUSREQUEST'].fields_by_name['datastore_id']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_UPDATECOLUMNLOCKSTATUSREQUEST'].fields_by_name['path']._options = None
  _globals['_UPDATECOLUMNLOCKSTATUSREQUEST'].fields_by_name['path']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_UPDATECOLUMNDATALABELREQUEST'].fields_by_name['datastore_id']._options = None
  _globals['_UPDATECOLUMNDATALABELREQUEST'].fields_by_name['datastore_id']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_UPDATECOLUMNDATALABELREQUEST'].fields_by_name['path']._options = None
  _globals['_UPDATECOLUMNDATALABELREQUEST'].fields_by_name['path']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_CREATEINVENTORYOBJECTREQUEST_DB'].fields_by_name['path']._options = None
  _globals['_CREATEINVENTORYOBJECTREQUEST_DB'].fields_by_name['path']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_CREATEINVENTORYOBJECTREQUEST_DB'].fields_by_name['name']._options = None
  _globals['_CREATEINVENTORYOBJECTREQUEST_DB'].fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_CREATEINVENTORYOBJECTREQUEST_SCHEMA'].fields_by_name['path']._options = None
  _globals['_CREATEINVENTORYOBJECTREQUEST_SCHEMA'].fields_by_name['path']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_CREATEINVENTORYOBJECTREQUEST_SCHEMA'].fields_by_name['name']._options = None
  _globals['_CREATEINVENTORYOBJECTREQUEST_SCHEMA'].fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_CREATEINVENTORYOBJECTREQUEST_TABLE'].fields_by_name['path']._options = None
  _globals['_CREATEINVENTORYOBJECTREQUEST_TABLE'].fields_by_name['path']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_CREATEINVENTORYOBJECTREQUEST_TABLE'].fields_by_name['name']._options = None
  _globals['_CREATEINVENTORYOBJECTREQUEST_TABLE'].fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_CREATEINVENTORYOBJECTREQUEST_COLUMN'].fields_by_name['path']._options = None
  _globals['_CREATEINVENTORYOBJECTREQUEST_COLUMN'].fields_by_name['path']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_CREATEINVENTORYOBJECTREQUEST_COLUMN'].fields_by_name['name']._options = None
  _globals['_CREATEINVENTORYOBJECTREQUEST_COLUMN'].fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_CREATEINVENTORYOBJECTREQUEST_COLUMN'].fields_by_name['data_type']._options = None
  _globals['_CREATEINVENTORYOBJECTREQUEST_COLUMN'].fields_by_name['data_type']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_CREATEINVENTORYOBJECTREQUEST_SUBCOLUMN'].fields_by_name['path']._options = None
  _globals['_CREATEINVENTORYOBJECTREQUEST_SUBCOLUMN'].fields_by_name['path']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_CREATEINVENTORYOBJECTREQUEST_SUBCOLUMN'].fields_by_name['name']._options = None
  _globals['_CREATEINVENTORYOBJECTREQUEST_SUBCOLUMN'].fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_CREATEINVENTORYOBJECTREQUEST_SUBCOLUMN'].fields_by_name['sub_type']._options = None
  _globals['_CREATEINVENTORYOBJECTREQUEST_SUBCOLUMN'].fields_by_name['sub_type']._serialized_options = b'\372B\020r\016R\006hstoreR\004json'
  _globals['_CREATEINVENTORYOBJECTREQUEST'].fields_by_name['datastore_id']._options = None
  _globals['_CREATEINVENTORYOBJECTREQUEST'].fields_by_name['datastore_id']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_CREATEINVENTORYOBJECTREQUEST'].fields_by_name['object_type']._options = None
  _globals['_CREATEINVENTORYOBJECTREQUEST'].fields_by_name['object_type']._serialized_options = b'\372B)r\'R\002dbR\006schemaR\005tableR\006columnR\nsub-column'
  _globals['_DELETEINVENTORYOBJECTREQUEST'].fields_by_name['datastore_id']._options = None
  _globals['_DELETEINVENTORYOBJECTREQUEST'].fields_by_name['datastore_id']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_DELETEINVENTORYOBJECTREQUEST'].fields_by_name['path']._options = None
  _globals['_DELETEINVENTORYOBJECTREQUEST'].fields_by_name['path']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_TAG'].fields_by_name['name']._options = None
  _globals['_TAG'].fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_TAG'].fields_by_name['created_at']._options = None
  _globals['_TAG'].fields_by_name['created_at']._serialized_options = b'\372B\005\262\001\002\010\001'
  _globals['_CREATEINVENTORYTAGREQUEST'].fields_by_name['name']._options = None
  _globals['_CREATEINVENTORYTAGREQUEST'].fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_UPDATEINVENTORYOBJECTTAGSREQUEST'].fields_by_name['datastore_id']._options = None
  _globals['_UPDATEINVENTORYOBJECTTAGSREQUEST'].fields_by_name['datastore_id']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_UPDATEINVENTORYOBJECTTAGSREQUEST'].fields_by_name['path']._options = None
  _globals['_UPDATEINVENTORYOBJECTTAGSREQUEST'].fields_by_name['path']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_DELETEINVENTORYTAGREQUEST'].fields_by_name['id']._options = None
  _globals['_DELETEINVENTORYTAGREQUEST'].fields_by_name['id']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_GETINVENTORYMETRICSREQUEST'].fields_by_name['user_id']._options = None
  _globals['_GETINVENTORYMETRICSREQUEST'].fields_by_name['user_id']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_GETINVENTORYMETRICSREQUEST'].fields_by_name['datastore_id']._options = None
  _globals['_GETINVENTORYMETRICSREQUEST'].fields_by_name['datastore_id']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_GETINVENTORYMETRICSREQUEST'].fields_by_name['path']._options = None
  _globals['_GETINVENTORYMETRICSREQUEST'].fields_by_name['path']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_GETINVENTORYMETRICSREQUEST'].fields_by_name['object_type']._options = None
  _globals['_GETINVENTORYMETRICSREQUEST'].fields_by_name['object_type']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_GETINVENTORYMETRICSREQUEST'].fields_by_name['timeframe']._options = None
  _globals['_GETINVENTORYMETRICSREQUEST'].fields_by_name['timeframe']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_GETINVENTORYFLATOLDREQUEST']._serialized_start=170
  _globals['_GETINVENTORYFLATOLDREQUEST']._serialized_end=198
  _globals['_COLUMNOLD']._serialized_start=201
  _globals['_COLUMNOLD']._serialized_end=751
  _globals['_GETINVENTORYFLATOLDRESPONSE']._serialized_start=753
  _globals['_GETINVENTORYFLATOLDRESPONSE']._serialized_end=833
  _globals['_UPDATECOLUMNFIELDENCRYPTIONREQUEST']._serialized_start=836
  _globals['_UPDATECOLUMNFIELDENCRYPTIONREQUEST']._serialized_end=1240
  _globals['_UPDATECOLUMNFIELDENCRYPTIONRESPONSE']._serialized_start=1242
  _globals['_UPDATECOLUMNFIELDENCRYPTIONRESPONSE']._serialized_end=1279
  _globals['_GETINVENTORYOBJECTREQUEST']._serialized_start=1281
  _globals['_GETINVENTORYOBJECTREQUEST']._serialized_end=1381
  _globals['_GETINVENTORYOBJECTRESPONSE']._serialized_start=1383
  _globals['_GETINVENTORYOBJECTRESPONSE']._serialized_end=1453
  _globals['_GETINVENTORYHIERARCHICALREQUEST']._serialized_start=1455
  _globals['_GETINVENTORYHIERARCHICALREQUEST']._serialized_end=1488
  _globals['_GETINVENTORYHIERARCHICALRESPONSE']._serialized_start=1491
  _globals['_GETINVENTORYHIERARCHICALRESPONSE']._serialized_end=2405
  _globals['_GETINVENTORYHIERARCHICALRESPONSE_DATASTORE']._serialized_start=1612
  _globals['_GETINVENTORYHIERARCHICALRESPONSE_DATASTORE']._serialized_end=1756
  _globals['_GETINVENTORYHIERARCHICALRESPONSE_DB']._serialized_start=1759
  _globals['_GETINVENTORYHIERARCHICALRESPONSE_DB']._serialized_end=1989
  _globals['_GETINVENTORYHIERARCHICALRESPONSE_SCHEMA']._serialized_start=1992
  _globals['_GETINVENTORYHIERARCHICALRESPONSE_SCHEMA']._serialized_end=2139
  _globals['_GETINVENTORYHIERARCHICALRESPONSE_TABLE']._serialized_start=2142
  _globals['_GETINVENTORYHIERARCHICALRESPONSE_TABLE']._serialized_end=2324
  _globals['_GETINVENTORYHIERARCHICALRESPONSE_COLUMN']._serialized_start=2326
  _globals['_GETINVENTORYHIERARCHICALRESPONSE_COLUMN']._serialized_end=2405
  _globals['_GETINVENTORYREQUEST']._serialized_start=2408
  _globals['_GETINVENTORYREQUEST']._serialized_end=2599
  _globals['_GETINVENTORYRESPONSE']._serialized_start=2602
  _globals['_GETINVENTORYRESPONSE']._serialized_end=2751
  _globals['_GETINVENTORYFLATREQUEST']._serialized_start=2753
  _globals['_GETINVENTORYFLATREQUEST']._serialized_end=2868
  _globals['_COLUMN']._serialized_start=2871
  _globals['_COLUMN']._serialized_end=3434
  _globals['_DS']._serialized_start=3436
  _globals['_DS']._serialized_end=3540
  _globals['_DB']._serialized_start=3543
  _globals['_DB']._serialized_end=3723
  _globals['_SCHEMA']._serialized_start=3726
  _globals['_SCHEMA']._serialized_end=3891
  _globals['_TABLE']._serialized_start=3894
  _globals['_TABLE']._serialized_end=4094
  _globals['_SUBCOLUMN']._serialized_start=4097
  _globals['_SUBCOLUMN']._serialized_end=4543
  _globals['_INVENTORYOBJECT']._serialized_start=4546
  _globals['_INVENTORYOBJECT']._serialized_end=4834
  _globals['_GETINVENTORYFLATRESPONSE']._serialized_start=4837
  _globals['_GETINVENTORYFLATRESPONSE']._serialized_end=4990
  _globals['_UPDATECOLUMNLOCKSTATUSREQUEST']._serialized_start=4993
  _globals['_UPDATECOLUMNLOCKSTATUSREQUEST']._serialized_end=5127
  _globals['_UPDATECOLUMNLOCKSTATUSRESPONSE']._serialized_start=5129
  _globals['_UPDATECOLUMNLOCKSTATUSRESPONSE']._serialized_end=5161
  _globals['_UPDATECOLUMNDATALABELREQUEST']._serialized_start=5164
  _globals['_UPDATECOLUMNDATALABELREQUEST']._serialized_end=5298
  _globals['_UPDATECOLUMNDATALABELRESPONSE']._serialized_start=5300
  _globals['_UPDATECOLUMNDATALABELRESPONSE']._serialized_end=5331
  _globals['_CREATEINVENTORYOBJECTREQUEST']._serialized_start=5334
  _globals['_CREATEINVENTORYOBJECTREQUEST']._serialized_end=6261
  _globals['_CREATEINVENTORYOBJECTREQUEST_DB']._serialized_start=5839
  _globals['_CREATEINVENTORYOBJECTREQUEST_DB']._serialized_end=5901
  _globals['_CREATEINVENTORYOBJECTREQUEST_SCHEMA']._serialized_start=5903
  _globals['_CREATEINVENTORYOBJECTREQUEST_SCHEMA']._serialized_end=5969
  _globals['_CREATEINVENTORYOBJECTREQUEST_TABLE']._serialized_start=5971
  _globals['_CREATEINVENTORYOBJECTREQUEST_TABLE']._serialized_end=6036
  _globals['_CREATEINVENTORYOBJECTREQUEST_COLUMN']._serialized_start=6038
  _globals['_CREATEINVENTORYOBJECTREQUEST_COLUMN']._serialized_end=6142
  _globals['_CREATEINVENTORYOBJECTREQUEST_SUBCOLUMN']._serialized_start=6144
  _globals['_CREATEINVENTORYOBJECTREQUEST_SUBCOLUMN']._serialized_end=6261
  _globals['_CREATEINVENTORYOBJECTRESPONSE']._serialized_start=6263
  _globals['_CREATEINVENTORYOBJECTRESPONSE']._serialized_end=6294
  _globals['_DELETEINVENTORYOBJECTREQUEST']._serialized_start=6296
  _globals['_DELETEINVENTORYOBJECTREQUEST']._serialized_end=6399
  _globals['_DELETEINVENTORYOBJECTRESPONSE']._serialized_start=6401
  _globals['_DELETEINVENTORYOBJECTRESPONSE']._serialized_end=6432
  _globals['_TAG']._serialized_start=6434
  _globals['_TAG']._serialized_end=6553
  _globals['_CREATEINVENTORYTAGREQUEST']._serialized_start=6555
  _globals['_CREATEINVENTORYTAGREQUEST']._serialized_end=6611
  _globals['_CREATEINVENTORYTAGRESPONSE']._serialized_start=6613
  _globals['_CREATEINVENTORYTAGRESPONSE']._serialized_end=6674
  _globals['_GETINVENTORYTAGSREQUEST']._serialized_start=6676
  _globals['_GETINVENTORYTAGSREQUEST']._serialized_end=6791
  _globals['_GETINVENTORYTAGSRESPONSE']._serialized_start=6794
  _globals['_GETINVENTORYTAGSRESPONSE']._serialized_end=6925
  _globals['_UPDATEINVENTORYOBJECTTAGSREQUEST']._serialized_start=6927
  _globals['_UPDATEINVENTORYOBJECTTAGSREQUEST']._serialized_end=7054
  _globals['_UPDATEINVENTORYOBJECTTAGSRESPONSE']._serialized_start=7057
  _globals['_UPDATEINVENTORYOBJECTTAGSRESPONSE']._serialized_end=7647
  _globals['_UPDATEINVENTORYOBJECTTAGSRESPONSE_INVENTORYOBJECT']._serialized_start=7180
  _globals['_UPDATEINVENTORYOBJECTTAGSRESPONSE_INVENTORYOBJECT']._serialized_end=7647
  _globals['_DELETEINVENTORYTAGREQUEST']._serialized_start=7649
  _globals['_DELETEINVENTORYTAGREQUEST']._serialized_end=7701
  _globals['_DELETEINVENTORYTAGRESPONSE']._serialized_start=7703
  _globals['_DELETEINVENTORYTAGRESPONSE']._serialized_end=7766
  _globals['_GETINVENTORYMETRICSREQUEST']._serialized_start=7769
  _globals['_GETINVENTORYMETRICSREQUEST']._serialized_end=7985
  _globals['_GETINVENTORYMETRICSRESPONSE']._serialized_start=7988
  _globals['_GETINVENTORYMETRICSRESPONSE']._serialized_end=8863
  _globals['_GETINVENTORYMETRICSRESPONSE_METRIC']._serialized_start=8092
  _globals['_GETINVENTORYMETRICSRESPONSE_METRIC']._serialized_end=8863
  _globals['_CREATEDATADOMAINREQUEST']._serialized_start=8866
  _globals['_CREATEDATADOMAINREQUEST']._serialized_end=9073
  _globals['_CREATEDATADOMAINRESPONSE']._serialized_start=9075
  _globals['_CREATEDATADOMAINRESPONSE']._serialized_end=9117
  _globals['_GETDATADOMAINSREQUEST']._serialized_start=9119
  _globals['_GETDATADOMAINSREQUEST']._serialized_end=9142
  _globals['_GETDATADOMAINSRESPONSE']._serialized_start=9144
  _globals['_GETDATADOMAINSRESPONSE']._serialized_end=9221
  _globals['_GETDATADOMAINBYIDREQUEST']._serialized_start=9223
  _globals['_GETDATADOMAINBYIDREQUEST']._serialized_end=9265
  _globals['_GETDATADOMAINBYIDRESPONSE']._serialized_start=9267
  _globals['_GETDATADOMAINBYIDRESPONSE']._serialized_end=9345
  _globals['_UPDATEDATADOMAINREQUEST']._serialized_start=9348
  _globals['_UPDATEDATADOMAINREQUEST']._serialized_end=9571
  _globals['_UPDATEDATADOMAINRESPONSE']._serialized_start=9573
  _globals['_UPDATEDATADOMAINRESPONSE']._serialized_end=9650
  _globals['_DELETEDATADOMAINREQUEST']._serialized_start=9652
  _globals['_DELETEDATADOMAINREQUEST']._serialized_end=9693
  _globals['_DELETEDATADOMAINRESPONSE']._serialized_start=9695
  _globals['_DELETEDATADOMAINRESPONSE']._serialized_end=9721
  _globals['_INVENTORYSERVICE']._serialized_start=9724
  _globals['_INVENTORYSERVICE']._serialized_end=11760
# @@protoc_insertion_point(module_scope)
