# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: admin/v1/integration_datahub.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .types.v1 import datahub_pb2 as admin_dot_v1_dot_types_dot_v1_dot_datahub__pb2
from ...validate.v1 import validate_pb2 as validate_dot_v1_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"admin/v1/integration_datahub.proto\x12\x08\x61\x64min.v1\x1a\x1f\x61\x64min/v1/types/v1/datahub.proto\x1a\x1avalidate/v1/validate.proto\"\xa7\x02\n\x1f\x43reateDatahubIntegrationRequest\x12\x61\n\x0esync_direction\x18\x01 \x01(\tB:\xfa\x42\x37r5R\rbidirectionalR\x11\x66ormal_to_datahubR\x11\x64\x61tahub_to_formalR\rsyncDirection\x12G\n generalized_metadata_service_url\x18\x02 \x01(\tR\x1dgeneralizedMetadataServiceUrl\x12\x16\n\x06\x61\x63tive\x18\x03 \x01(\x08R\x06\x61\x63tive\x12\x17\n\x07\x61pi_key\x18\x04 \x01(\tR\x06\x61piKey\x12\'\n\x0fsynced_entities\x18\x05 \x03(\tR\x0esyncedEntities\"2\n CreateDatahubIntegrationResponse\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"7\n\x1cGetDatahubIntegrationRequest\x12\x17\n\x02id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x02id\"]\n\x1dGetDatahubIntegrationResponse\x12<\n\x0bintegration\x18\x01 \x01(\x0b\x32\x1a.admin.v1.types.v1.DatahubR\x0bintegration\"\xba\x02\n\x1fUpdateDatahubIntegrationRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x64\n\x0esync_direction\x18\x02 \x01(\tB=\xfa\x42:r8R\rbidirectionalR\x11\x66ormal_to_datahubR\x11\x64\x61tahub_to_formal\xd0\x01\x01R\rsyncDirection\x12G\n generalized_metadata_service_url\x18\x03 \x01(\tR\x1dgeneralizedMetadataServiceUrl\x12\x16\n\x06\x61\x63tive\x18\x04 \x01(\x08R\x06\x61\x63tive\x12\x17\n\x07\x61pi_key\x18\x05 \x01(\tR\x06\x61piKey\x12\'\n\x0fsynced_entities\x18\x06 \x03(\tR\x0esyncedEntities\"`\n UpdateDatahubIntegrationResponse\x12<\n\x0bintegration\x18\x01 \x01(\x0b\x32\x1a.admin.v1.types.v1.DatahubR\x0bintegration\",\n\x1aRefreshWebhookTokenRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"3\n\x1bRefreshWebhookTokenResponse\x12\x14\n\x05token\x18\x01 \x01(\tR\x05token\"1\n\x1f\x44\x65leteDatahubIntegrationRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"\"\n DeleteDatahubIntegrationResponse2\xc1\x04\n\x0e\x44\x61tahubService\x12s\n\x18\x43reateDatahubIntegration\x12).admin.v1.CreateDatahubIntegrationRequest\x1a*.admin.v1.CreateDatahubIntegrationResponse\"\x00\x12j\n\x15GetDatahubIntegration\x12&.admin.v1.GetDatahubIntegrationRequest\x1a\'.admin.v1.GetDatahubIntegrationResponse\"\x00\x12s\n\x18UpdateDatahubIntegration\x12).admin.v1.UpdateDatahubIntegrationRequest\x1a*.admin.v1.UpdateDatahubIntegrationResponse\"\x00\x12\x64\n\x13RefreshWebhookToken\x12$.admin.v1.RefreshWebhookTokenRequest\x1a%.admin.v1.RefreshWebhookTokenResponse\"\x00\x12s\n\x18\x44\x65leteDatahubIntegration\x12).admin.v1.DeleteDatahubIntegrationRequest\x1a*.admin.v1.DeleteDatahubIntegrationResponse\"\x00\x42\xb2\x01\n\x0c\x63om.admin.v1B\x17IntegrationDatahubProtoP\x01ZHgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1;adminv1\xa2\x02\x03\x41XX\xaa\x02\x08\x41\x64min.V1\xca\x02\x08\x41\x64min\\V1\xe2\x02\x14\x41\x64min\\V1\\GPBMetadata\xea\x02\tAdmin::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.integration_datahub_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\014com.admin.v1B\027IntegrationDatahubProtoP\001ZHgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1;adminv1\242\002\003AXX\252\002\010Admin.V1\312\002\010Admin\\V1\342\002\024Admin\\V1\\GPBMetadata\352\002\tAdmin::V1'
  _globals['_CREATEDATAHUBINTEGRATIONREQUEST'].fields_by_name['sync_direction']._options = None
  _globals['_CREATEDATAHUBINTEGRATIONREQUEST'].fields_by_name['sync_direction']._serialized_options = b'\372B7r5R\rbidirectionalR\021formal_to_datahubR\021datahub_to_formal'
  _globals['_GETDATAHUBINTEGRATIONREQUEST'].fields_by_name['id']._options = None
  _globals['_GETDATAHUBINTEGRATIONREQUEST'].fields_by_name['id']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_UPDATEDATAHUBINTEGRATIONREQUEST'].fields_by_name['sync_direction']._options = None
  _globals['_UPDATEDATAHUBINTEGRATIONREQUEST'].fields_by_name['sync_direction']._serialized_options = b'\372B:r8R\rbidirectionalR\021formal_to_datahubR\021datahub_to_formal\320\001\001'
  _globals['_CREATEDATAHUBINTEGRATIONREQUEST']._serialized_start=110
  _globals['_CREATEDATAHUBINTEGRATIONREQUEST']._serialized_end=405
  _globals['_CREATEDATAHUBINTEGRATIONRESPONSE']._serialized_start=407
  _globals['_CREATEDATAHUBINTEGRATIONRESPONSE']._serialized_end=457
  _globals['_GETDATAHUBINTEGRATIONREQUEST']._serialized_start=459
  _globals['_GETDATAHUBINTEGRATIONREQUEST']._serialized_end=514
  _globals['_GETDATAHUBINTEGRATIONRESPONSE']._serialized_start=516
  _globals['_GETDATAHUBINTEGRATIONRESPONSE']._serialized_end=609
  _globals['_UPDATEDATAHUBINTEGRATIONREQUEST']._serialized_start=612
  _globals['_UPDATEDATAHUBINTEGRATIONREQUEST']._serialized_end=926
  _globals['_UPDATEDATAHUBINTEGRATIONRESPONSE']._serialized_start=928
  _globals['_UPDATEDATAHUBINTEGRATIONRESPONSE']._serialized_end=1024
  _globals['_REFRESHWEBHOOKTOKENREQUEST']._serialized_start=1026
  _globals['_REFRESHWEBHOOKTOKENREQUEST']._serialized_end=1070
  _globals['_REFRESHWEBHOOKTOKENRESPONSE']._serialized_start=1072
  _globals['_REFRESHWEBHOOKTOKENRESPONSE']._serialized_end=1123
  _globals['_DELETEDATAHUBINTEGRATIONREQUEST']._serialized_start=1125
  _globals['_DELETEDATAHUBINTEGRATIONREQUEST']._serialized_end=1174
  _globals['_DELETEDATAHUBINTEGRATIONRESPONSE']._serialized_start=1176
  _globals['_DELETEDATAHUBINTEGRATIONRESPONSE']._serialized_end=1210
  _globals['_DATAHUBSERVICE']._serialized_start=1213
  _globals['_DATAHUBSERVICE']._serialized_end=1790
# @@protoc_insertion_point(module_scope)
