# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: admin/v1/permissions.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x61\x64min/v1/permissions.proto\x12\x08\x61\x64min.v1\":\n\x1eGetPermissionsByServiceRequest\x12\x18\n\x07service\x18\x01 \x01(\tR\x07service\"\xbf\x01\n\x1fGetPermissionsByServiceResponse\x12\\\n\x0bpermissions\x18\x01 \x03(\x0b\x32:.admin.v1.GetPermissionsByServiceResponse.PermissionsEntryR\x0bpermissions\x1a>\n\x10PermissionsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x08R\x05value:\x02\x38\x01\"\x17\n\x15GetPermissionsRequest\"\xad\x01\n\x16GetPermissionsResponse\x12S\n\x0bpermissions\x18\x01 \x03(\x0b\x32\x31.admin.v1.GetPermissionsResponse.PermissionsEntryR\x0bpermissions\x1a>\n\x10PermissionsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x08R\x05value:\x02\x38\x01\x32\xdc\x01\n\x11PermissionService\x12U\n\x0eGetPermissions\x12\x1f.admin.v1.GetPermissionsRequest\x1a .admin.v1.GetPermissionsResponse\"\x00\x12p\n\x17GetPermissionsByService\x12(.admin.v1.GetPermissionsByServiceRequest\x1a).admin.v1.GetPermissionsByServiceResponse\"\x00\x42\xab\x01\n\x0c\x63om.admin.v1B\x10PermissionsProtoP\x01ZHgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1;adminv1\xa2\x02\x03\x41XX\xaa\x02\x08\x41\x64min.V1\xca\x02\x08\x41\x64min\\V1\xe2\x02\x14\x41\x64min\\V1\\GPBMetadata\xea\x02\tAdmin::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.permissions_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\014com.admin.v1B\020PermissionsProtoP\001ZHgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1;adminv1\242\002\003AXX\252\002\010Admin.V1\312\002\010Admin\\V1\342\002\024Admin\\V1\\GPBMetadata\352\002\tAdmin::V1'
  _globals['_GETPERMISSIONSBYSERVICERESPONSE_PERMISSIONSENTRY']._options = None
  _globals['_GETPERMISSIONSBYSERVICERESPONSE_PERMISSIONSENTRY']._serialized_options = b'8\001'
  _globals['_GETPERMISSIONSRESPONSE_PERMISSIONSENTRY']._options = None
  _globals['_GETPERMISSIONSRESPONSE_PERMISSIONSENTRY']._serialized_options = b'8\001'
  _globals['_GETPERMISSIONSBYSERVICEREQUEST']._serialized_start=40
  _globals['_GETPERMISSIONSBYSERVICEREQUEST']._serialized_end=98
  _globals['_GETPERMISSIONSBYSERVICERESPONSE']._serialized_start=101
  _globals['_GETPERMISSIONSBYSERVICERESPONSE']._serialized_end=292
  _globals['_GETPERMISSIONSBYSERVICERESPONSE_PERMISSIONSENTRY']._serialized_start=230
  _globals['_GETPERMISSIONSBYSERVICERESPONSE_PERMISSIONSENTRY']._serialized_end=292
  _globals['_GETPERMISSIONSREQUEST']._serialized_start=294
  _globals['_GETPERMISSIONSREQUEST']._serialized_end=317
  _globals['_GETPERMISSIONSRESPONSE']._serialized_start=320
  _globals['_GETPERMISSIONSRESPONSE']._serialized_end=493
  _globals['_GETPERMISSIONSRESPONSE_PERMISSIONSENTRY']._serialized_start=230
  _globals['_GETPERMISSIONSRESPONSE_PERMISSIONSENTRY']._serialized_end=292
  _globals['_PERMISSIONSERVICE']._serialized_start=496
  _globals['_PERMISSIONSERVICE']._serialized_end=716
# @@protoc_insertion_point(module_scope)
