# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import satellite_pb2 as admin_dot_v1_dot_satellite__pb2


class SatelliteServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateSatellite = channel.unary_unary(
                '/admin.v1.SatelliteService/CreateSatellite',
                request_serializer=admin_dot_v1_dot_satellite__pb2.CreateSatelliteRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_satellite__pb2.CreateSatelliteResponse.FromString,
                )
        self.GetSatelliteById = channel.unary_unary(
                '/admin.v1.SatelliteService/GetSatelliteById',
                request_serializer=admin_dot_v1_dot_satellite__pb2.GetSatelliteByIdRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_satellite__pb2.GetSatelliteByIdResponse.FromString,
                )
        self.GetSatellites = channel.unary_unary(
                '/admin.v1.SatelliteService/GetSatellites',
                request_serializer=admin_dot_v1_dot_satellite__pb2.GetSatellitesRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_satellite__pb2.GetSatellitesResponse.FromString,
                )
        self.GetSatelliteApiKey = channel.unary_unary(
                '/admin.v1.SatelliteService/GetSatelliteApiKey',
                request_serializer=admin_dot_v1_dot_satellite__pb2.GetSatelliteApiKeyRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_satellite__pb2.GetSatelliteApiKeyResponse.FromString,
                )
        self.DeleteSatellite = channel.unary_unary(
                '/admin.v1.SatelliteService/DeleteSatellite',
                request_serializer=admin_dot_v1_dot_satellite__pb2.DeleteSatelliteRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_satellite__pb2.DeleteSatelliteResponse.FromString,
                )


class SatelliteServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateSatellite(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSatelliteById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSatellites(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSatelliteApiKey(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteSatellite(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SatelliteServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateSatellite': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateSatellite,
                    request_deserializer=admin_dot_v1_dot_satellite__pb2.CreateSatelliteRequest.FromString,
                    response_serializer=admin_dot_v1_dot_satellite__pb2.CreateSatelliteResponse.SerializeToString,
            ),
            'GetSatelliteById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSatelliteById,
                    request_deserializer=admin_dot_v1_dot_satellite__pb2.GetSatelliteByIdRequest.FromString,
                    response_serializer=admin_dot_v1_dot_satellite__pb2.GetSatelliteByIdResponse.SerializeToString,
            ),
            'GetSatellites': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSatellites,
                    request_deserializer=admin_dot_v1_dot_satellite__pb2.GetSatellitesRequest.FromString,
                    response_serializer=admin_dot_v1_dot_satellite__pb2.GetSatellitesResponse.SerializeToString,
            ),
            'GetSatelliteApiKey': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSatelliteApiKey,
                    request_deserializer=admin_dot_v1_dot_satellite__pb2.GetSatelliteApiKeyRequest.FromString,
                    response_serializer=admin_dot_v1_dot_satellite__pb2.GetSatelliteApiKeyResponse.SerializeToString,
            ),
            'DeleteSatellite': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteSatellite,
                    request_deserializer=admin_dot_v1_dot_satellite__pb2.DeleteSatelliteRequest.FromString,
                    response_serializer=admin_dot_v1_dot_satellite__pb2.DeleteSatelliteResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'admin.v1.SatelliteService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class SatelliteService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateSatellite(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.SatelliteService/CreateSatellite',
            admin_dot_v1_dot_satellite__pb2.CreateSatelliteRequest.SerializeToString,
            admin_dot_v1_dot_satellite__pb2.CreateSatelliteResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSatelliteById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.SatelliteService/GetSatelliteById',
            admin_dot_v1_dot_satellite__pb2.GetSatelliteByIdRequest.SerializeToString,
            admin_dot_v1_dot_satellite__pb2.GetSatelliteByIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSatellites(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.SatelliteService/GetSatellites',
            admin_dot_v1_dot_satellite__pb2.GetSatellitesRequest.SerializeToString,
            admin_dot_v1_dot_satellite__pb2.GetSatellitesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSatelliteApiKey(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.SatelliteService/GetSatelliteApiKey',
            admin_dot_v1_dot_satellite__pb2.GetSatelliteApiKeyRequest.SerializeToString,
            admin_dot_v1_dot_satellite__pb2.GetSatelliteApiKeyResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteSatellite(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.SatelliteService/DeleteSatellite',
            admin_dot_v1_dot_satellite__pb2.DeleteSatelliteRequest.SerializeToString,
            admin_dot_v1_dot_satellite__pb2.DeleteSatelliteResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
