# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: admin/v1/work_os.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16\x61\x64min/v1/work_os.proto\x12\x08\x61\x64min.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\x15\n\x13GetDirectoryRequest\"I\n\x14GetDirectoryResponse\x12\x31\n\tdirectory\x18\x01 \x01(\x0b\x32\x13.admin.v1.DirectoryR\tdirectory\"\xa7\x01\n\tDirectory\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x15\n\x06idp_id\x18\x03 \x01(\tR\x05idpId\x12!\n\x0c\x64irectory_id\x18\x04 \x01(\tR\x0b\x64irectoryId\x12\x1d\n\ncreated_at\x18\x05 \x01(\tR\tcreatedAt\x12\x1d\n\nupdated_at\x18\x06 \x01(\tR\tupdatedAt\"/\n\x1dGetGroupsByDirectoryIdRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"V\n\x1eGetGroupsByDirectoryIdResponse\x12\x34\n\x06groups\x18\x01 \x03(\x0b\x32\x1c.admin.v1.DirectorySyncGroupR\x06groups\".\n\x1cGetUsersByDirectoryIdRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"I\n\x1dGetUsersByDirectoryIdResponse\x12(\n\x05users\x18\x01 \x03(\x0b\x32\x12.admin.v1.WorkUserR\x05users\"+\n\x19GetWorkOsGroupByIdRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"P\n\x1aGetWorkOsGroupByIdResponse\x12\x32\n\x05group\x18\x01 \x01(\x0b\x32\x1c.admin.v1.DirectorySyncGroupR\x05group\"\xe5\x01\n\x12\x44irectorySyncGroup\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x15\n\x06idp_id\x18\x03 \x01(\tR\x05idpId\x12!\n\x0c\x64irectory_id\x18\x04 \x01(\tR\x0b\x64irectoryId\x12\x1d\n\ncreated_at\x18\x05 \x01(\tR\tcreatedAt\x12\x1d\n\nupdated_at\x18\x06 \x01(\tR\tupdatedAt\x12\x33\n\x16mapped_formal_group_id\x18\x07 \x01(\tR\x13mappedFormalGroupId\"O\n\tUserEmail\x12\x18\n\x07primary\x18\x01 \x01(\x08R\x07primary\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value\x12\x12\n\x04type\x18\x03 \x01(\tR\x04type\"G\n\tUserGroup\x12\x16\n\x06object\x18\x01 \x01(\tR\x06object\x12\x0e\n\x02id\x18\x02 \x01(\tR\x02id\x12\x12\n\x04name\x18\x03 \x01(\tR\x04name\"\xca\x02\n\x08WorkUser\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x15\n\x06idp_id\x18\x02 \x01(\tR\x05idpId\x12!\n\x0c\x64irectory_id\x18\x03 \x01(\tR\x0b\x64irectoryId\x12\x1a\n\x08username\x18\x04 \x01(\tR\x08username\x12+\n\x06\x65mails\x18\x05 \x03(\x0b\x32\x13.admin.v1.UserEmailR\x06\x65mails\x12\x1d\n\nfirst_name\x18\x07 \x01(\tR\tfirstName\x12\x1b\n\tlast_name\x18\x08 \x01(\tR\x08lastName\x12\x1b\n\tjob_title\x18\t \x01(\tR\x08jobTitle\x12\x14\n\x05state\x18\n \x01(\tR\x05state\x12\x1d\n\ncreated_at\x18\x0b \x01(\tR\tcreatedAt\x12\x1d\n\nupdated_at\x18\x0c \x01(\tR\tupdatedAt\"1\n\x05Users\x12(\n\x05users\x18\x01 \x03(\x0b\x32\x12.admin.v1.WorkUserR\x05users\"\xf9\x01\n\x05Group\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12\x16\n\x06\x61\x63tive\x18\x04 \x01(\x08R\x06\x61\x63tive\x12\x16\n\x06status\x18\x05 \x01(\tR\x06status\x12\x39\n\ncreated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x19\n\x08user_ids\x18\x07 \x03(\tR\x07userIds\x12$\n\x0e\x64sync_group_id\x18\x08 \x01(\tR\x0c\x64syncGroupId\"l\n\tGroupPair\x12(\n\x07\x66_group\x18\x01 \x01(\x0b\x32\x0f.admin.v1.GroupR\x06\x66Group\x12\x35\n\x07\x64_group\x18\x02 \x01(\x0b\x32\x1c.admin.v1.DirectorySyncGroupR\x06\x64Group\"\x1b\n\x19GetDirectoryGroupsRequest\"\x88\x03\n\x1aGetDirectoryGroupsResponse\x12#\n\rdirectory_ids\x18\x01 \x03(\tR\x0c\x64irectoryIds\x12*\n\x08\x66_groups\x18\x02 \x03(\x0b\x32\x0f.admin.v1.GroupR\x07\x66Groups\x12\x37\n\x08\x64_groups\x18\x03 \x03(\x0b\x32\x1c.admin.v1.DirectorySyncGroupR\x07\x64Groups\x12\x34\n\x0bgroup_pairs\x18\x04 \x03(\x0b\x32\x13.admin.v1.GroupPairR\ngroupPairs\x12Y\n\rd_group_users\x18\x05 \x03(\x0b\x32\x35.admin.v1.GetDirectoryGroupsResponse.DGroupUsersEntryR\x0b\x64GroupUsers\x1aO\n\x10\x44GroupUsersEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12%\n\x05value\x18\x02 \x01(\x0b\x32\x0f.admin.v1.UsersR\x05value:\x02\x38\x01\"\x95\x02\n\x1fUpdateDirectoryGroupSyncRequest\x12\x1c\n\nf_group_id\x18\x01 \x01(\tR\x08\x66GroupId\x12\x1c\n\nd_group_id\x18\x02 \x01(\tR\x08\x64GroupId\x12p\n\x13\x64\x65selected_user_ids\x18\x03 \x03(\x0b\x32@.admin.v1.UpdateDirectoryGroupSyncRequest.DeselectedUserIdsEntryR\x11\x64\x65selectedUserIds\x1a\x44\n\x16\x44\x65selectedUserIdsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x08R\x05value:\x02\x38\x01\"@\n UpdateDirectoryGroupSyncResponse\x12\x1c\n\nf_group_id\x18\x01 \x01(\tR\x08\x66GroupId\"6\n\x15GetDSyncPortalRequest\x12\x1d\n\nauth_token\x18\x01 \x01(\tR\tauthToken\",\n\x16GetDSyncPortalResponse\x12\x12\n\x04link\x18\x01 \x01(\tR\x04link2\xbe\x05\n\x0c\x44SyncService\x12M\n\x0cGetDirectory\x12\x1d.admin.v1.GetDirectoryRequest\x1a\x1e.admin.v1.GetDirectoryResponse\x12k\n\x16GetGroupsByDirectoryId\x12\'.admin.v1.GetGroupsByDirectoryIdRequest\x1a(.admin.v1.GetGroupsByDirectoryIdResponse\x12h\n\x15GetUsersByDirectoryId\x12&.admin.v1.GetUsersByDirectoryIdRequest\x1a\'.admin.v1.GetUsersByDirectoryIdResponse\x12_\n\x12GetWorkOsGroupById\x12#.admin.v1.GetWorkOsGroupByIdRequest\x1a$.admin.v1.GetWorkOsGroupByIdResponse\x12_\n\x12GetDirectoryGroups\x12#.admin.v1.GetDirectoryGroupsRequest\x1a$.admin.v1.GetDirectoryGroupsResponse\x12q\n\x18UpdateDirectoryGroupSync\x12).admin.v1.UpdateDirectoryGroupSyncRequest\x1a*.admin.v1.UpdateDirectoryGroupSyncResponse\x12S\n\x0eGetDSyncPortal\x12\x1f.admin.v1.GetDSyncPortalRequest\x1a .admin.v1.GetDSyncPortalResponseB\xa6\x01\n\x0c\x63om.admin.v1B\x0bWorkOsProtoP\x01ZHgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1;adminv1\xa2\x02\x03\x41XX\xaa\x02\x08\x41\x64min.V1\xca\x02\x08\x41\x64min\\V1\xe2\x02\x14\x41\x64min\\V1\\GPBMetadata\xea\x02\tAdmin::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.work_os_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\014com.admin.v1B\013WorkOsProtoP\001ZHgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1;adminv1\242\002\003AXX\252\002\010Admin.V1\312\002\010Admin\\V1\342\002\024Admin\\V1\\GPBMetadata\352\002\tAdmin::V1'
  _globals['_GETDIRECTORYGROUPSRESPONSE_DGROUPUSERSENTRY']._options = None
  _globals['_GETDIRECTORYGROUPSRESPONSE_DGROUPUSERSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATEDIRECTORYGROUPSYNCREQUEST_DESELECTEDUSERIDSENTRY']._options = None
  _globals['_UPDATEDIRECTORYGROUPSYNCREQUEST_DESELECTEDUSERIDSENTRY']._serialized_options = b'8\001'
  _globals['_GETDIRECTORYREQUEST']._serialized_start=69
  _globals['_GETDIRECTORYREQUEST']._serialized_end=90
  _globals['_GETDIRECTORYRESPONSE']._serialized_start=92
  _globals['_GETDIRECTORYRESPONSE']._serialized_end=165
  _globals['_DIRECTORY']._serialized_start=168
  _globals['_DIRECTORY']._serialized_end=335
  _globals['_GETGROUPSBYDIRECTORYIDREQUEST']._serialized_start=337
  _globals['_GETGROUPSBYDIRECTORYIDREQUEST']._serialized_end=384
  _globals['_GETGROUPSBYDIRECTORYIDRESPONSE']._serialized_start=386
  _globals['_GETGROUPSBYDIRECTORYIDRESPONSE']._serialized_end=472
  _globals['_GETUSERSBYDIRECTORYIDREQUEST']._serialized_start=474
  _globals['_GETUSERSBYDIRECTORYIDREQUEST']._serialized_end=520
  _globals['_GETUSERSBYDIRECTORYIDRESPONSE']._serialized_start=522
  _globals['_GETUSERSBYDIRECTORYIDRESPONSE']._serialized_end=595
  _globals['_GETWORKOSGROUPBYIDREQUEST']._serialized_start=597
  _globals['_GETWORKOSGROUPBYIDREQUEST']._serialized_end=640
  _globals['_GETWORKOSGROUPBYIDRESPONSE']._serialized_start=642
  _globals['_GETWORKOSGROUPBYIDRESPONSE']._serialized_end=722
  _globals['_DIRECTORYSYNCGROUP']._serialized_start=725
  _globals['_DIRECTORYSYNCGROUP']._serialized_end=954
  _globals['_USEREMAIL']._serialized_start=956
  _globals['_USEREMAIL']._serialized_end=1035
  _globals['_USERGROUP']._serialized_start=1037
  _globals['_USERGROUP']._serialized_end=1108
  _globals['_WORKUSER']._serialized_start=1111
  _globals['_WORKUSER']._serialized_end=1441
  _globals['_USERS']._serialized_start=1443
  _globals['_USERS']._serialized_end=1492
  _globals['_GROUP']._serialized_start=1495
  _globals['_GROUP']._serialized_end=1744
  _globals['_GROUPPAIR']._serialized_start=1746
  _globals['_GROUPPAIR']._serialized_end=1854
  _globals['_GETDIRECTORYGROUPSREQUEST']._serialized_start=1856
  _globals['_GETDIRECTORYGROUPSREQUEST']._serialized_end=1883
  _globals['_GETDIRECTORYGROUPSRESPONSE']._serialized_start=1886
  _globals['_GETDIRECTORYGROUPSRESPONSE']._serialized_end=2278
  _globals['_GETDIRECTORYGROUPSRESPONSE_DGROUPUSERSENTRY']._serialized_start=2199
  _globals['_GETDIRECTORYGROUPSRESPONSE_DGROUPUSERSENTRY']._serialized_end=2278
  _globals['_UPDATEDIRECTORYGROUPSYNCREQUEST']._serialized_start=2281
  _globals['_UPDATEDIRECTORYGROUPSYNCREQUEST']._serialized_end=2558
  _globals['_UPDATEDIRECTORYGROUPSYNCREQUEST_DESELECTEDUSERIDSENTRY']._serialized_start=2490
  _globals['_UPDATEDIRECTORYGROUPSYNCREQUEST_DESELECTEDUSERIDSENTRY']._serialized_end=2558
  _globals['_UPDATEDIRECTORYGROUPSYNCRESPONSE']._serialized_start=2560
  _globals['_UPDATEDIRECTORYGROUPSYNCRESPONSE']._serialized_end=2624
  _globals['_GETDSYNCPORTALREQUEST']._serialized_start=2626
  _globals['_GETDSYNCPORTALREQUEST']._serialized_end=2680
  _globals['_GETDSYNCPORTALRESPONSE']._serialized_start=2682
  _globals['_GETDSYNCPORTALRESPONSE']._serialized_end=2726
  _globals['_DSYNCSERVICE']._serialized_start=2729
  _globals['_DSYNCSERVICE']._serialized_end=3431
# @@protoc_insertion_point(module_scope)
