# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: admin/v1/types/v1/log.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import column_pb2 as admin_dot_v1_dot_types_dot_v1_dot_column__pb2
from . import domain_pb2 as admin_dot_v1_dot_types_dot_v1_dot_domain__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x61\x64min/v1/types/v1/log.proto\x12\x11\x61\x64min.v1.types.v1\x1a\x1e\x61\x64min/v1/types/v1/column.proto\x1a\x1e\x61\x64min/v1/types/v1/domain.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/duration.proto\"\x84\x02\n\x0fTriggeredPolicy\x12\x1b\n\tpolicy_id\x18\x01 \x01(\tR\x08policyId\x12\x16\n\x06owners\x18\x02 \x03(\tR\x06owners\x12\x16\n\x06notify\x18\x03 \x01(\tR\x06notify\x12>\n\x0bpolicy_type\x18\x04 \x01(\x0e\x32\x1d.admin.v1.types.v1.PolicyTypeR\npolicyType\x12\x16\n\x06reason\x18\x05 \x01(\tR\x06reason\x12\'\n\x0f\x63ontextual_data\x18\x06 \x01(\tR\x0e\x63ontextualData\x12#\n\rpolicy_status\x18\x07 \x01(\tR\x0cpolicyStatus\"_\n\x15TriggeredFilterPolicy\x12\x1a\n\x08interval\x18\x01 \x01(\tR\x08interval\x12\x14\n\x05limit\x18\x02 \x01(\x03R\x05limit\x12\x14\n\x05\x63ount\x18\x03 \x01(\x03R\x05\x63ount\"<\n\x19TriggeredDecryptionPolicy\x12\x1f\n\x0b\x63olumn_path\x18\x01 \x01(\tR\ncolumnPath\"x\n\x16TriggeredMaskingPolicy\x12\x1f\n\x0b\x63olumn_path\x18\x01 \x01(\tR\ncolumnPath\x12!\n\x0cmasking_type\x18\x02 \x01(\tR\x0bmaskingType\x12\x1a\n\x08typesafe\x18\x03 \x01(\x08R\x08typesafe\"\xdf\x01\n\x14TriggeredBlockPolicy\x12\x1f\n\x0bobject_type\x18\x01 \x01(\tR\nobjectType\x12\x12\n\x04path\x18\x02 \x01(\tR\x04path\x12!\n\x0cobject_paths\x18\x03 \x03(\tR\x0bobjectPaths\x12\x1a\n\x08multiple\x18\x04 \x01(\x08R\x08multiple\x12\x16\n\x06\x61\x63tion\x18\x05 \x01(\tR\x06\x61\x63tion\x12;\n\x1a\x64\x61tastore_is_default_block\x18\x06 \x01(\x08R\x17\x64\x61tastoreIsDefaultBlock\"J\n\x13TiggeredAllowPolicy\x12\x1f\n\x0bobject_type\x18\x01 \x01(\tR\nobjectType\x12\x12\n\x04path\x18\x02 \x01(\tR\x04path\"\xda\x10\n\nLogRequest\x12\x39\n\nstart_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tstartTime\x12\x35\n\x08\x65nd_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x07\x65ndTime\x12Q\n\x17sidecar_processing_time\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationR\x15sidecarProcessingTime\x12M\n\x15\x64\x61ta_store_start_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x12\x64\x61taStoreStartTime\x12I\n\x13\x64\x61ta_store_end_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x10\x64\x61taStoreEndTime\x12V\n\x1a\x64\x61ta_store_processing_time\x18\x06 \x01(\x0b\x32\x19.google.protobuf.DurationR\x17\x64\x61taStoreProcessingTime\x12\x14\n\x05query\x18\x07 \x01(\tR\x05query\x12\x18\n\x07success\x18\x08 \x01(\x08R\x07success\x12#\n\rerror_message\x18\t \x01(\tR\x0c\x65rrorMessage\x12!\n\x0cstament_type\x18\n \x01(\tR\x0bstamentType\x12\'\n\x0freturned_tables\x18\x0b \x03(\tR\x0ereturnedTables\x12\x44\n\x10returned_columns\x18\x0c \x03(\x0b\x32\x19.admin.v1.types.v1.ColumnR\x0freturnedColumns\x12\x1f\n\x0b\x64\x61ta_volume\x18\r \x01(\x04R\ndataVolume\x12\x1e\n\x0b\x65nd_user_id\x18\x0e \x01(\tR\tendUserId\x12\x30\n\x15\x65nd_user_db_user_name\x18\x0f \x01(\tR\x11\x65ndUserDbUserName\x12\x31\n\x15\x65nd_user_external_ids\x18\x10 \x03(\tR\x12\x65ndUserExternalIds\x12#\n\rpolicy_action\x18\x11 \x01(\tR\x0cpolicyAction\x12.\n\x13returned_rows_count\x18\x12 \x01(\x03R\x11returnedRowsCount\x12@\n\x1dreturned_rows_count_by_server\x18\x13 \x01(\x03R\x19returnedRowsCountByServer\x12<\n\x1breturned_rows_count_to_user\x18\x14 \x01(\x03R\x17returnedRowsCountToUser\x12.\n\x13\x66iltered_rows_count\x18\x15 \x01(\x03R\x11\x66ilteredRowsCount\x12Q\n\x12triggered_policies\x18\x16 \x03(\x0b\x32\".admin.v1.types.v1.TriggeredPolicyR\x11triggeredPolicies\x12\x1b\n\ttenant_id\x18\x17 \x01(\tR\x08tenantId\x12M\n\x11row_level_metrics\x18\x18 \x03(\x0b\x32!.admin.v1.types.v1.RowLevelMetricR\x0frowLevelMetrics\x12\x31\n\x15tenant_id_column_name\x18\x19 \x01(\tR\x12tenantIdColumnName\x12\'\n\x0ftenant_mismatch\x18\x1a \x03(\tR\x0etenantMismatch\x12\x1f\n\x0b\x62ucket_name\x18\x1b \x01(\tR\nbucketName\x12\x1b\n\ts3_action\x18\x1c \x01(\tR\x08s3Action\x12\x46\n\x10returned_objects\x18\x1d \x03(\x0b\x32\x1b.admin.v1.types.v1.S3ObjectR\x0freturnedObjects\x12\x35\n\x17ssh_aws_connection_type\x18\x1e \x01(\tR\x14sshAwsConnectionType\x12\x1e\n\x0bssh_aws_arn\x18\x1f \x01(\tR\tsshAwsArn\x12&\n\x0f\x65nd_user_groups\x18  \x03(\tR\rendUserGroups\x12\x1f\n\x0buser_groups\x18! \x03(\tR\nuserGroups\x12\x16\n\x06groups\x18\" \x03(\tR\x06groups\x12 \n\x0b\x66ingerprint\x18# \x01(\tR\x0b\x66ingerprint\x12<\n\x0c\x64\x61ta_domains\x18$ \x03(\x0b\x32\x19.admin.v1.types.v1.DomainR\x0b\x64\x61taDomains\x12!\n\x0crequest_body\x18% \x01(\tR\x0brequestBody\x12#\n\rresponse_body\x18& \x01(\tR\x0cresponseBody\x12\x34\n\x16request_body_encrypted\x18\' \x01(\x08R\x14requestBodyEncrypted\x12\x36\n\x17response_body_encrypted\x18( \x01(\x08R\x15responseBodyEncrypted\x12H\n!request_body_post_policies_action\x18) \x01(\tR\x1drequestBodyPostPoliciesAction\x12J\n\"response_body_post_policies_action\x18* \x01(\tR\x1eresponseBodyPostPoliciesAction\"\xee\x08\n\x07Session\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x1d\n\nstart_time\x18\x02 \x01(\x03R\tstartTime\x12!\n\x0c\x64\x61tastore_id\x18\x03 \x01(\tR\x0b\x64\x61tastoreId\x12%\n\x0e\x64\x61tastore_name\x18\x04 \x01(\tR\rdatastoreName\x12\x31\n\x14\x64\x61tastore_technology\x18\x05 \x01(\tR\x13\x64\x61tastoreTechnology\x12:\n\x19\x64\x61tastore_deployment_type\x18\x06 \x01(\tR\x17\x64\x61tastoreDeploymentType\x12*\n\x11server_ip_address\x18\x07 \x01(\tR\x0fserverIpAddress\x12*\n\x11\x63lient_ip_address\x18\x08 \x01(\tR\x0f\x63lientIpAddress\x12\x17\n\x07user_id\x18\t \x01(\tR\x06userId\x12\x1b\n\tuser_type\x18\n \x01(\tR\x08userType\x12\x17\n\x07\x64\x62_user\x18\x0b \x01(\tR\x06\x64\x62User\x12\x17\n\x07\x64\x62_name\x18\x0c \x01(\tR\x06\x64\x62Name\x12)\n\x10\x61pplication_name\x18\r \x01(\tR\x0f\x61pplicationName\x12\x18\n\x07schemas\x18\x0e \x03(\tR\x07schemas\x12$\n\x0enative_role_id\x18\x0f \x01(\tR\x0cnativeRoleId\x12\x34\n\x16native_role_assignment\x18\x10 \x01(\tR\x14nativeRoleAssignment\x12\x1d\n\nsidecar_id\x18\x11 \x01(\tR\tsidecarId\x12!\n\x0csidecar_name\x18\x12 \x01(\tR\x0bsidecarName\x12-\n\x12sidecar_technology\x18\x13 \x01(\tR\x11sidecarTechnology\x12$\n\x0e\x61ws_account_id\x18\x14 \x01(\tR\x0c\x61wsAccountId\x12\x1d\n\naws_region\x18\x15 \x01(\tR\tawsRegion\x12-\n\x13\x61ws_ec2_instance_id\x18\x16 \x01(\tR\x10\x61wsEc2InstanceId\x12/\n\x14\x61ws_ecs_cluster_name\x18\x17 \x01(\tR\x11\x61wsEcsClusterName\x12-\n\x13\x61ws_ecs_cluster_arn\x18\x18 \x01(\tR\x10\x61wsEcsClusterArn\x12/\n\x14\x61ws_ecs_service_name\x18\x19 \x01(\tR\x11\x61wsEcsServiceName\x12-\n\x13\x61ws_ecs_service_arn\x18\x1a \x01(\tR\x10\x61wsEcsServiceArn\x12%\n\x0f\x61ws_ecs_task_id\x18\x1b \x01(\tR\x0c\x61wsEcsTaskId\x12\'\n\x10\x61ws_ecs_task_arn\x18\x1c \x01(\tR\rawsEcsTaskArn\x12%\n\x0e\x63ontainer_name\x18\x1d \x01(\tR\rcontainerName\"\x9c\x02\n\tFormalLog\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12!\n\x0c\x64\x61tastore_id\x18\x02 \x01(\tR\x0b\x64\x61tastoreId\x12\x34\n\x07session\x18\x03 \x01(\x0b\x32\x1a.admin.v1.types.v1.SessionR\x07session\x12\x37\n\x07request\x18\x04 \x01(\x0b\x32\x1d.admin.v1.types.v1.LogRequestR\x07request\x12\x1d\n\ncreated_at\x18\x05 \x01(\tR\tcreatedAt\x12\x38\n\ttimestamp\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x12\x14\n\x05total\x18\x07 \x01(\x03R\x05total\"\x85\x01\n\x0fTenantLogsInfra\x12\x10\n\x03uri\x18\x01 \x01(\tR\x03uri\x12\x1a\n\x08password\x18\x02 \x01(\tR\x08password\x12\x1a\n\x08username\x18\x03 \x01(\tR\x08username\x12(\n\x10metrics_role_pwd\x18\x04 \x01(\tR\x0emetricsRolePwd\"C\n\x0cLogStorageS3\x12\x33\n\x16s3_firehose_stream_arn\x18\x01 \x01(\tR\x13s3FirehoseStreamArn\"b\n\x12\x43svOrParquetColumn\x12\x1b\n\tcol_index\x18\x01 \x01(\x05R\x08\x63olIndex\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x1b\n\tdata_type\x18\x03 \x01(\tR\x08\x64\x61taType\"\xa3\x01\n\x05Image\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x1f\n\x0b\x66\x61\x63\x65s_count\x18\x02 \x01(\x05R\nfacesCount\x12\x14\n\x05width\x18\x03 \x01(\x05R\x05width\x12\x16\n\x06height\x18\x04 \x01(\x05R\x06height\x12\x12\n\x04type\x18\x05 \x01(\tR\x04type\x12#\n\rpolicy_action\x18\x06 \x01(\tR\x0cpolicyAction\"\xd9\x01\n\x08S3Object\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12!\n\x0c\x63ontent_type\x18\x02 \x01(\tR\x0b\x63ontentType\x12%\n\x0e\x63ontent_length\x18\x03 \x01(\x03R\rcontentLength\x12?\n\x07\x63olumns\x18\x04 \x03(\x0b\x32%.admin.v1.types.v1.CsvOrParquetColumnR\x07\x63olumns\x12.\n\x05image\x18\x05 \x01(\x0b\x32\x18.admin.v1.types.v1.ImageR\x05image\"\xe2\x04\n\x0eRowLevelMetric\x12!\n\x0c\x64\x61tastore_id\x18\x01 \x01(\tR\x0b\x64\x61tastoreId\x12%\n\x0e\x64\x61tastore_name\x18\x02 \x01(\tR\rdatastoreName\x12\x1e\n\x0b\x65nd_user_id\x18\x03 \x01(\tR\tendUserId\x12/\n\x14\x65nd_user_db_username\x18\x04 \x01(\tR\x11\x65ndUserDbUsername\x12\x17\n\x07user_id\x18\x05 \x01(\tR\x06userId\x12\x17\n\x07\x64\x62_user\x18\x06 \x01(\tR\x06\x64\x62User\x12\x17\n\x07\x64\x62_name\x18\x07 \x01(\tR\x06\x64\x62Name\x12\x1f\n\x0bschema_name\x18\x08 \x01(\tR\nschemaName\x12\x1d\n\ntable_name\x18\t \x01(\tR\ttableName\x12\x12\n\x04path\x18\n \x01(\tR\x04path\x12\x33\n\x16hashed_row_level_value\x18\x0b \x01(\tR\x13hashedRowLevelValue\x12:\n\x1a\x63lear_text_row_level_value\x18\x0c \x01(\tR\x16\x63learTextRowLevelValue\x12*\n\x02ts\x18\r \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x02ts\x12\x18\n\x07\x63ounter\x18\x0e \x01(\x03R\x07\x63ounter\x12#\n\rreturned_rows\x18\x0f \x01(\x03R\x0creturnedRows\x12:\n\ntimebucket\x18\x10 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ntimebucket*\xc7\x01\n\nPolicyType\x12\x1b\n\x17POLICY_TYPE_UNSPECIFIED\x10\x00\x12\x1d\n\x19POLICY_TYPE_FILTER_POLICY\x10\x01\x12!\n\x1dPOLICY_TYPE_DECRYPTION_POLICY\x10\x02\x12\x1e\n\x1aPOLICY_TYPE_MASKING_POLICY\x10\x03\x12\x1c\n\x18POLICY_TYPE_BLOCK_POLICY\x10\x04\x12\x1c\n\x18POLICY_TYPE_ALLOW_POLICY\x10\x05\x42\xdb\x01\n\x15\x63om.admin.v1.types.v1B\x08LogProtoP\x01ZQgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1/types/v1;typesv1\xa2\x02\x03\x41VT\xaa\x02\x11\x41\x64min.V1.Types.V1\xca\x02\x11\x41\x64min\\V1\\Types\\V1\xe2\x02\x1d\x41\x64min\\V1\\Types\\V1\\GPBMetadata\xea\x02\x14\x41\x64min::V1::Types::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.types.v1.log_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.admin.v1.types.v1B\010LogProtoP\001ZQgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1/types/v1;typesv1\242\002\003AVT\252\002\021Admin.V1.Types.V1\312\002\021Admin\\V1\\Types\\V1\342\002\035Admin\\V1\\Types\\V1\\GPBMetadata\352\002\024Admin::V1::Types::V1'
  _globals['_POLICYTYPE']._serialized_start=5895
  _globals['_POLICYTYPE']._serialized_end=6094
  _globals['_TRIGGEREDPOLICY']._serialized_start=180
  _globals['_TRIGGEREDPOLICY']._serialized_end=440
  _globals['_TRIGGEREDFILTERPOLICY']._serialized_start=442
  _globals['_TRIGGEREDFILTERPOLICY']._serialized_end=537
  _globals['_TRIGGEREDDECRYPTIONPOLICY']._serialized_start=539
  _globals['_TRIGGEREDDECRYPTIONPOLICY']._serialized_end=599
  _globals['_TRIGGEREDMASKINGPOLICY']._serialized_start=601
  _globals['_TRIGGEREDMASKINGPOLICY']._serialized_end=721
  _globals['_TRIGGEREDBLOCKPOLICY']._serialized_start=724
  _globals['_TRIGGEREDBLOCKPOLICY']._serialized_end=947
  _globals['_TIGGEREDALLOWPOLICY']._serialized_start=949
  _globals['_TIGGEREDALLOWPOLICY']._serialized_end=1023
  _globals['_LOGREQUEST']._serialized_start=1026
  _globals['_LOGREQUEST']._serialized_end=3164
  _globals['_SESSION']._serialized_start=3167
  _globals['_SESSION']._serialized_end=4301
  _globals['_FORMALLOG']._serialized_start=4304
  _globals['_FORMALLOG']._serialized_end=4588
  _globals['_TENANTLOGSINFRA']._serialized_start=4591
  _globals['_TENANTLOGSINFRA']._serialized_end=4724
  _globals['_LOGSTORAGES3']._serialized_start=4726
  _globals['_LOGSTORAGES3']._serialized_end=4793
  _globals['_CSVORPARQUETCOLUMN']._serialized_start=4795
  _globals['_CSVORPARQUETCOLUMN']._serialized_end=4893
  _globals['_IMAGE']._serialized_start=4896
  _globals['_IMAGE']._serialized_end=5059
  _globals['_S3OBJECT']._serialized_start=5062
  _globals['_S3OBJECT']._serialized_end=5279
  _globals['_ROWLEVELMETRIC']._serialized_start=5282
  _globals['_ROWLEVELMETRIC']._serialized_end=5892
# @@protoc_insertion_point(module_scope)
