# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: admin/v1/integration_github.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!admin/v1/integration_github.proto\x12\x08\x61\x64min.v1\"B\n\x17InstallGithubAppRequest\x12\'\n\x0finstallation_id\x18\x01 \x01(\tR\x0einstallationId\"\x1a\n\x18InstallGithubAppResponse\"\x1b\n\x19GetGithubAppForOrgRequest\"6\n\x1aGetGithubAppForOrgResponse\x12\x18\n\x07message\x18\x01 \x01(\tR\x07message2\xcb\x01\n\rGithubService\x12Y\n\x10InstallGithubApp\x12!.admin.v1.InstallGithubAppRequest\x1a\".admin.v1.InstallGithubAppResponse\x12_\n\x12GetGithubAppForOrg\x12#.admin.v1.GetGithubAppForOrgRequest\x1a$.admin.v1.GetGithubAppForOrgResponseB\xb1\x01\n\x0c\x63om.admin.v1B\x16IntegrationGithubProtoP\x01ZHgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1;adminv1\xa2\x02\x03\x41XX\xaa\x02\x08\x41\x64min.V1\xca\x02\x08\x41\x64min\\V1\xe2\x02\x14\x41\x64min\\V1\\GPBMetadata\xea\x02\tAdmin::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.integration_github_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\014com.admin.v1B\026IntegrationGithubProtoP\001ZHgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1;adminv1\242\002\003AXX\252\002\010Admin.V1\312\002\010Admin\\V1\342\002\024Admin\\V1\\GPBMetadata\352\002\tAdmin::V1'
  _globals['_INSTALLGITHUBAPPREQUEST']._serialized_start=47
  _globals['_INSTALLGITHUBAPPREQUEST']._serialized_end=113
  _globals['_INSTALLGITHUBAPPRESPONSE']._serialized_start=115
  _globals['_INSTALLGITHUBAPPRESPONSE']._serialized_end=141
  _globals['_GETGITHUBAPPFORORGREQUEST']._serialized_start=143
  _globals['_GETGITHUBAPPFORORGREQUEST']._serialized_end=170
  _globals['_GETGITHUBAPPFORORGRESPONSE']._serialized_start=172
  _globals['_GETGITHUBAPPFORORGRESPONSE']._serialized_end=226
  _globals['_GITHUBSERVICE']._serialized_start=229
  _globals['_GITHUBSERVICE']._serialized_end=432
# @@protoc_insertion_point(module_scope)
