# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: admin/v1/integration_slack.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n admin/v1/integration_slack.proto\x12\x08\x61\x64min.v1\"V\n\x1d\x43reateSlackIntegrationRequest\x12\x12\n\x04\x63ode\x18\x01 \x01(\tR\x04\x63ode\x12!\n\x0credirect_uri\x18\x02 \x01(\tR\x0bredirectUri\" \n\x1e\x43reateSlackIntegrationResponse\"\x1c\n\x1aGetSlackIntegrationRequest\"\xe2\x01\n\x1bGetSlackIntegrationResponse\x12\x17\n\x07team_id\x18\x01 \x01(\tR\x06teamId\x12\x1b\n\tteam_name\x18\x02 \x01(\tR\x08teamName\x12\x1e\n\x0b\x62ot_user_id\x18\x03 \x01(\tR\tbotUserId\x12(\n\x10\x62ot_access_token\x18\x04 \x01(\tR\x0e\x62otAccessToken\x12$\n\x0e\x61uthed_user_id\x18\x05 \x01(\tR\x0c\x61uthedUserId\x12\x1d\n\nchannel_id\x18\x06 \x01(\tR\tchannelId2\xdf\x01\n\x0cSlackService\x12k\n\x16\x43reateSlackIntegration\x12\'.admin.v1.CreateSlackIntegrationRequest\x1a(.admin.v1.CreateSlackIntegrationResponse\x12\x62\n\x13GetSlackIntegration\x12$.admin.v1.GetSlackIntegrationRequest\x1a%.admin.v1.GetSlackIntegrationResponseB\xb0\x01\n\x0c\x63om.admin.v1B\x15IntegrationSlackProtoP\x01ZHgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1;adminv1\xa2\x02\x03\x41XX\xaa\x02\x08\x41\x64min.V1\xca\x02\x08\x41\x64min\\V1\xe2\x02\x14\x41\x64min\\V1\\GPBMetadata\xea\x02\tAdmin::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.integration_slack_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\014com.admin.v1B\025IntegrationSlackProtoP\001ZHgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1;adminv1\242\002\003AXX\252\002\010Admin.V1\312\002\010Admin\\V1\342\002\024Admin\\V1\\GPBMetadata\352\002\tAdmin::V1'
  _globals['_CREATESLACKINTEGRATIONREQUEST']._serialized_start=46
  _globals['_CREATESLACKINTEGRATIONREQUEST']._serialized_end=132
  _globals['_CREATESLACKINTEGRATIONRESPONSE']._serialized_start=134
  _globals['_CREATESLACKINTEGRATIONRESPONSE']._serialized_end=166
  _globals['_GETSLACKINTEGRATIONREQUEST']._serialized_start=168
  _globals['_GETSLACKINTEGRATIONREQUEST']._serialized_end=196
  _globals['_GETSLACKINTEGRATIONRESPONSE']._serialized_start=199
  _globals['_GETSLACKINTEGRATIONRESPONSE']._serialized_end=425
  _globals['_SLACKSERVICE']._serialized_start=428
  _globals['_SLACKSERVICE']._serialized_end=651
# @@protoc_insertion_point(module_scope)
