# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: admin/v1/integration_log.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .types.v1 import integration_log_pb2 as admin_dot_v1_dot_types_dot_v1_dot_integration__log__pb2
from .types.v1 import log_link_pb2 as admin_dot_v1_dot_types_dot_v1_dot_log__link__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x61\x64min/v1/integration_log.proto\x12\x08\x61\x64min.v1\x1a\'admin/v1/types/v1/integration_log.proto\x1a admin/v1/types/v1/log_link.proto\"\xe6\x01\n\x1c\x43reateIntegrationLogsRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x12\n\x04type\x18\x02 \x01(\tR\x04type\x12\x17\n\x07\x64\x64_site\x18\x03 \x01(\tR\x06\x64\x64Site\x12\x1c\n\ndd_api_key\x18\x04 \x01(\tR\x08\x64\x64\x41piKey\x12\"\n\rdd_account_id\x18\x05 \x01(\tR\x0b\x64\x64\x41\x63\x63ountId\x12\x1d\n\nsplunk_url\x18\x06 \x01(\tR\tsplunkUrl\x12$\n\x0esplunk_api_key\x18\x07 \x01(\tR\x0csplunkApiKey\"e\n\x1d\x43reateIntegrationLogsResponse\x12\x44\n\x0bintegration\x18\x01 \x01(\x0b\x32\".admin.v1.types.v1.IntegrationLogsR\x0bintegration\"\x1b\n\x19GetIntegrationLogsRequest\"d\n\x1aGetIntegrationLogsResponse\x12\x46\n\x0cintegrations\x18\x01 \x03(\x0b\x32\".admin.v1.types.v1.IntegrationLogsR\x0cintegrations\".\n\x1cGetIntegrationLogByIdRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"e\n\x1dGetIntegrationLogByIdResponse\x12\x44\n\x0bintegration\x18\x01 \x01(\x0b\x32\".admin.v1.types.v1.IntegrationLogsR\x0bintegration\".\n\x1c\x44\x65leteIntegrationLogsRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"\x1f\n\x1d\x44\x65leteIntegrationLogsResponse\"e\n\x19\x43reateLogsLinkItemRequest\x12%\n\x0eintegration_id\x18\x01 \x01(\tR\rintegrationId\x12!\n\x0c\x64\x61tastore_id\x18\x02 \x01(\tR\x0b\x64\x61tastoreId\"`\n\x1a\x43reateLogsLinkItemResponse\x12\x42\n\rlog_item_link\x18\x01 \x01(\x0b\x32\x1e.admin.v1.types.v1.LogLinkItemR\x0blogItemLink\",\n\x1aGetLogsLinkItemByIdRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"c\n\x1bGetLogsLinkItemByIdResponse\x12\x44\n\x0elog_item_links\x18\x01 \x01(\x0b\x32\x1e.admin.v1.types.v1.LogLinkItemR\x0clogItemLinks\"+\n\x19\x44\x65leteLogsLinkItemRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"\x1c\n\x1a\x44\x65leteLogsLinkItemResponse2\xd2\x05\n\x0bLogsService\x12h\n\x15\x43reateIntegrationLogs\x12&.admin.v1.CreateIntegrationLogsRequest\x1a\'.admin.v1.CreateIntegrationLogsResponse\x12_\n\x12GetIntegrationLogs\x12#.admin.v1.GetIntegrationLogsRequest\x1a$.admin.v1.GetIntegrationLogsResponse\x12h\n\x15GetIntegrationLogById\x12&.admin.v1.GetIntegrationLogByIdRequest\x1a\'.admin.v1.GetIntegrationLogByIdResponse\x12h\n\x15\x44\x65leteIntegrationLogs\x12&.admin.v1.DeleteIntegrationLogsRequest\x1a\'.admin.v1.DeleteIntegrationLogsResponse\x12_\n\x12\x43reateLogsLinkItem\x12#.admin.v1.CreateLogsLinkItemRequest\x1a$.admin.v1.CreateLogsLinkItemResponse\x12\x62\n\x13GetLogsLinkItemById\x12$.admin.v1.GetLogsLinkItemByIdRequest\x1a%.admin.v1.GetLogsLinkItemByIdResponse\x12_\n\x12\x44\x65leteLogsLinkItem\x12#.admin.v1.DeleteLogsLinkItemRequest\x1a$.admin.v1.DeleteLogsLinkItemResponseB\xae\x01\n\x0c\x63om.admin.v1B\x13IntegrationLogProtoP\x01ZHgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1;adminv1\xa2\x02\x03\x41XX\xaa\x02\x08\x41\x64min.V1\xca\x02\x08\x41\x64min\\V1\xe2\x02\x14\x41\x64min\\V1\\GPBMetadata\xea\x02\tAdmin::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.integration_log_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\014com.admin.v1B\023IntegrationLogProtoP\001ZHgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1;adminv1\242\002\003AXX\252\002\010Admin.V1\312\002\010Admin\\V1\342\002\024Admin\\V1\\GPBMetadata\352\002\tAdmin::V1'
  _globals['_CREATEINTEGRATIONLOGSREQUEST']._serialized_start=120
  _globals['_CREATEINTEGRATIONLOGSREQUEST']._serialized_end=350
  _globals['_CREATEINTEGRATIONLOGSRESPONSE']._serialized_start=352
  _globals['_CREATEINTEGRATIONLOGSRESPONSE']._serialized_end=453
  _globals['_GETINTEGRATIONLOGSREQUEST']._serialized_start=455
  _globals['_GETINTEGRATIONLOGSREQUEST']._serialized_end=482
  _globals['_GETINTEGRATIONLOGSRESPONSE']._serialized_start=484
  _globals['_GETINTEGRATIONLOGSRESPONSE']._serialized_end=584
  _globals['_GETINTEGRATIONLOGBYIDREQUEST']._serialized_start=586
  _globals['_GETINTEGRATIONLOGBYIDREQUEST']._serialized_end=632
  _globals['_GETINTEGRATIONLOGBYIDRESPONSE']._serialized_start=634
  _globals['_GETINTEGRATIONLOGBYIDRESPONSE']._serialized_end=735
  _globals['_DELETEINTEGRATIONLOGSREQUEST']._serialized_start=737
  _globals['_DELETEINTEGRATIONLOGSREQUEST']._serialized_end=783
  _globals['_DELETEINTEGRATIONLOGSRESPONSE']._serialized_start=785
  _globals['_DELETEINTEGRATIONLOGSRESPONSE']._serialized_end=816
  _globals['_CREATELOGSLINKITEMREQUEST']._serialized_start=818
  _globals['_CREATELOGSLINKITEMREQUEST']._serialized_end=919
  _globals['_CREATELOGSLINKITEMRESPONSE']._serialized_start=921
  _globals['_CREATELOGSLINKITEMRESPONSE']._serialized_end=1017
  _globals['_GETLOGSLINKITEMBYIDREQUEST']._serialized_start=1019
  _globals['_GETLOGSLINKITEMBYIDREQUEST']._serialized_end=1063
  _globals['_GETLOGSLINKITEMBYIDRESPONSE']._serialized_start=1065
  _globals['_GETLOGSLINKITEMBYIDRESPONSE']._serialized_end=1164
  _globals['_DELETELOGSLINKITEMREQUEST']._serialized_start=1166
  _globals['_DELETELOGSLINKITEMREQUEST']._serialized_end=1209
  _globals['_DELETELOGSLINKITEMRESPONSE']._serialized_start=1211
  _globals['_DELETELOGSLINKITEMRESPONSE']._serialized_end=1239
  _globals['_LOGSSERVICE']._serialized_start=1242
  _globals['_LOGSSERVICE']._serialized_end=1964
# @@protoc_insertion_point(module_scope)
