# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: admin/v1/types/v1/search.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x61\x64min/v1/types/v1/search.proto\x12\x11\x61\x64min.v1.types.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xf5\x01\n\nSearchUser\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x1f\n\x0b\x64\x62_username\x18\x02 \x01(\tR\ndbUsername\x12\x39\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x16\n\x06\x61\x63tive\x18\x04 \x01(\x08R\x06\x61\x63tive\x12\x12\n\x04type\x18\x05 \x01(\tR\x04type\x12\x16\n\x06status\x18\x06 \x01(\tR\x06status\x12\x37\n\texpire_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x08\x65xpireAt\"\xbe\x01\n\x0bSearchGroup\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12\x16\n\x06status\x18\x04 \x01(\tR\x06status\x12\x39\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x16\n\x06\x61\x63tive\x18\x07 \x01(\x08R\x06\x61\x63tive\"\x99\x02\n\x0cSearchPolicy\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12\x16\n\x06status\x18\x04 \x01(\tR\x06status\x12\x1d\n\ncreated_by\x18\x05 \x01(\tR\tcreatedBy\x12\x39\n\ncreated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x39\n\nupdated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tupdatedAt\x12\x16\n\x06\x61\x63tive\x18\x08 \x01(\x08R\x06\x61\x63tive\"\xcf\x01\n\x0fSearchDatastore\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12!\n\x0c\x64\x61tastore_id\x18\x02 \x01(\tR\x0b\x64\x61tastoreId\x12\x12\n\x04name\x18\x03 \x01(\tR\x04name\x12\x1a\n\x08hostname\x18\x04 \x01(\tR\x08hostname\x12\x1e\n\ntechnology\x18\x05 \x01(\tR\ntechnology\x12\x39\n\ncreated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\"\xc7\x03\n\rSearchSidecar\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12!\n\x0c\x64\x61tastore_id\x18\x02 \x01(\tR\x0b\x64\x61tastoreId\x12\x12\n\x04name\x18\x03 \x01(\tR\x04name\x12\'\n\x0f\x66ormal_hostname\x18\x04 \x01(\tR\x0e\x66ormalHostname\x12%\n\x0e\x63loud_provider\x18\x05 \x01(\tR\rcloudProvider\x12!\n\x0c\x63loud_region\x18\x06 \x01(\tR\x0b\x63loudRegion\x12\'\n\x0f\x64\x65ployment_type\x18\x07 \x01(\tR\x0e\x64\x65ploymentType\x12\x1b\n\tfail_open\x18\x08 \x01(\x08R\x08\x66\x61ilOpen\x12\x1e\n\ntechnology\x18\t \x01(\tR\ntechnology\x12!\n\x0cproxy_status\x18\n \x01(\tR\x0bproxyStatus\x12\x38\n\x18server_connection_status\x18\x0b \x01(\tR\x16serverConnectionStatus\x12\x39\n\ncreated_at\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\"\xcd\x04\n\x0fSearchInventory\x12\x1d\n\ncreated_at\x18\x01 \x01(\x03R\tcreatedAt\x12\x1d\n\nupdated_at\x18\x02 \x01(\x03R\tupdatedAt\x12!\n\x0c\x64\x61tastore_id\x18\x03 \x01(\tR\x0b\x64\x61tastoreId\x12%\n\x0e\x64\x61tastore_name\x18\x04 \x01(\tR\rdatastoreName\x12\x12\n\x04path\x18\x05 \x01(\tR\x04path\x12*\n\x11table_physical_id\x18\x06 \x01(\tR\x0ftablePhysicalId\x12\x34\n\x16table_attribute_number\x18\x07 \x01(\x04R\x14tableAttributeNumber\x12\x12\n\x04name\x18\x08 \x01(\tR\x04name\x12\x14\n\x05\x61lias\x18\t \x01(\tR\x05\x61lias\x12\x1d\n\ntable_path\x18\n \x01(\tR\ttablePath\x12\x1d\n\ndata_label\x18\x0b \x01(\tR\tdataLabel\x12\x1b\n\tdata_type\x18\x0c \x01(\tR\x08\x64\x61taType\x12\"\n\rdata_type_oid\x18\r \x01(\rR\x0b\x64\x61taTypeOid\x12@\n\x1d\x64\x61ta_label_locked_for_sidecar\x18\x0e \x01(\x08R\x19\x64\x61taLabelLockedForSidecar\x12\x12\n\x04tags\x18\x0f \x03(\tR\x04tags\x12\x1c\n\tencrypted\x18\x10 \x01(\x08R\tencrypted\x12\x1f\n\x0b\x64\x61ta_labels\x18\x11 \x03(\tR\ndataLabelsB\xde\x01\n\x15\x63om.admin.v1.types.v1B\x0bSearchProtoP\x01ZQgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1/types/v1;typesv1\xa2\x02\x03\x41VT\xaa\x02\x11\x41\x64min.V1.Types.V1\xca\x02\x11\x41\x64min\\V1\\Types\\V1\xe2\x02\x1d\x41\x64min\\V1\\Types\\V1\\GPBMetadata\xea\x02\x14\x41\x64min::V1::Types::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.types.v1.search_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.admin.v1.types.v1B\013SearchProtoP\001ZQgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1/types/v1;typesv1\242\002\003AVT\252\002\021Admin.V1.Types.V1\312\002\021Admin\\V1\\Types\\V1\342\002\035Admin\\V1\\Types\\V1\\GPBMetadata\352\002\024Admin::V1::Types::V1'
  _globals['_SEARCHUSER']._serialized_start=87
  _globals['_SEARCHUSER']._serialized_end=332
  _globals['_SEARCHGROUP']._serialized_start=335
  _globals['_SEARCHGROUP']._serialized_end=525
  _globals['_SEARCHPOLICY']._serialized_start=528
  _globals['_SEARCHPOLICY']._serialized_end=809
  _globals['_SEARCHDATASTORE']._serialized_start=812
  _globals['_SEARCHDATASTORE']._serialized_end=1019
  _globals['_SEARCHSIDECAR']._serialized_start=1022
  _globals['_SEARCHSIDECAR']._serialized_end=1477
  _globals['_SEARCHINVENTORY']._serialized_start=1480
  _globals['_SEARCHINVENTORY']._serialized_end=2069
# @@protoc_insertion_point(module_scope)
