# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: admin/v1/types/v1/sidecar.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x61\x64min/v1/types/v1/sidecar.proto\x12\x11\x61\x64min.v1.types.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\x89\x06\n\x07Sidecar\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12(\n\x10\x63loud_account_id\x18\x03 \x01(\tR\x0e\x63loudAccountId\x12G\n\x0e\x63loud_provider\x18\x04 \x01(\x0e\x32 .admin.v1.types.v1.CloudProviderR\rcloudProvider\x12!\n\x0c\x63loud_region\x18\x05 \x01(\tR\x0b\x63loudRegion\x12\x1e\n\ntechnology\x18\x06 \x01(\tR\ntechnology\x12\'\n\x0f\x64\x65ployment_type\x18\x07 \x01(\tR\x0e\x64\x65ploymentType\x12!\n\x0cnetwork_type\x18\x08 \x01(\tR\x0bnetworkType\x12!\n\x0c\x64\x61taplane_id\x18\t \x01(\tR\x0b\x64\x61taplaneId\x12!\n\x0c\x64\x61tastore_id\x18\n \x01(\tR\x0b\x64\x61tastoreId\x12\x1a\n\x08\x64\x65ployed\x18\x0b \x01(\x08R\x08\x64\x65ployed\x12\x18\n\x07version\x18\x0c \x01(\tR\x07version\x12\'\n\x0f\x66ormal_hostname\x18\r \x01(\tR\x0e\x66ormalHostname\x12\x38\n\x18server_connection_status\x18\x0e \x01(\tR\x16serverConnectionStatus\x12!\n\x0cproxy_status\x18\x0f \x01(\tR\x0bproxyStatus\x12\x1b\n\tfail_open\x18\x10 \x01(\x08R\x08\x66\x61ilOpen\x12,\n\x12global_kms_decrypt\x18\x11 \x01(\x08R\x10globalKmsDecrypt\x12\x1e\n\x0bssh_rsa_key\x18\x12 \x01(\x0cR\tsshRsaKey\x12\x30\n\x14server_error_message\x18\x13 \x01(\tR\x12serverErrorMessage\x12\x39\n\ncreated_at\x18\x14 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt*j\n\x0e\x44\x65ploymentType\x12\x1f\n\x1b\x44\x45PLOYMENT_TYPE_UNSPECIFIED\x10\x00\x12\x1a\n\x16\x44\x45PLOYMENT_TYPE_ONPREM\x10\x01\x12\x1b\n\x17\x44\x45PLOYMENT_TYPE_MANAGED\x10\x02*\x90\x01\n\x0bNetworkType\x12\x1c\n\x18NETWORK_TYPE_UNSPECIFIED\x10\x00\x12 \n\x1cNETWORK_TYPE_INTERNET_FACING\x10\x01\x12\x19\n\x15NETWORK_TYPE_INTERNAL\x10\x02\x12&\n\"NETWORK_TYPE_INTERNET_AND_INTERNAL\x10\x03*y\n\rCloudProvider\x12\x1e\n\x1a\x43LOUD_PROVIDER_UNSPECIFIED\x10\x00\x12\x16\n\x12\x43LOUD_PROVIDER_AWS\x10\x01\x12\x18\n\x14\x43LOUD_PROVIDER_AZURE\x10\x02\x12\x16\n\x12\x43LOUD_PROVIDER_GCP\x10\x03\x42\xdf\x01\n\x15\x63om.admin.v1.types.v1B\x0cSidecarProtoP\x01ZQgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1/types/v1;typesv1\xa2\x02\x03\x41VT\xaa\x02\x11\x41\x64min.V1.Types.V1\xca\x02\x11\x41\x64min\\V1\\Types\\V1\xe2\x02\x1d\x41\x64min\\V1\\Types\\V1\\GPBMetadata\xea\x02\x14\x41\x64min::V1::Types::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.types.v1.sidecar_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.admin.v1.types.v1B\014SidecarProtoP\001ZQgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1/types/v1;typesv1\242\002\003AVT\252\002\021Admin.V1.Types.V1\312\002\021Admin\\V1\\Types\\V1\342\002\035Admin\\V1\\Types\\V1\\GPBMetadata\352\002\024Admin::V1::Types::V1'
  _globals['_DEPLOYMENTTYPE']._serialized_start=867
  _globals['_DEPLOYMENTTYPE']._serialized_end=973
  _globals['_NETWORKTYPE']._serialized_start=976
  _globals['_NETWORKTYPE']._serialized_end=1120
  _globals['_CLOUDPROVIDER']._serialized_start=1122
  _globals['_CLOUDPROVIDER']._serialized_end=1243
  _globals['_SIDECAR']._serialized_start=88
  _globals['_SIDECAR']._serialized_end=865
# @@protoc_insertion_point(module_scope)
