# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import etl_pb2 as admin_dot_v1_dot_etl__pb2


class ETLServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetConnectors = channel.unary_unary(
                '/admin.v1.ETLService/GetConnectors',
                request_serializer=admin_dot_v1_dot_etl__pb2.GetConnectorsRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_etl__pb2.GetConnectorsResponse.FromString,
                )
        self.GetConnectorByDbName = channel.unary_unary(
                '/admin.v1.ETLService/GetConnectorByDbName',
                request_serializer=admin_dot_v1_dot_etl__pb2.GetConnectorByDbNameRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_etl__pb2.GetConnectorByDbNameResponse.FromString,
                )
        self.GetDestinations = channel.unary_unary(
                '/admin.v1.ETLService/GetDestinations',
                request_serializer=admin_dot_v1_dot_etl__pb2.GetDestinationsRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_etl__pb2.GetDestinationsResponse.FromString,
                )
        self.GetDestinationByID = channel.unary_unary(
                '/admin.v1.ETLService/GetDestinationByID',
                request_serializer=admin_dot_v1_dot_etl__pb2.GetDestinationByIDRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_etl__pb2.GetDestinationByIDResponse.FromString,
                )
        self.GetGroups = channel.unary_unary(
                '/admin.v1.ETLService/GetGroups',
                request_serializer=admin_dot_v1_dot_etl__pb2.GetGroupsRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_etl__pb2.GetGroupsResponse.FromString,
                )
        self.GetLineageSchemas = channel.unary_unary(
                '/admin.v1.ETLService/GetLineageSchemas',
                request_serializer=admin_dot_v1_dot_etl__pb2.GetLineageSchemasRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_etl__pb2.GetLineageSchemasResponse.FromString,
                )
        self.GetLineageSchemaByName = channel.unary_unary(
                '/admin.v1.ETLService/GetLineageSchemaByName',
                request_serializer=admin_dot_v1_dot_etl__pb2.GetLineageSchemaByNameRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_etl__pb2.GetLineageSchemaByNameResponse.FromString,
                )
        self.GetLineageTables = channel.unary_unary(
                '/admin.v1.ETLService/GetLineageTables',
                request_serializer=admin_dot_v1_dot_etl__pb2.GetLineageTablesRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_etl__pb2.GetLineageTablesResponse.FromString,
                )
        self.GetLineageTableByName = channel.unary_unary(
                '/admin.v1.ETLService/GetLineageTableByName',
                request_serializer=admin_dot_v1_dot_etl__pb2.GetLineageTableByNameRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_etl__pb2.GetLineageTableByNameResponse.FromString,
                )
        self.GetLineageColumns = channel.unary_unary(
                '/admin.v1.ETLService/GetLineageColumns',
                request_serializer=admin_dot_v1_dot_etl__pb2.GetLineageColumnsRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_etl__pb2.GetLineageColumnsResponse.FromString,
                )
        self.GetLineageColumnsByTable = channel.unary_unary(
                '/admin.v1.ETLService/GetLineageColumnsByTable',
                request_serializer=admin_dot_v1_dot_etl__pb2.GetLineageColumnsByTableRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_etl__pb2.GetLineageColumnsByTableResponse.FromString,
                )


class ETLServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetConnectors(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetConnectorByDbName(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDestinations(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDestinationByID(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetGroups(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLineageSchemas(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLineageSchemaByName(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLineageTables(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLineageTableByName(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLineageColumns(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLineageColumnsByTable(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ETLServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetConnectors': grpc.unary_unary_rpc_method_handler(
                    servicer.GetConnectors,
                    request_deserializer=admin_dot_v1_dot_etl__pb2.GetConnectorsRequest.FromString,
                    response_serializer=admin_dot_v1_dot_etl__pb2.GetConnectorsResponse.SerializeToString,
            ),
            'GetConnectorByDbName': grpc.unary_unary_rpc_method_handler(
                    servicer.GetConnectorByDbName,
                    request_deserializer=admin_dot_v1_dot_etl__pb2.GetConnectorByDbNameRequest.FromString,
                    response_serializer=admin_dot_v1_dot_etl__pb2.GetConnectorByDbNameResponse.SerializeToString,
            ),
            'GetDestinations': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDestinations,
                    request_deserializer=admin_dot_v1_dot_etl__pb2.GetDestinationsRequest.FromString,
                    response_serializer=admin_dot_v1_dot_etl__pb2.GetDestinationsResponse.SerializeToString,
            ),
            'GetDestinationByID': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDestinationByID,
                    request_deserializer=admin_dot_v1_dot_etl__pb2.GetDestinationByIDRequest.FromString,
                    response_serializer=admin_dot_v1_dot_etl__pb2.GetDestinationByIDResponse.SerializeToString,
            ),
            'GetGroups': grpc.unary_unary_rpc_method_handler(
                    servicer.GetGroups,
                    request_deserializer=admin_dot_v1_dot_etl__pb2.GetGroupsRequest.FromString,
                    response_serializer=admin_dot_v1_dot_etl__pb2.GetGroupsResponse.SerializeToString,
            ),
            'GetLineageSchemas': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLineageSchemas,
                    request_deserializer=admin_dot_v1_dot_etl__pb2.GetLineageSchemasRequest.FromString,
                    response_serializer=admin_dot_v1_dot_etl__pb2.GetLineageSchemasResponse.SerializeToString,
            ),
            'GetLineageSchemaByName': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLineageSchemaByName,
                    request_deserializer=admin_dot_v1_dot_etl__pb2.GetLineageSchemaByNameRequest.FromString,
                    response_serializer=admin_dot_v1_dot_etl__pb2.GetLineageSchemaByNameResponse.SerializeToString,
            ),
            'GetLineageTables': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLineageTables,
                    request_deserializer=admin_dot_v1_dot_etl__pb2.GetLineageTablesRequest.FromString,
                    response_serializer=admin_dot_v1_dot_etl__pb2.GetLineageTablesResponse.SerializeToString,
            ),
            'GetLineageTableByName': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLineageTableByName,
                    request_deserializer=admin_dot_v1_dot_etl__pb2.GetLineageTableByNameRequest.FromString,
                    response_serializer=admin_dot_v1_dot_etl__pb2.GetLineageTableByNameResponse.SerializeToString,
            ),
            'GetLineageColumns': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLineageColumns,
                    request_deserializer=admin_dot_v1_dot_etl__pb2.GetLineageColumnsRequest.FromString,
                    response_serializer=admin_dot_v1_dot_etl__pb2.GetLineageColumnsResponse.SerializeToString,
            ),
            'GetLineageColumnsByTable': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLineageColumnsByTable,
                    request_deserializer=admin_dot_v1_dot_etl__pb2.GetLineageColumnsByTableRequest.FromString,
                    response_serializer=admin_dot_v1_dot_etl__pb2.GetLineageColumnsByTableResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'admin.v1.ETLService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ETLService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetConnectors(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.ETLService/GetConnectors',
            admin_dot_v1_dot_etl__pb2.GetConnectorsRequest.SerializeToString,
            admin_dot_v1_dot_etl__pb2.GetConnectorsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetConnectorByDbName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.ETLService/GetConnectorByDbName',
            admin_dot_v1_dot_etl__pb2.GetConnectorByDbNameRequest.SerializeToString,
            admin_dot_v1_dot_etl__pb2.GetConnectorByDbNameResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDestinations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.ETLService/GetDestinations',
            admin_dot_v1_dot_etl__pb2.GetDestinationsRequest.SerializeToString,
            admin_dot_v1_dot_etl__pb2.GetDestinationsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDestinationByID(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.ETLService/GetDestinationByID',
            admin_dot_v1_dot_etl__pb2.GetDestinationByIDRequest.SerializeToString,
            admin_dot_v1_dot_etl__pb2.GetDestinationByIDResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetGroups(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.ETLService/GetGroups',
            admin_dot_v1_dot_etl__pb2.GetGroupsRequest.SerializeToString,
            admin_dot_v1_dot_etl__pb2.GetGroupsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetLineageSchemas(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.ETLService/GetLineageSchemas',
            admin_dot_v1_dot_etl__pb2.GetLineageSchemasRequest.SerializeToString,
            admin_dot_v1_dot_etl__pb2.GetLineageSchemasResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetLineageSchemaByName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.ETLService/GetLineageSchemaByName',
            admin_dot_v1_dot_etl__pb2.GetLineageSchemaByNameRequest.SerializeToString,
            admin_dot_v1_dot_etl__pb2.GetLineageSchemaByNameResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetLineageTables(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.ETLService/GetLineageTables',
            admin_dot_v1_dot_etl__pb2.GetLineageTablesRequest.SerializeToString,
            admin_dot_v1_dot_etl__pb2.GetLineageTablesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetLineageTableByName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.ETLService/GetLineageTableByName',
            admin_dot_v1_dot_etl__pb2.GetLineageTableByNameRequest.SerializeToString,
            admin_dot_v1_dot_etl__pb2.GetLineageTableByNameResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetLineageColumns(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.ETLService/GetLineageColumns',
            admin_dot_v1_dot_etl__pb2.GetLineageColumnsRequest.SerializeToString,
            admin_dot_v1_dot_etl__pb2.GetLineageColumnsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetLineageColumnsByTable(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.ETLService/GetLineageColumnsByTable',
            admin_dot_v1_dot_etl__pb2.GetLineageColumnsByTableRequest.SerializeToString,
            admin_dot_v1_dot_etl__pb2.GetLineageColumnsByTableResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
