# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: admin/v1/native_user.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x61\x64min/v1/native_user.proto\x12\x08\x61\x64min.v1\"\xb7\x01\n\x17\x43reateNativeUserRequest\x12\"\n\rdata_store_id\x18\x01 \x01(\tR\x0b\x64\x61taStoreId\x12$\n\x0enative_user_id\x18\x02 \x01(\tR\x0cnativeUserId\x12,\n\x12native_user_secret\x18\x03 \x01(\tR\x10nativeUserSecret\x12$\n\x0euse_as_default\x18\x04 \x01(\x08R\x0cuseAsDefault\"Q\n\x18\x43reateNativeUserResponse\x12\x35\n\x0bnative_user\x18\x01 \x01(\x0b\x32\x14.admin.v1.NativeUserR\nnativeUser\";\n\x15GetNativeUsersRequest\x12\"\n\rdata_store_id\x18\x01 \x01(\tR\x0b\x64\x61taStoreId\"\xc4\x01\n\x16GetNativeUsersResponse\x12T\n\x0cnative_users\x18\x01 \x03(\x0b\x32\x31.admin.v1.GetNativeUsersResponse.NativeUsersEntryR\x0bnativeUsers\x1aT\n\x10NativeUsersEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12*\n\x05value\x18\x02 \x01(\x0b\x32\x14.admin.v1.NativeUserR\x05value:\x02\x38\x01\"`\n\x14GetNativeUserRequest\x12\"\n\rdata_store_id\x18\x01 \x01(\tR\x0b\x64\x61taStoreId\x12$\n\x0enative_user_id\x18\x02 \x01(\tR\x0cnativeUserId\"N\n\x15GetNativeUserResponse\x12\x35\n\x0bnative_user\x18\x01 \x01(\x0b\x32\x14.admin.v1.NativeUserR\nnativeUser\"\xf6\x01\n\nNativeUser\x12!\n\x0c\x64\x61tastore_id\x18\x01 \x01(\tR\x0b\x64\x61tastoreId\x12$\n\x0enative_user_id\x18\x02 \x01(\tR\x0cnativeUserId\x12,\n\x12native_user_secret\x18\x03 \x01(\tR\x10nativeUserSecret\x12$\n\x0euse_as_default\x18\x04 \x01(\x08R\x0cuseAsDefault\x12\x1d\n\ncreated_at\x18\x05 \x01(\x03R\tcreatedAt\x12\x14\n\x05users\x18\x06 \x03(\tR\x05users\x12\x16\n\x06groups\x18\x07 \x03(\tR\x06groups\"c\n\x17\x44\x65leteNativeUserRequest\x12\"\n\rdata_store_id\x18\x01 \x01(\tR\x0b\x64\x61taStoreId\x12$\n\x0enative_user_id\x18\x02 \x01(\tR\x0cnativeUserId\"\x1a\n\x18\x44\x65leteNativeUserResponse\"\x97\x01\n\x1dUpdateNativeUserSecretRequest\x12\"\n\rdata_store_id\x18\x01 \x01(\tR\x0b\x64\x61taStoreId\x12$\n\x0enative_user_id\x18\x02 \x01(\tR\x0cnativeUserId\x12,\n\x12native_user_secret\x18\x03 \x01(\tR\x10nativeUserSecret\" \n\x1eUpdateNativeUserSecretResponse\"i\n\x1dSetNativeUserAsDefaultRequest\x12\"\n\rdata_store_id\x18\x01 \x01(\tR\x0b\x64\x61taStoreId\x12$\n\x0enative_user_id\x18\x02 \x01(\tR\x0cnativeUserId\" \n\x1eSetNativeUserAsDefaultResponse\"\xc2\x01\n#CreateNativeUserIdentityLinkRequest\x12\"\n\rdata_store_id\x18\x01 \x01(\tR\x0b\x64\x61taStoreId\x12$\n\x0enative_user_id\x18\x02 \x01(\tR\x0cnativeUserId\x12\x1f\n\x0bidentity_id\x18\x03 \x01(\tR\nidentityId\x12\x30\n\x14\x66ormal_identity_type\x18\x04 \x01(\tR\x12\x66ormalIdentityType\"T\n$CreateNativeUserIdentityLinkResponse\x12,\n\x04link\x18\x01 \x01(\x0b\x32\x18.admin.v1.NativeUserLinkR\x04link\"g\n GetNativeUserIdentityLinkRequest\x12\"\n\rdata_store_id\x18\x01 \x01(\tR\x0b\x64\x61taStoreId\x12\x1f\n\x0bidentity_id\x18\x02 \x01(\tR\nidentityId\"\xc4\x01\n%CreateNativeUserIdentityLinkV2Request\x12\"\n\rdata_store_id\x18\x01 \x01(\tR\x0b\x64\x61taStoreId\x12$\n\x0enative_user_id\x18\x02 \x01(\tR\x0cnativeUserId\x12\x1f\n\x0bidentity_id\x18\x03 \x01(\tR\nidentityId\x12\x30\n\x14\x66ormal_identity_type\x18\x04 \x01(\tR\x12\x66ormalIdentityType\"V\n&CreateNativeUserIdentityLinkV2Response\x12,\n\x04link\x18\x01 \x01(\x0b\x32\x18.admin.v1.NativeUserLinkR\x04link\"Q\n!GetNativeUserIdentityLinkResponse\x12,\n\x04link\x18\x01 \x01(\x0b\x32\x18.admin.v1.NativeUserLinkR\x04link\"j\n#DeleteNativeUserIdentityLinkRequest\x12\"\n\rdata_store_id\x18\x01 \x01(\tR\x0b\x64\x61taStoreId\x12\x1f\n\x0bidentity_id\x18\x02 \x01(\tR\nidentityId\"&\n$DeleteNativeUserIdentityLinkResponse\"\xba\x01\n\x0eNativeUserLink\x12\"\n\rdata_store_id\x18\x01 \x01(\tR\x0b\x64\x61taStoreId\x12,\n\x12\x66ormal_identity_id\x18\x02 \x01(\tR\x10\x66ormalIdentityId\x12\x30\n\x14\x66ormal_identity_type\x18\x03 \x01(\tR\x12\x66ormalIdentityType\x12$\n\x0enative_user_id\x18\x04 \x01(\tR\x0cnativeUserId2\xc4\x08\n\x11NativeUserService\x12Y\n\x10\x43reateNativeUser\x12!.admin.v1.CreateNativeUserRequest\x1a\".admin.v1.CreateNativeUserResponse\x12P\n\rGetNativeUser\x12\x1e.admin.v1.GetNativeUserRequest\x1a\x1f.admin.v1.GetNativeUserResponse\x12S\n\x0eGetNativeUsers\x12\x1f.admin.v1.GetNativeUsersRequest\x1a .admin.v1.GetNativeUsersResponse\x12Y\n\x10\x44\x65leteNativeUser\x12!.admin.v1.DeleteNativeUserRequest\x1a\".admin.v1.DeleteNativeUserResponse\x12k\n\x16UpdateNativeUserSecret\x12\'.admin.v1.UpdateNativeUserSecretRequest\x1a(.admin.v1.UpdateNativeUserSecretResponse\x12k\n\x16SetNativeUserAsDefault\x12\'.admin.v1.SetNativeUserAsDefaultRequest\x1a(.admin.v1.SetNativeUserAsDefaultResponse\x12}\n\x1c\x43reateNativeUserIdentityLink\x12-.admin.v1.CreateNativeUserIdentityLinkRequest\x1a..admin.v1.CreateNativeUserIdentityLinkResponse\x12\x83\x01\n\x1e\x43reateNativeUserIdentityLinkV2\x12/.admin.v1.CreateNativeUserIdentityLinkV2Request\x1a\x30.admin.v1.CreateNativeUserIdentityLinkV2Response\x12t\n\x19GetNativeUserIdentityLink\x12*.admin.v1.GetNativeUserIdentityLinkRequest\x1a+.admin.v1.GetNativeUserIdentityLinkResponse\x12}\n\x1c\x44\x65leteNativeUserIdentityLink\x12-.admin.v1.DeleteNativeUserIdentityLinkRequest\x1a..admin.v1.DeleteNativeUserIdentityLinkResponseB\xaa\x01\n\x0c\x63om.admin.v1B\x0fNativeUserProtoP\x01ZHgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1;adminv1\xa2\x02\x03\x41XX\xaa\x02\x08\x41\x64min.V1\xca\x02\x08\x41\x64min\\V1\xe2\x02\x14\x41\x64min\\V1\\GPBMetadata\xea\x02\tAdmin::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.native_user_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\014com.admin.v1B\017NativeUserProtoP\001ZHgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1;adminv1\242\002\003AXX\252\002\010Admin.V1\312\002\010Admin\\V1\342\002\024Admin\\V1\\GPBMetadata\352\002\tAdmin::V1'
  _globals['_GETNATIVEUSERSRESPONSE_NATIVEUSERSENTRY']._options = None
  _globals['_GETNATIVEUSERSRESPONSE_NATIVEUSERSENTRY']._serialized_options = b'8\001'
  _globals['_CREATENATIVEUSERREQUEST']._serialized_start=41
  _globals['_CREATENATIVEUSERREQUEST']._serialized_end=224
  _globals['_CREATENATIVEUSERRESPONSE']._serialized_start=226
  _globals['_CREATENATIVEUSERRESPONSE']._serialized_end=307
  _globals['_GETNATIVEUSERSREQUEST']._serialized_start=309
  _globals['_GETNATIVEUSERSREQUEST']._serialized_end=368
  _globals['_GETNATIVEUSERSRESPONSE']._serialized_start=371
  _globals['_GETNATIVEUSERSRESPONSE']._serialized_end=567
  _globals['_GETNATIVEUSERSRESPONSE_NATIVEUSERSENTRY']._serialized_start=483
  _globals['_GETNATIVEUSERSRESPONSE_NATIVEUSERSENTRY']._serialized_end=567
  _globals['_GETNATIVEUSERREQUEST']._serialized_start=569
  _globals['_GETNATIVEUSERREQUEST']._serialized_end=665
  _globals['_GETNATIVEUSERRESPONSE']._serialized_start=667
  _globals['_GETNATIVEUSERRESPONSE']._serialized_end=745
  _globals['_NATIVEUSER']._serialized_start=748
  _globals['_NATIVEUSER']._serialized_end=994
  _globals['_DELETENATIVEUSERREQUEST']._serialized_start=996
  _globals['_DELETENATIVEUSERREQUEST']._serialized_end=1095
  _globals['_DELETENATIVEUSERRESPONSE']._serialized_start=1097
  _globals['_DELETENATIVEUSERRESPONSE']._serialized_end=1123
  _globals['_UPDATENATIVEUSERSECRETREQUEST']._serialized_start=1126
  _globals['_UPDATENATIVEUSERSECRETREQUEST']._serialized_end=1277
  _globals['_UPDATENATIVEUSERSECRETRESPONSE']._serialized_start=1279
  _globals['_UPDATENATIVEUSERSECRETRESPONSE']._serialized_end=1311
  _globals['_SETNATIVEUSERASDEFAULTREQUEST']._serialized_start=1313
  _globals['_SETNATIVEUSERASDEFAULTREQUEST']._serialized_end=1418
  _globals['_SETNATIVEUSERASDEFAULTRESPONSE']._serialized_start=1420
  _globals['_SETNATIVEUSERASDEFAULTRESPONSE']._serialized_end=1452
  _globals['_CREATENATIVEUSERIDENTITYLINKREQUEST']._serialized_start=1455
  _globals['_CREATENATIVEUSERIDENTITYLINKREQUEST']._serialized_end=1649
  _globals['_CREATENATIVEUSERIDENTITYLINKRESPONSE']._serialized_start=1651
  _globals['_CREATENATIVEUSERIDENTITYLINKRESPONSE']._serialized_end=1735
  _globals['_GETNATIVEUSERIDENTITYLINKREQUEST']._serialized_start=1737
  _globals['_GETNATIVEUSERIDENTITYLINKREQUEST']._serialized_end=1840
  _globals['_CREATENATIVEUSERIDENTITYLINKV2REQUEST']._serialized_start=1843
  _globals['_CREATENATIVEUSERIDENTITYLINKV2REQUEST']._serialized_end=2039
  _globals['_CREATENATIVEUSERIDENTITYLINKV2RESPONSE']._serialized_start=2041
  _globals['_CREATENATIVEUSERIDENTITYLINKV2RESPONSE']._serialized_end=2127
  _globals['_GETNATIVEUSERIDENTITYLINKRESPONSE']._serialized_start=2129
  _globals['_GETNATIVEUSERIDENTITYLINKRESPONSE']._serialized_end=2210
  _globals['_DELETENATIVEUSERIDENTITYLINKREQUEST']._serialized_start=2212
  _globals['_DELETENATIVEUSERIDENTITYLINKREQUEST']._serialized_end=2318
  _globals['_DELETENATIVEUSERIDENTITYLINKRESPONSE']._serialized_start=2320
  _globals['_DELETENATIVEUSERIDENTITYLINKRESPONSE']._serialized_end=2358
  _globals['_NATIVEUSERLINK']._serialized_start=2361
  _globals['_NATIVEUSERLINK']._serialized_end=2547
  _globals['_NATIVEUSERSERVICE']._serialized_start=2550
  _globals['_NATIVEUSERSERVICE']._serialized_end=3642
# @@protoc_insertion_point(module_scope)
