# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: admin/v1/identities.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .types.v1 import external_id_pb2 as admin_dot_v1_dot_types_dot_v1_dot_external__id__pb2
from .types.v1 import group_pb2 as admin_dot_v1_dot_types_dot_v1_dot_group__pb2
from .types.v1 import user_pb2 as admin_dot_v1_dot_types_dot_v1_dot_user__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from .types.v1 import list_metadata_pb2 as admin_dot_v1_dot_types_dot_v1_dot_list__metadata__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19\x61\x64min/v1/identities.proto\x12\x08\x61\x64min.v1\x1a#admin/v1/types/v1/external_id.proto\x1a\x1d\x61\x64min/v1/types/v1/group.proto\x1a\x1c\x61\x64min/v1/types/v1/user.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a%admin/v1/types/v1/list_metadata.proto\"W\n\x11ListGroupsRequest\x12\x14\n\x05limit\x18\x01 \x01(\x05R\x05limit\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor\x12\x14\n\x05order\x18\x03 \x01(\tR\x05order\"J\n\x12\x43reateGroupRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\"%\n\x13GetGroupByIdRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"$\n\x12\x44\x65leteGroupRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"Z\n\x12UpdateGroupRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\"D\n\x17LinkUsersToGroupRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x19\n\x08user_ids\x18\x02 \x03(\tR\x07userIds\"F\n\x19LinkUsersToGroupV2Request\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x19\n\x08user_ids\x18\x02 \x03(\tR\x07userIds\"H\n\x1bUnlinkUsersFromGroupRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x19\n\x08user_ids\x18\x02 \x03(\tR\x07userIds\"E\n\x13\x43reateGroupResponse\x12.\n\x05group\x18\x01 \x01(\x0b\x32\x18.admin.v1.types.v1.GroupR\x05group\"F\n\x14GetGroupByIdResponse\x12.\n\x05group\x18\x01 \x01(\x0b\x32\x18.admin.v1.types.v1.GroupR\x05group\"E\n\x13\x44\x65leteGroupResponse\x12.\n\x05group\x18\x01 \x01(\x0b\x32\x18.admin.v1.types.v1.GroupR\x05group\"E\n\x13UpdateGroupResponse\x12.\n\x05group\x18\x01 \x01(\x0b\x32\x18.admin.v1.types.v1.GroupR\x05group\"\x8c\x01\n\x12ListGroupsResponse\x12\x30\n\x06groups\x18\x01 \x03(\x0b\x32\x18.admin.v1.types.v1.GroupR\x06groups\x12\x44\n\rlist_metadata\x18\x02 \x01(\x0b\x32\x1f.admin.v1.types.v1.ListMetadataR\x0clistMetadata\"P\n\x18LinkUsersToGroupResponse\x12\x19\n\x08user_ids\x18\x01 \x03(\tR\x07userIds\x12\x19\n\x08group_id\x18\x02 \x01(\tR\x07groupId\"R\n\x1aLinkUsersToGroupV2Response\x12\x19\n\x08user_ids\x18\x01 \x03(\tR\x07userIds\x12\x19\n\x08group_id\x18\x02 \x01(\tR\x07groupId\"T\n\x1cUnlinkUsersFromGroupResponse\x12\x19\n\x08user_ids\x18\x01 \x03(\tR\x07userIds\x12\x19\n\x08group_id\x18\x02 \x01(\tR\x07groupId\"M\n\x15UserLinkGroupResponse\x12\x19\n\x08user_ids\x18\x01 \x03(\tR\x07userIds\x12\x19\n\x08group_id\x18\x02 \x01(\tR\x07groupId\"V\n\x10ListUsersRequest\x12\x14\n\x05limit\x18\x01 \x01(\x05R\x05limit\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor\x12\x14\n\x05order\x18\x03 \x01(\tR\x05order\"\x88\x01\n\x11ListUsersResponse\x12-\n\x05users\x18\x01 \x03(\x0b\x32\x17.admin.v1.types.v1.UserR\x05users\x12\x44\n\rlist_metadata\x18\x02 \x01(\x0b\x32\x1f.admin.v1.types.v1.ListMetadataR\x0clistMetadata\"\xb8\x02\n\x11\x43reateUserRequest\x12\x1d\n\nfirst_name\x18\x01 \x01(\tR\tfirstName\x12\x1b\n\tlast_name\x18\x02 \x01(\tR\x08lastName\x12\x12\n\x04type\x18\x03 \x01(\tR\x04type\x12\x19\n\x08\x61pp_type\x18\x04 \x01(\tR\x07\x61ppType\x12\x15\n\x06\x61pp_id\x18\x05 \x01(\tR\x05\x61ppId\x12\x12\n\x04name\x18\x06 \x01(\tR\x04name\x12\x14\n\x05\x65mail\x18\x07 \x01(\tR\x05\x65mail\x12\x14\n\x05\x61\x64min\x18\x08 \x01(\x08R\x05\x61\x64min\x12\x10\n\x03idp\x18\t \x01(\tR\x03idp\x12\x16\n\x06status\x18\n \x01(\tR\x06status\x12\x37\n\texpire_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x08\x65xpireAt\"^\n\x12\x43reateUserResponse\x12+\n\x04user\x18\x01 \x01(\x0b\x32\x17.admin.v1.types.v1.UserR\x04user\x12\x1b\n\ttenant_id\x18\x02 \x01(\tR\x08tenantId\"\xba\x02\n\x13\x43reateUserV2Request\x12\x1d\n\nfirst_name\x18\x01 \x01(\tR\tfirstName\x12\x1b\n\tlast_name\x18\x02 \x01(\tR\x08lastName\x12\x12\n\x04type\x18\x03 \x01(\tR\x04type\x12\x19\n\x08\x61pp_type\x18\x04 \x01(\tR\x07\x61ppType\x12\x15\n\x06\x61pp_id\x18\x05 \x01(\tR\x05\x61ppId\x12\x12\n\x04name\x18\x06 \x01(\tR\x04name\x12\x14\n\x05\x65mail\x18\x07 \x01(\tR\x05\x65mail\x12\x14\n\x05\x61\x64min\x18\x08 \x01(\x08R\x05\x61\x64min\x12\x10\n\x03idp\x18\t \x01(\tR\x03idp\x12\x16\n\x06status\x18\n \x01(\tR\x06status\x12\x37\n\texpire_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x08\x65xpireAt\"&\n\x14\x43reateUserV2Response\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"$\n\x12GetUserByIdRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"B\n\x13GetUserByIdResponse\x12+\n\x04user\x18\x01 \x01(\x0b\x32\x17.admin.v1.types.v1.UserR\x04user\"#\n\x11\x44\x65leteUserRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"\x14\n\x12\x44\x65leteUserResponse\"\x89\x01\n\x11UpdateUserRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x1d\n\nfirst_name\x18\x03 \x01(\tR\tfirstName\x12\x1b\n\tlast_name\x18\x04 \x01(\tR\x08lastName\x12\x14\n\x05\x65mail\x18\x05 \x01(\tR\x05\x65mail\"\x14\n\x12UpdateUserResponse\"0\n\x1eGetMachineUserAuthTokenRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"S\n\x1fGetMachineUserAuthTokenResponse\x12\x14\n\x05token\x18\x01 \x01(\tR\x05token\x12\x1a\n\x08username\x18\x02 \x01(\tR\x08username\"4\n\"RefreshMachineUserAuthTokenRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"W\n#RefreshMachineUserAuthTokenResponse\x12\x14\n\x05token\x18\x01 \x01(\tR\x05token\x12\x1a\n\x08username\x18\x02 \x01(\tR\x08username\"+\n\x19GetUserExternalIdsRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"^\n\x1aGetUserExternalIdsResponse\x12@\n\x0c\x65xternal_ids\x18\x01 \x03(\x0b\x32\x1d.admin.v1.types.v1.ExternalIdR\x0b\x65xternalIds\"\x8f\x01\n\x1aMapUserToExternalIdRequest\x12\x17\n\x07user_id\x18\x01 \x01(\tR\x06userId\x12\x1f\n\x0b\x65xternal_id\x18\x02 \x01(\tR\nexternalId\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12\x15\n\x06\x61pp_id\x18\x04 \x01(\tR\x05\x61ppId\"\x1d\n\x1bMapUserToExternalIdResponse\"?\n\x1e\x44\x65leteExternalIdMappingRequest\x12\x1d\n\nmapping_id\x18\x01 \x01(\tR\tmappingId\"!\n\x1f\x44\x65leteExternalIdMappingResponse2\xea\x07\n\x0bUserService\x12\x44\n\tListUsers\x12\x1a.admin.v1.ListUsersRequest\x1a\x1b.admin.v1.ListUsersResponse\x12G\n\nCreateUser\x12\x1b.admin.v1.CreateUserRequest\x1a\x1c.admin.v1.CreateUserResponse\x12M\n\x0c\x43reateUserV2\x12\x1d.admin.v1.CreateUserV2Request\x1a\x1e.admin.v1.CreateUserV2Response\x12J\n\x0bGetUserById\x12\x1c.admin.v1.GetUserByIdRequest\x1a\x1d.admin.v1.GetUserByIdResponse\x12G\n\nDeleteUser\x12\x1b.admin.v1.DeleteUserRequest\x1a\x1c.admin.v1.DeleteUserResponse\x12G\n\nUpdateUser\x12\x1b.admin.v1.UpdateUserRequest\x1a\x1c.admin.v1.UpdateUserResponse\x12n\n\x17GetMachineUserAuthToken\x12(.admin.v1.GetMachineUserAuthTokenRequest\x1a).admin.v1.GetMachineUserAuthTokenResponse\x12z\n\x1bRefreshMachineUserAuthToken\x12,.admin.v1.RefreshMachineUserAuthTokenRequest\x1a-.admin.v1.RefreshMachineUserAuthTokenResponse\x12_\n\x12GetUserExternalIds\x12#.admin.v1.GetUserExternalIdsRequest\x1a$.admin.v1.GetUserExternalIdsResponse\x12\x62\n\x13MapUserToExternalId\x12$.admin.v1.MapUserToExternalIdRequest\x1a%.admin.v1.MapUserToExternalIdResponse\x12n\n\x17\x44\x65leteExternalIdMapping\x12(.admin.v1.DeleteExternalIdMappingRequest\x1a).admin.v1.DeleteExternalIdMappingResponse2\xad\x05\n\x0cGroupService\x12J\n\x0b\x43reateGroup\x12\x1c.admin.v1.CreateGroupRequest\x1a\x1d.admin.v1.CreateGroupResponse\x12G\n\nListGroups\x12\x1b.admin.v1.ListGroupsRequest\x1a\x1c.admin.v1.ListGroupsResponse\x12M\n\x0cGetGroupById\x12\x1d.admin.v1.GetGroupByIdRequest\x1a\x1e.admin.v1.GetGroupByIdResponse\x12J\n\x0bUpdateGroup\x12\x1c.admin.v1.UpdateGroupRequest\x1a\x1d.admin.v1.UpdateGroupResponse\x12Y\n\x10LinkUsersToGroup\x12!.admin.v1.LinkUsersToGroupRequest\x1a\".admin.v1.LinkUsersToGroupResponse\x12_\n\x12LinkUsersToGroupV2\x12#.admin.v1.LinkUsersToGroupV2Request\x1a$.admin.v1.LinkUsersToGroupV2Response\x12\x65\n\x14UnlinkUsersFromGroup\x12%.admin.v1.UnlinkUsersFromGroupRequest\x1a&.admin.v1.UnlinkUsersFromGroupResponse\x12J\n\x0b\x44\x65leteGroup\x12\x1c.admin.v1.DeleteGroupRequest\x1a\x1d.admin.v1.DeleteGroupResponseB\xaa\x01\n\x0c\x63om.admin.v1B\x0fIdentitiesProtoP\x01ZHgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1;adminv1\xa2\x02\x03\x41XX\xaa\x02\x08\x41\x64min.V1\xca\x02\x08\x41\x64min\\V1\xe2\x02\x14\x41\x64min\\V1\\GPBMetadata\xea\x02\tAdmin::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.identities_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\014com.admin.v1B\017IdentitiesProtoP\001ZHgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1;adminv1\242\002\003AXX\252\002\010Admin.V1\312\002\010Admin\\V1\342\002\024Admin\\V1\\GPBMetadata\352\002\tAdmin::V1'
  _globals['_LISTGROUPSREQUEST']._serialized_start=209
  _globals['_LISTGROUPSREQUEST']._serialized_end=296
  _globals['_CREATEGROUPREQUEST']._serialized_start=298
  _globals['_CREATEGROUPREQUEST']._serialized_end=372
  _globals['_GETGROUPBYIDREQUEST']._serialized_start=374
  _globals['_GETGROUPBYIDREQUEST']._serialized_end=411
  _globals['_DELETEGROUPREQUEST']._serialized_start=413
  _globals['_DELETEGROUPREQUEST']._serialized_end=449
  _globals['_UPDATEGROUPREQUEST']._serialized_start=451
  _globals['_UPDATEGROUPREQUEST']._serialized_end=541
  _globals['_LINKUSERSTOGROUPREQUEST']._serialized_start=543
  _globals['_LINKUSERSTOGROUPREQUEST']._serialized_end=611
  _globals['_LINKUSERSTOGROUPV2REQUEST']._serialized_start=613
  _globals['_LINKUSERSTOGROUPV2REQUEST']._serialized_end=683
  _globals['_UNLINKUSERSFROMGROUPREQUEST']._serialized_start=685
  _globals['_UNLINKUSERSFROMGROUPREQUEST']._serialized_end=757
  _globals['_CREATEGROUPRESPONSE']._serialized_start=759
  _globals['_CREATEGROUPRESPONSE']._serialized_end=828
  _globals['_GETGROUPBYIDRESPONSE']._serialized_start=830
  _globals['_GETGROUPBYIDRESPONSE']._serialized_end=900
  _globals['_DELETEGROUPRESPONSE']._serialized_start=902
  _globals['_DELETEGROUPRESPONSE']._serialized_end=971
  _globals['_UPDATEGROUPRESPONSE']._serialized_start=973
  _globals['_UPDATEGROUPRESPONSE']._serialized_end=1042
  _globals['_LISTGROUPSRESPONSE']._serialized_start=1045
  _globals['_LISTGROUPSRESPONSE']._serialized_end=1185
  _globals['_LINKUSERSTOGROUPRESPONSE']._serialized_start=1187
  _globals['_LINKUSERSTOGROUPRESPONSE']._serialized_end=1267
  _globals['_LINKUSERSTOGROUPV2RESPONSE']._serialized_start=1269
  _globals['_LINKUSERSTOGROUPV2RESPONSE']._serialized_end=1351
  _globals['_UNLINKUSERSFROMGROUPRESPONSE']._serialized_start=1353
  _globals['_UNLINKUSERSFROMGROUPRESPONSE']._serialized_end=1437
  _globals['_USERLINKGROUPRESPONSE']._serialized_start=1439
  _globals['_USERLINKGROUPRESPONSE']._serialized_end=1516
  _globals['_LISTUSERSREQUEST']._serialized_start=1518
  _globals['_LISTUSERSREQUEST']._serialized_end=1604
  _globals['_LISTUSERSRESPONSE']._serialized_start=1607
  _globals['_LISTUSERSRESPONSE']._serialized_end=1743
  _globals['_CREATEUSERREQUEST']._serialized_start=1746
  _globals['_CREATEUSERREQUEST']._serialized_end=2058
  _globals['_CREATEUSERRESPONSE']._serialized_start=2060
  _globals['_CREATEUSERRESPONSE']._serialized_end=2154
  _globals['_CREATEUSERV2REQUEST']._serialized_start=2157
  _globals['_CREATEUSERV2REQUEST']._serialized_end=2471
  _globals['_CREATEUSERV2RESPONSE']._serialized_start=2473
  _globals['_CREATEUSERV2RESPONSE']._serialized_end=2511
  _globals['_GETUSERBYIDREQUEST']._serialized_start=2513
  _globals['_GETUSERBYIDREQUEST']._serialized_end=2549
  _globals['_GETUSERBYIDRESPONSE']._serialized_start=2551
  _globals['_GETUSERBYIDRESPONSE']._serialized_end=2617
  _globals['_DELETEUSERREQUEST']._serialized_start=2619
  _globals['_DELETEUSERREQUEST']._serialized_end=2654
  _globals['_DELETEUSERRESPONSE']._serialized_start=2656
  _globals['_DELETEUSERRESPONSE']._serialized_end=2676
  _globals['_UPDATEUSERREQUEST']._serialized_start=2679
  _globals['_UPDATEUSERREQUEST']._serialized_end=2816
  _globals['_UPDATEUSERRESPONSE']._serialized_start=2818
  _globals['_UPDATEUSERRESPONSE']._serialized_end=2838
  _globals['_GETMACHINEUSERAUTHTOKENREQUEST']._serialized_start=2840
  _globals['_GETMACHINEUSERAUTHTOKENREQUEST']._serialized_end=2888
  _globals['_GETMACHINEUSERAUTHTOKENRESPONSE']._serialized_start=2890
  _globals['_GETMACHINEUSERAUTHTOKENRESPONSE']._serialized_end=2973
  _globals['_REFRESHMACHINEUSERAUTHTOKENREQUEST']._serialized_start=2975
  _globals['_REFRESHMACHINEUSERAUTHTOKENREQUEST']._serialized_end=3027
  _globals['_REFRESHMACHINEUSERAUTHTOKENRESPONSE']._serialized_start=3029
  _globals['_REFRESHMACHINEUSERAUTHTOKENRESPONSE']._serialized_end=3116
  _globals['_GETUSEREXTERNALIDSREQUEST']._serialized_start=3118
  _globals['_GETUSEREXTERNALIDSREQUEST']._serialized_end=3161
  _globals['_GETUSEREXTERNALIDSRESPONSE']._serialized_start=3163
  _globals['_GETUSEREXTERNALIDSRESPONSE']._serialized_end=3257
  _globals['_MAPUSERTOEXTERNALIDREQUEST']._serialized_start=3260
  _globals['_MAPUSERTOEXTERNALIDREQUEST']._serialized_end=3403
  _globals['_MAPUSERTOEXTERNALIDRESPONSE']._serialized_start=3405
  _globals['_MAPUSERTOEXTERNALIDRESPONSE']._serialized_end=3434
  _globals['_DELETEEXTERNALIDMAPPINGREQUEST']._serialized_start=3436
  _globals['_DELETEEXTERNALIDMAPPINGREQUEST']._serialized_end=3499
  _globals['_DELETEEXTERNALIDMAPPINGRESPONSE']._serialized_start=3501
  _globals['_DELETEEXTERNALIDMAPPINGRESPONSE']._serialized_end=3534
  _globals['_USERSERVICE']._serialized_start=3537
  _globals['_USERSERVICE']._serialized_end=4539
  _globals['_GROUPSERVICE']._serialized_start=4542
  _globals['_GROUPSERVICE']._serialized_end=5227
# @@protoc_insertion_point(module_scope)
