# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: admin/v1/encryption.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19\x61\x64min/v1/encryption.proto\x12\x08\x61\x64min.v1\"\xa2\x01\n1CreateOrUpdateDefaultFieldEncryptionPolicyRequest\x12\x1c\n\nkms_key_id\x18\x01 \x01(\tR\x08kmsKeyId\x12%\n\x0e\x65ncryption_alg\x18\x02 \x01(\tR\rencryptionAlg\x12(\n\x10\x64\x61ta_key_storage\x18\x03 \x01(\tR\x0e\x64\x61taKeyStorage\"\xa3\x01\n2CreateOrUpdateDefaultFieldEncryptionPolicyResponse\x12m\n\x1f\x64\x65\x66\x61ult_field_encryption_policy\x18\x01 \x01(\x0b\x32&.admin.v1.DefaultFieldEncryptionPolicyR\x1c\x64\x65\x66\x61ultFieldEncryptionPolicy\"(\n&GetDefaultFieldEncryptionPolicyRequest\"\x98\x01\n\'GetDefaultFieldEncryptionPolicyResponse\x12m\n\x1f\x64\x65\x66\x61ult_field_encryption_policy\x18\x01 \x01(\x0b\x32&.admin.v1.DefaultFieldEncryptionPolicyR\x1c\x64\x65\x66\x61ultFieldEncryptionPolicy\"\xac\x01\n\x1c\x44\x65\x66\x61ultFieldEncryptionPolicy\x12\x1c\n\nkms_key_id\x18\x01 \x01(\tR\x08kmsKeyId\x12%\n\x0e\x65ncryption_alg\x18\x02 \x01(\tR\rencryptionAlg\x12(\n\x10\x64\x61ta_key_storage\x18\x03 \x01(\tR\x0e\x64\x61taKeyStorage\x12\x1d\n\nupdated_at\x18\x05 \x01(\x03R\tupdatedAt\"\x9f\x01\n\x1c\x43reateFieldEncryptionRequest\x12\x12\n\x04path\x18\x01 \x01(\tR\x04path\x12\x1f\n\x0bkey_storage\x18\x02 \x01(\tR\nkeyStorage\x12\x15\n\x06key_id\x18\x03 \x01(\tR\x05keyId\x12\x10\n\x03\x61lg\x18\x04 \x01(\tR\x03\x61lg\x12!\n\x0c\x64\x61tastore_id\x18\x05 \x01(\tR\x0b\x64\x61tastoreId\"e\n\x1d\x43reateFieldEncryptionResponse\x12\x44\n\x10\x66ield_encryption\x18\x01 \x01(\x0b\x32\x19.admin.v1.FieldEncryptionR\x0f\x66ieldEncryption\"J\n%GetFieldEncryptionsByDatastoreRequest\x12!\n\x0c\x64\x61tastore_id\x18\x01 \x01(\tR\x0b\x64\x61tastoreId\"p\n&GetFieldEncryptionsByDatastoreResponse\x12\x46\n\x11\x66ield_encryptions\x18\x01 \x03(\x0b\x32\x19.admin.v1.FieldEncryptionR\x10\x66ieldEncryptions\"q\n\x1c\x44\x65leteFieldEncryptionRequest\x12!\n\x0c\x64\x61tastore_id\x18\x01 \x01(\tR\x0b\x64\x61tastoreId\x12.\n\x13\x66ield_encryption_id\x18\x02 \x01(\tR\x11\x66ieldEncryptionId\"B\n\x1d\x44\x65leteFieldEncryptionResponse\x12!\n\x0c\x64\x61tastore_id\x18\x01 \x01(\tR\x0b\x64\x61tastoreId\"\xc5\x01\n\x0f\x46ieldEncryption\x12!\n\x0c\x64\x61tastore_id\x18\x01 \x01(\tR\x0b\x64\x61tastoreId\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x12\n\x04path\x18\x03 \x01(\tR\x04path\x12\x1f\n\x0bkey_storage\x18\x04 \x01(\tR\nkeyStorage\x12\x15\n\x06key_id\x18\x05 \x01(\tR\x05keyId\x12\x1d\n\nkey_region\x18\x06 \x01(\tR\tkeyRegion\x12\x10\n\x03\x61lg\x18\x07 \x01(\tR\x03\x61lg2\xd5\x02\n\x1c\x46ieldEncryptionPolicyService\x12\xa9\x01\n*CreateOrUpdateDefaultFieldEncryptionPolicy\x12;.admin.v1.CreateOrUpdateDefaultFieldEncryptionPolicyRequest\x1a<.admin.v1.CreateOrUpdateDefaultFieldEncryptionPolicyResponse\"\x00\x12\x88\x01\n\x1fGetDefaultFieldEncryptionPolicy\x12\x30.admin.v1.GetDefaultFieldEncryptionPolicyRequest\x1a\x31.admin.v1.GetDefaultFieldEncryptionPolicyResponse\"\x00\x32\xf8\x02\n\x16\x46ieldEncryptionService\x12j\n\x15\x43reateFieldEncryption\x12&.admin.v1.CreateFieldEncryptionRequest\x1a\'.admin.v1.CreateFieldEncryptionResponse\"\x00\x12\x85\x01\n\x1eGetFieldEncryptionsByDatastore\x12/.admin.v1.GetFieldEncryptionsByDatastoreRequest\x1a\x30.admin.v1.GetFieldEncryptionsByDatastoreResponse\"\x00\x12j\n\x15\x44\x65leteFieldEncryption\x12&.admin.v1.DeleteFieldEncryptionRequest\x1a\'.admin.v1.DeleteFieldEncryptionResponse\"\x00\x42\xaa\x01\n\x0c\x63om.admin.v1B\x0f\x45ncryptionProtoP\x01ZHgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1;adminv1\xa2\x02\x03\x41XX\xaa\x02\x08\x41\x64min.V1\xca\x02\x08\x41\x64min\\V1\xe2\x02\x14\x41\x64min\\V1\\GPBMetadata\xea\x02\tAdmin::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.encryption_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\014com.admin.v1B\017EncryptionProtoP\001ZHgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1;adminv1\242\002\003AXX\252\002\010Admin.V1\312\002\010Admin\\V1\342\002\024Admin\\V1\\GPBMetadata\352\002\tAdmin::V1'
  _globals['_CREATEORUPDATEDEFAULTFIELDENCRYPTIONPOLICYREQUEST']._serialized_start=40
  _globals['_CREATEORUPDATEDEFAULTFIELDENCRYPTIONPOLICYREQUEST']._serialized_end=202
  _globals['_CREATEORUPDATEDEFAULTFIELDENCRYPTIONPOLICYRESPONSE']._serialized_start=205
  _globals['_CREATEORUPDATEDEFAULTFIELDENCRYPTIONPOLICYRESPONSE']._serialized_end=368
  _globals['_GETDEFAULTFIELDENCRYPTIONPOLICYREQUEST']._serialized_start=370
  _globals['_GETDEFAULTFIELDENCRYPTIONPOLICYREQUEST']._serialized_end=410
  _globals['_GETDEFAULTFIELDENCRYPTIONPOLICYRESPONSE']._serialized_start=413
  _globals['_GETDEFAULTFIELDENCRYPTIONPOLICYRESPONSE']._serialized_end=565
  _globals['_DEFAULTFIELDENCRYPTIONPOLICY']._serialized_start=568
  _globals['_DEFAULTFIELDENCRYPTIONPOLICY']._serialized_end=740
  _globals['_CREATEFIELDENCRYPTIONREQUEST']._serialized_start=743
  _globals['_CREATEFIELDENCRYPTIONREQUEST']._serialized_end=902
  _globals['_CREATEFIELDENCRYPTIONRESPONSE']._serialized_start=904
  _globals['_CREATEFIELDENCRYPTIONRESPONSE']._serialized_end=1005
  _globals['_GETFIELDENCRYPTIONSBYDATASTOREREQUEST']._serialized_start=1007
  _globals['_GETFIELDENCRYPTIONSBYDATASTOREREQUEST']._serialized_end=1081
  _globals['_GETFIELDENCRYPTIONSBYDATASTORERESPONSE']._serialized_start=1083
  _globals['_GETFIELDENCRYPTIONSBYDATASTORERESPONSE']._serialized_end=1195
  _globals['_DELETEFIELDENCRYPTIONREQUEST']._serialized_start=1197
  _globals['_DELETEFIELDENCRYPTIONREQUEST']._serialized_end=1310
  _globals['_DELETEFIELDENCRYPTIONRESPONSE']._serialized_start=1312
  _globals['_DELETEFIELDENCRYPTIONRESPONSE']._serialized_end=1378
  _globals['_FIELDENCRYPTION']._serialized_start=1381
  _globals['_FIELDENCRYPTION']._serialized_end=1578
  _globals['_FIELDENCRYPTIONPOLICYSERVICE']._serialized_start=1581
  _globals['_FIELDENCRYPTIONPOLICYSERVICE']._serialized_end=1922
  _globals['_FIELDENCRYPTIONSERVICE']._serialized_start=1925
  _globals['_FIELDENCRYPTIONSERVICE']._serialized_end=2301
# @@protoc_insertion_point(module_scope)
