# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: admin/v1/types/v1/datastore.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!admin/v1/types/v1/datastore.proto\x12\x11\x61\x64min.v1.types.v1\"\xb3\x04\n\tDatastore\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x1d\n\ncreated_at\x18\x02 \x01(\x03R\tcreatedAt\x12!\n\x0c\x64\x61tastore_id\x18\x03 \x01(\tR\x0b\x64\x61tastoreId\x12\x12\n\x04name\x18\x04 \x01(\tR\x04name\x12+\n\x11original_hostname\x18\x05 \x01(\tR\x10originalHostname\x12\x12\n\x04port\x18\x06 \x01(\x05R\x04port\x12\x1e\n\ntechnology\x18\x07 \x01(\tR\ntechnology\x12/\n\x14health_check_db_name\x18\x08 \x01(\tR\x11healthCheckDbName\x12\x36\n\x17\x64\x65\x66\x61ult_access_behavior\x18\t \x01(\tR\x15\x64\x65\x66\x61ultAccessBehavior\x12:\n\x1a\x64\x62_discovery_job_wait_time\x18\n \x01(\tR\x16\x64\x62\x44iscoveryJobWaitTime\x12<\n\x1b\x64\x62_discovery_native_role_id\x18\x0b \x01(\tR\x17\x64\x62\x44iscoveryNativeRoleId\x12\x1f\n\x08username\x18\x0c \x01(\tH\x00R\x08username\x88\x01\x01\x12\x1f\n\x08password\x18\r \x01(\tH\x01R\x08password\x88\x01\x01\x12 \n\x0b\x65nvironment\x18\x0e \x01(\tR\x0b\x65nvironmentB\x0b\n\t_usernameB\x0b\n\t_passwordB\xe1\x01\n\x15\x63om.admin.v1.types.v1B\x0e\x44\x61tastoreProtoP\x01ZQgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1/types/v1;typesv1\xa2\x02\x03\x41VT\xaa\x02\x11\x41\x64min.V1.Types.V1\xca\x02\x11\x41\x64min\\V1\\Types\\V1\xe2\x02\x1d\x41\x64min\\V1\\Types\\V1\\GPBMetadata\xea\x02\x14\x41\x64min::V1::Types::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.types.v1.datastore_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.admin.v1.types.v1B\016DatastoreProtoP\001ZQgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1/types/v1;typesv1\242\002\003AVT\252\002\021Admin.V1.Types.V1\312\002\021Admin\\V1\\Types\\V1\342\002\035Admin\\V1\\Types\\V1\\GPBMetadata\352\002\024Admin::V1::Types::V1'
  _globals['_DATASTORE']._serialized_start=57
  _globals['_DATASTORE']._serialized_end=620
# @@protoc_insertion_point(module_scope)
