# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import inventory_pb2 as admin_dot_v1_dot_inventory__pb2


class InventoryServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetInventoryHierarchical = channel.unary_unary(
                '/admin.v1.InventoryService/GetInventoryHierarchical',
                request_serializer=admin_dot_v1_dot_inventory__pb2.GetInventoryHierarchicalRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_inventory__pb2.GetInventoryHierarchicalResponse.FromString,
                )
        self.GetInventory = channel.unary_unary(
                '/admin.v1.InventoryService/GetInventory',
                request_serializer=admin_dot_v1_dot_inventory__pb2.GetInventoryRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_inventory__pb2.GetInventoryResponse.FromString,
                )
        self.GetInventoryFlat = channel.unary_unary(
                '/admin.v1.InventoryService/GetInventoryFlat',
                request_serializer=admin_dot_v1_dot_inventory__pb2.GetInventoryFlatRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_inventory__pb2.GetInventoryFlatResponse.FromString,
                )
        self.GetInventoryFlatOld = channel.unary_unary(
                '/admin.v1.InventoryService/GetInventoryFlatOld',
                request_serializer=admin_dot_v1_dot_inventory__pb2.GetInventoryFlatOldRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_inventory__pb2.GetInventoryFlatOldResponse.FromString,
                )
        self.GetInventoryObject = channel.unary_unary(
                '/admin.v1.InventoryService/GetInventoryObject',
                request_serializer=admin_dot_v1_dot_inventory__pb2.GetInventoryObjectRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_inventory__pb2.GetInventoryObjectResponse.FromString,
                )
        self.UpdateColumnLockStatus = channel.unary_unary(
                '/admin.v1.InventoryService/UpdateColumnLockStatus',
                request_serializer=admin_dot_v1_dot_inventory__pb2.UpdateColumnLockStatusRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_inventory__pb2.UpdateColumnLockStatusResponse.FromString,
                )
        self.UpdateColumnDataLabel = channel.unary_unary(
                '/admin.v1.InventoryService/UpdateColumnDataLabel',
                request_serializer=admin_dot_v1_dot_inventory__pb2.UpdateColumnDataLabelRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_inventory__pb2.UpdateColumnDataLabelResponse.FromString,
                )
        self.UpdateColumnFieldEncryption = channel.unary_unary(
                '/admin.v1.InventoryService/UpdateColumnFieldEncryption',
                request_serializer=admin_dot_v1_dot_inventory__pb2.UpdateColumnFieldEncryptionRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_inventory__pb2.UpdateColumnFieldEncryptionResponse.FromString,
                )
        self.UpdateInventoryObjectTags = channel.unary_unary(
                '/admin.v1.InventoryService/UpdateInventoryObjectTags',
                request_serializer=admin_dot_v1_dot_inventory__pb2.UpdateInventoryObjectTagsRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_inventory__pb2.UpdateInventoryObjectTagsResponse.FromString,
                )
        self.CreateInventoryObject = channel.unary_unary(
                '/admin.v1.InventoryService/CreateInventoryObject',
                request_serializer=admin_dot_v1_dot_inventory__pb2.CreateInventoryObjectRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_inventory__pb2.CreateInventoryObjectResponse.FromString,
                )
        self.DeleteInventoryObject = channel.unary_unary(
                '/admin.v1.InventoryService/DeleteInventoryObject',
                request_serializer=admin_dot_v1_dot_inventory__pb2.DeleteInventoryObjectRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_inventory__pb2.DeleteInventoryObjectResponse.FromString,
                )
        self.CreateInventoryTag = channel.unary_unary(
                '/admin.v1.InventoryService/CreateInventoryTag',
                request_serializer=admin_dot_v1_dot_inventory__pb2.CreateInventoryTagRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_inventory__pb2.CreateInventoryTagResponse.FromString,
                )
        self.GetInventoryTags = channel.unary_unary(
                '/admin.v1.InventoryService/GetInventoryTags',
                request_serializer=admin_dot_v1_dot_inventory__pb2.GetInventoryTagsRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_inventory__pb2.GetInventoryTagsResponse.FromString,
                )
        self.DeleteInventoryTag = channel.unary_unary(
                '/admin.v1.InventoryService/DeleteInventoryTag',
                request_serializer=admin_dot_v1_dot_inventory__pb2.DeleteInventoryTagRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_inventory__pb2.DeleteInventoryTagResponse.FromString,
                )
        self.GetInventoryMetrics = channel.unary_unary(
                '/admin.v1.InventoryService/GetInventoryMetrics',
                request_serializer=admin_dot_v1_dot_inventory__pb2.GetInventoryMetricsRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_inventory__pb2.GetInventoryMetricsResponse.FromString,
                )
        self.CreateDataDomain = channel.unary_unary(
                '/admin.v1.InventoryService/CreateDataDomain',
                request_serializer=admin_dot_v1_dot_inventory__pb2.CreateDataDomainRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_inventory__pb2.CreateDataDomainResponse.FromString,
                )
        self.GetDataDomains = channel.unary_unary(
                '/admin.v1.InventoryService/GetDataDomains',
                request_serializer=admin_dot_v1_dot_inventory__pb2.GetDataDomainsRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_inventory__pb2.GetDataDomainsResponse.FromString,
                )
        self.GetDataDomainById = channel.unary_unary(
                '/admin.v1.InventoryService/GetDataDomainById',
                request_serializer=admin_dot_v1_dot_inventory__pb2.GetDataDomainByIdRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_inventory__pb2.GetDataDomainByIdResponse.FromString,
                )
        self.UpdateDataDomain = channel.unary_unary(
                '/admin.v1.InventoryService/UpdateDataDomain',
                request_serializer=admin_dot_v1_dot_inventory__pb2.UpdateDataDomainRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_inventory__pb2.UpdateDataDomainResponse.FromString,
                )
        self.DeleteDataDomain = channel.unary_unary(
                '/admin.v1.InventoryService/DeleteDataDomain',
                request_serializer=admin_dot_v1_dot_inventory__pb2.DeleteDataDomainRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_inventory__pb2.DeleteDataDomainResponse.FromString,
                )


class InventoryServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetInventoryHierarchical(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetInventory(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetInventoryFlat(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetInventoryFlatOld(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetInventoryObject(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateColumnLockStatus(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateColumnDataLabel(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateColumnFieldEncryption(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateInventoryObjectTags(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateInventoryObject(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteInventoryObject(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateInventoryTag(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetInventoryTags(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteInventoryTag(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetInventoryMetrics(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateDataDomain(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDataDomains(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDataDomainById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateDataDomain(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteDataDomain(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_InventoryServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetInventoryHierarchical': grpc.unary_unary_rpc_method_handler(
                    servicer.GetInventoryHierarchical,
                    request_deserializer=admin_dot_v1_dot_inventory__pb2.GetInventoryHierarchicalRequest.FromString,
                    response_serializer=admin_dot_v1_dot_inventory__pb2.GetInventoryHierarchicalResponse.SerializeToString,
            ),
            'GetInventory': grpc.unary_unary_rpc_method_handler(
                    servicer.GetInventory,
                    request_deserializer=admin_dot_v1_dot_inventory__pb2.GetInventoryRequest.FromString,
                    response_serializer=admin_dot_v1_dot_inventory__pb2.GetInventoryResponse.SerializeToString,
            ),
            'GetInventoryFlat': grpc.unary_unary_rpc_method_handler(
                    servicer.GetInventoryFlat,
                    request_deserializer=admin_dot_v1_dot_inventory__pb2.GetInventoryFlatRequest.FromString,
                    response_serializer=admin_dot_v1_dot_inventory__pb2.GetInventoryFlatResponse.SerializeToString,
            ),
            'GetInventoryFlatOld': grpc.unary_unary_rpc_method_handler(
                    servicer.GetInventoryFlatOld,
                    request_deserializer=admin_dot_v1_dot_inventory__pb2.GetInventoryFlatOldRequest.FromString,
                    response_serializer=admin_dot_v1_dot_inventory__pb2.GetInventoryFlatOldResponse.SerializeToString,
            ),
            'GetInventoryObject': grpc.unary_unary_rpc_method_handler(
                    servicer.GetInventoryObject,
                    request_deserializer=admin_dot_v1_dot_inventory__pb2.GetInventoryObjectRequest.FromString,
                    response_serializer=admin_dot_v1_dot_inventory__pb2.GetInventoryObjectResponse.SerializeToString,
            ),
            'UpdateColumnLockStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateColumnLockStatus,
                    request_deserializer=admin_dot_v1_dot_inventory__pb2.UpdateColumnLockStatusRequest.FromString,
                    response_serializer=admin_dot_v1_dot_inventory__pb2.UpdateColumnLockStatusResponse.SerializeToString,
            ),
            'UpdateColumnDataLabel': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateColumnDataLabel,
                    request_deserializer=admin_dot_v1_dot_inventory__pb2.UpdateColumnDataLabelRequest.FromString,
                    response_serializer=admin_dot_v1_dot_inventory__pb2.UpdateColumnDataLabelResponse.SerializeToString,
            ),
            'UpdateColumnFieldEncryption': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateColumnFieldEncryption,
                    request_deserializer=admin_dot_v1_dot_inventory__pb2.UpdateColumnFieldEncryptionRequest.FromString,
                    response_serializer=admin_dot_v1_dot_inventory__pb2.UpdateColumnFieldEncryptionResponse.SerializeToString,
            ),
            'UpdateInventoryObjectTags': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateInventoryObjectTags,
                    request_deserializer=admin_dot_v1_dot_inventory__pb2.UpdateInventoryObjectTagsRequest.FromString,
                    response_serializer=admin_dot_v1_dot_inventory__pb2.UpdateInventoryObjectTagsResponse.SerializeToString,
            ),
            'CreateInventoryObject': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateInventoryObject,
                    request_deserializer=admin_dot_v1_dot_inventory__pb2.CreateInventoryObjectRequest.FromString,
                    response_serializer=admin_dot_v1_dot_inventory__pb2.CreateInventoryObjectResponse.SerializeToString,
            ),
            'DeleteInventoryObject': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteInventoryObject,
                    request_deserializer=admin_dot_v1_dot_inventory__pb2.DeleteInventoryObjectRequest.FromString,
                    response_serializer=admin_dot_v1_dot_inventory__pb2.DeleteInventoryObjectResponse.SerializeToString,
            ),
            'CreateInventoryTag': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateInventoryTag,
                    request_deserializer=admin_dot_v1_dot_inventory__pb2.CreateInventoryTagRequest.FromString,
                    response_serializer=admin_dot_v1_dot_inventory__pb2.CreateInventoryTagResponse.SerializeToString,
            ),
            'GetInventoryTags': grpc.unary_unary_rpc_method_handler(
                    servicer.GetInventoryTags,
                    request_deserializer=admin_dot_v1_dot_inventory__pb2.GetInventoryTagsRequest.FromString,
                    response_serializer=admin_dot_v1_dot_inventory__pb2.GetInventoryTagsResponse.SerializeToString,
            ),
            'DeleteInventoryTag': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteInventoryTag,
                    request_deserializer=admin_dot_v1_dot_inventory__pb2.DeleteInventoryTagRequest.FromString,
                    response_serializer=admin_dot_v1_dot_inventory__pb2.DeleteInventoryTagResponse.SerializeToString,
            ),
            'GetInventoryMetrics': grpc.unary_unary_rpc_method_handler(
                    servicer.GetInventoryMetrics,
                    request_deserializer=admin_dot_v1_dot_inventory__pb2.GetInventoryMetricsRequest.FromString,
                    response_serializer=admin_dot_v1_dot_inventory__pb2.GetInventoryMetricsResponse.SerializeToString,
            ),
            'CreateDataDomain': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateDataDomain,
                    request_deserializer=admin_dot_v1_dot_inventory__pb2.CreateDataDomainRequest.FromString,
                    response_serializer=admin_dot_v1_dot_inventory__pb2.CreateDataDomainResponse.SerializeToString,
            ),
            'GetDataDomains': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDataDomains,
                    request_deserializer=admin_dot_v1_dot_inventory__pb2.GetDataDomainsRequest.FromString,
                    response_serializer=admin_dot_v1_dot_inventory__pb2.GetDataDomainsResponse.SerializeToString,
            ),
            'GetDataDomainById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDataDomainById,
                    request_deserializer=admin_dot_v1_dot_inventory__pb2.GetDataDomainByIdRequest.FromString,
                    response_serializer=admin_dot_v1_dot_inventory__pb2.GetDataDomainByIdResponse.SerializeToString,
            ),
            'UpdateDataDomain': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateDataDomain,
                    request_deserializer=admin_dot_v1_dot_inventory__pb2.UpdateDataDomainRequest.FromString,
                    response_serializer=admin_dot_v1_dot_inventory__pb2.UpdateDataDomainResponse.SerializeToString,
            ),
            'DeleteDataDomain': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteDataDomain,
                    request_deserializer=admin_dot_v1_dot_inventory__pb2.DeleteDataDomainRequest.FromString,
                    response_serializer=admin_dot_v1_dot_inventory__pb2.DeleteDataDomainResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'admin.v1.InventoryService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class InventoryService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetInventoryHierarchical(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.InventoryService/GetInventoryHierarchical',
            admin_dot_v1_dot_inventory__pb2.GetInventoryHierarchicalRequest.SerializeToString,
            admin_dot_v1_dot_inventory__pb2.GetInventoryHierarchicalResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetInventory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.InventoryService/GetInventory',
            admin_dot_v1_dot_inventory__pb2.GetInventoryRequest.SerializeToString,
            admin_dot_v1_dot_inventory__pb2.GetInventoryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetInventoryFlat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.InventoryService/GetInventoryFlat',
            admin_dot_v1_dot_inventory__pb2.GetInventoryFlatRequest.SerializeToString,
            admin_dot_v1_dot_inventory__pb2.GetInventoryFlatResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetInventoryFlatOld(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.InventoryService/GetInventoryFlatOld',
            admin_dot_v1_dot_inventory__pb2.GetInventoryFlatOldRequest.SerializeToString,
            admin_dot_v1_dot_inventory__pb2.GetInventoryFlatOldResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetInventoryObject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.InventoryService/GetInventoryObject',
            admin_dot_v1_dot_inventory__pb2.GetInventoryObjectRequest.SerializeToString,
            admin_dot_v1_dot_inventory__pb2.GetInventoryObjectResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateColumnLockStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.InventoryService/UpdateColumnLockStatus',
            admin_dot_v1_dot_inventory__pb2.UpdateColumnLockStatusRequest.SerializeToString,
            admin_dot_v1_dot_inventory__pb2.UpdateColumnLockStatusResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateColumnDataLabel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.InventoryService/UpdateColumnDataLabel',
            admin_dot_v1_dot_inventory__pb2.UpdateColumnDataLabelRequest.SerializeToString,
            admin_dot_v1_dot_inventory__pb2.UpdateColumnDataLabelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateColumnFieldEncryption(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.InventoryService/UpdateColumnFieldEncryption',
            admin_dot_v1_dot_inventory__pb2.UpdateColumnFieldEncryptionRequest.SerializeToString,
            admin_dot_v1_dot_inventory__pb2.UpdateColumnFieldEncryptionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateInventoryObjectTags(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.InventoryService/UpdateInventoryObjectTags',
            admin_dot_v1_dot_inventory__pb2.UpdateInventoryObjectTagsRequest.SerializeToString,
            admin_dot_v1_dot_inventory__pb2.UpdateInventoryObjectTagsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateInventoryObject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.InventoryService/CreateInventoryObject',
            admin_dot_v1_dot_inventory__pb2.CreateInventoryObjectRequest.SerializeToString,
            admin_dot_v1_dot_inventory__pb2.CreateInventoryObjectResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteInventoryObject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.InventoryService/DeleteInventoryObject',
            admin_dot_v1_dot_inventory__pb2.DeleteInventoryObjectRequest.SerializeToString,
            admin_dot_v1_dot_inventory__pb2.DeleteInventoryObjectResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateInventoryTag(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.InventoryService/CreateInventoryTag',
            admin_dot_v1_dot_inventory__pb2.CreateInventoryTagRequest.SerializeToString,
            admin_dot_v1_dot_inventory__pb2.CreateInventoryTagResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetInventoryTags(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.InventoryService/GetInventoryTags',
            admin_dot_v1_dot_inventory__pb2.GetInventoryTagsRequest.SerializeToString,
            admin_dot_v1_dot_inventory__pb2.GetInventoryTagsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteInventoryTag(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.InventoryService/DeleteInventoryTag',
            admin_dot_v1_dot_inventory__pb2.DeleteInventoryTagRequest.SerializeToString,
            admin_dot_v1_dot_inventory__pb2.DeleteInventoryTagResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetInventoryMetrics(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.InventoryService/GetInventoryMetrics',
            admin_dot_v1_dot_inventory__pb2.GetInventoryMetricsRequest.SerializeToString,
            admin_dot_v1_dot_inventory__pb2.GetInventoryMetricsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateDataDomain(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.InventoryService/CreateDataDomain',
            admin_dot_v1_dot_inventory__pb2.CreateDataDomainRequest.SerializeToString,
            admin_dot_v1_dot_inventory__pb2.CreateDataDomainResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDataDomains(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.InventoryService/GetDataDomains',
            admin_dot_v1_dot_inventory__pb2.GetDataDomainsRequest.SerializeToString,
            admin_dot_v1_dot_inventory__pb2.GetDataDomainsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDataDomainById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.InventoryService/GetDataDomainById',
            admin_dot_v1_dot_inventory__pb2.GetDataDomainByIdRequest.SerializeToString,
            admin_dot_v1_dot_inventory__pb2.GetDataDomainByIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateDataDomain(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.InventoryService/UpdateDataDomain',
            admin_dot_v1_dot_inventory__pb2.UpdateDataDomainRequest.SerializeToString,
            admin_dot_v1_dot_inventory__pb2.UpdateDataDomainResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteDataDomain(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.InventoryService/DeleteDataDomain',
            admin_dot_v1_dot_inventory__pb2.DeleteDataDomainRequest.SerializeToString,
            admin_dot_v1_dot_inventory__pb2.DeleteDataDomainResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
