# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: admin/v1/integration_cloud.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .types.v1 import flat_dataplane_pb2 as admin_dot_v1_dot_types_dot_v1_dot_flat__dataplane__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n admin/v1/integration_cloud.proto\x12\x08\x61\x64min.v1\x1a&admin/v1/types/v1/flat_dataplane.proto\"\xbc\x01\n\x16\x43reateDataplaneRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x16\n\x06region\x18\x02 \x01(\tR\x06region\x12(\n\x10\x63loud_account_id\x18\x03 \x01(\tR\x0e\x63loudAccountId\x12+\n\x11\x61vailability_zone\x18\x04 \x01(\x05R\x10\x61vailabilityZone\x12\x1f\n\x0bvpc_peering\x18\x05 \x01(\x08R\nvpcPeering\"Y\n\x17\x43reateDataplaneResponse\x12>\n\tdataplane\x18\x01 \x01(\x0b\x32 .admin.v1.types.v1.FlatDataplaneR\tdataplane\")\n\x17GetDataplaneByIdRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"Z\n\x18GetDataplaneByIdResponse\x12>\n\tdataplane\x18\x01 \x01(\x0b\x32 .admin.v1.types.v1.FlatDataplaneR\tdataplane\"(\n\x16\x44\x65leteDataplaneRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"\x19\n\x17\x44\x65leteDataplaneResponse\"\xe0\x01\n\x1c\x43reateDataplaneRoutesRequest\x12!\n\x0c\x64\x61taplane_id\x18\x01 \x01(\tR\x0b\x64\x61taplaneId\x12\x34\n\x16\x64\x65stination_cidr_block\x18\x02 \x01(\tR\x14\x64\x65stinationCidrBlock\x12,\n\x12transit_gateway_id\x18\x03 \x01(\tR\x10transitGatewayId\x12\x39\n\x19vpc_peering_connection_id\x18\x04 \x01(\tR\x16vpcPeeringConnectionId\"|\n\x1d\x43reateDataplaneRoutesResponse\x12[\n\x10\x64\x61taplane_routes\x18\x01 \x01(\x0b\x32\x30.admin.v1.types.v1.DataplaneTransitGatewayRoutesR\x0f\x64\x61taplaneRoutes\"/\n\x1dGetDataplaneRoutesByIdRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"}\n\x1eGetDataplaneRoutesByIdResponse\x12[\n\x10\x64\x61taplane_routes\x18\x01 \x01(\x0b\x32\x30.admin.v1.types.v1.DataplaneTransitGatewayRoutesR\x0f\x64\x61taplaneRoutes\".\n\x1c\x44\x65leteDataplaneRoutesRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"9\n\x1d\x44\x65leteDataplaneRoutesResponse\x12\x18\n\x07message\x18\x01 \x01(\tR\x07message\"\x83\x01\n!CreateAwsConnectionSessionRequest\x12,\n\x12\x63loud_account_name\x18\x01 \x01(\tR\x10\x63loudAccountName\x12\x30\n\x14\x63loud_account_region\x18\x02 \x01(\tR\x12\x63loudAccountRegion\"v\n\"CreateAwsConnectionSessionResponse\x12P\n\x11\x63loud_integration\x18\x01 \x01(\x0b\x32#.admin.v1.types.v1.CloudIntegrationR\x10\x63loudIntegration\"3\n!DeleteAwsConnectionSessionRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"8\n&GetIntegrationsCloudAccountByIdRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"p\n\'GetIntegrationsCloudAccountByIdResponse\x12\x45\n\x0bintegration\x18\x01 \x01(\x0b\x32#.admin.v1.types.v1.CloudIntegrationR\x0bintegration\"%\n#GetIntegrationsCloudAccountsRequest\"o\n$GetIntegrationsCloudAccountsResponse\x12G\n\x0cintegrations\x18\x01 \x03(\x0b\x32#.admin.v1.types.v1.CloudIntegrationR\x0cintegrations\"B\n!CreateGcpConnectionSessionRequest\x12\x1d\n\nproject_id\x18\x01 \x01(\tR\tprojectId\"$\n\"CreateGcpConnectionSessionResponse\"$\n\"DeleteAwsConnectionSessionResponse\"U\n)GetDataplaneStacksByCloudAccountIdRequest\x12(\n\x10\x63loud_account_id\x18\x01 \x01(\tR\x0e\x63loudAccountId\"n\n*GetDataplaneStacksByCloudAccountIdResponse\x12@\n\ndataplanes\x18\x01 \x03(\x0b\x32 .admin.v1.types.v1.FlatDataplaneR\ndataplanes2\xdf\n\n\x0c\x43loudService\x12V\n\x0f\x43reateDataplane\x12 .admin.v1.CreateDataplaneRequest\x1a!.admin.v1.CreateDataplaneResponse\x12Y\n\x10GetDataplaneById\x12!.admin.v1.GetDataplaneByIdRequest\x1a\".admin.v1.GetDataplaneByIdResponse\x12V\n\x0f\x44\x65leteDataplane\x12 .admin.v1.DeleteDataplaneRequest\x1a!.admin.v1.DeleteDataplaneResponse\x12h\n\x15\x43reateDataplaneRoutes\x12&.admin.v1.CreateDataplaneRoutesRequest\x1a\'.admin.v1.CreateDataplaneRoutesResponse\x12k\n\x16GetDataplaneRoutesById\x12\'.admin.v1.GetDataplaneRoutesByIdRequest\x1a(.admin.v1.GetDataplaneRoutesByIdResponse\x12h\n\x15\x44\x65leteDataplaneRoutes\x12&.admin.v1.DeleteDataplaneRoutesRequest\x1a\'.admin.v1.DeleteDataplaneRoutesResponse\x12\x8f\x01\n\"GetDataplaneStacksByCloudAccountId\x12\x33.admin.v1.GetDataplaneStacksByCloudAccountIdRequest\x1a\x34.admin.v1.GetDataplaneStacksByCloudAccountIdResponse\x12w\n\x1a\x43reateAwsConnectionSession\x12+.admin.v1.CreateAwsConnectionSessionRequest\x1a,.admin.v1.CreateAwsConnectionSessionResponse\x12w\n\x1a\x44\x65leteAwsConnectionSession\x12+.admin.v1.DeleteAwsConnectionSessionRequest\x1a,.admin.v1.DeleteAwsConnectionSessionResponse\x12\x86\x01\n\x1fGetIntegrationsCloudAccountById\x12\x30.admin.v1.GetIntegrationsCloudAccountByIdRequest\x1a\x31.admin.v1.GetIntegrationsCloudAccountByIdResponse\x12}\n\x1cGetIntegrationsCloudAccounts\x12-.admin.v1.GetIntegrationsCloudAccountsRequest\x1a..admin.v1.GetIntegrationsCloudAccountsResponse\x12w\n\x1a\x43reateGcpConnectionSession\x12+.admin.v1.CreateGcpConnectionSessionRequest\x1a,.admin.v1.CreateGcpConnectionSessionResponseB\xb0\x01\n\x0c\x63om.admin.v1B\x15IntegrationCloudProtoP\x01ZHgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1;adminv1\xa2\x02\x03\x41XX\xaa\x02\x08\x41\x64min.V1\xca\x02\x08\x41\x64min\\V1\xe2\x02\x14\x41\x64min\\V1\\GPBMetadata\xea\x02\tAdmin::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.integration_cloud_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\014com.admin.v1B\025IntegrationCloudProtoP\001ZHgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1;adminv1\242\002\003AXX\252\002\010Admin.V1\312\002\010Admin\\V1\342\002\024Admin\\V1\\GPBMetadata\352\002\tAdmin::V1'
  _globals['_CREATEDATAPLANEREQUEST']._serialized_start=87
  _globals['_CREATEDATAPLANEREQUEST']._serialized_end=275
  _globals['_CREATEDATAPLANERESPONSE']._serialized_start=277
  _globals['_CREATEDATAPLANERESPONSE']._serialized_end=366
  _globals['_GETDATAPLANEBYIDREQUEST']._serialized_start=368
  _globals['_GETDATAPLANEBYIDREQUEST']._serialized_end=409
  _globals['_GETDATAPLANEBYIDRESPONSE']._serialized_start=411
  _globals['_GETDATAPLANEBYIDRESPONSE']._serialized_end=501
  _globals['_DELETEDATAPLANEREQUEST']._serialized_start=503
  _globals['_DELETEDATAPLANEREQUEST']._serialized_end=543
  _globals['_DELETEDATAPLANERESPONSE']._serialized_start=545
  _globals['_DELETEDATAPLANERESPONSE']._serialized_end=570
  _globals['_CREATEDATAPLANEROUTESREQUEST']._serialized_start=573
  _globals['_CREATEDATAPLANEROUTESREQUEST']._serialized_end=797
  _globals['_CREATEDATAPLANEROUTESRESPONSE']._serialized_start=799
  _globals['_CREATEDATAPLANEROUTESRESPONSE']._serialized_end=923
  _globals['_GETDATAPLANEROUTESBYIDREQUEST']._serialized_start=925
  _globals['_GETDATAPLANEROUTESBYIDREQUEST']._serialized_end=972
  _globals['_GETDATAPLANEROUTESBYIDRESPONSE']._serialized_start=974
  _globals['_GETDATAPLANEROUTESBYIDRESPONSE']._serialized_end=1099
  _globals['_DELETEDATAPLANEROUTESREQUEST']._serialized_start=1101
  _globals['_DELETEDATAPLANEROUTESREQUEST']._serialized_end=1147
  _globals['_DELETEDATAPLANEROUTESRESPONSE']._serialized_start=1149
  _globals['_DELETEDATAPLANEROUTESRESPONSE']._serialized_end=1206
  _globals['_CREATEAWSCONNECTIONSESSIONREQUEST']._serialized_start=1209
  _globals['_CREATEAWSCONNECTIONSESSIONREQUEST']._serialized_end=1340
  _globals['_CREATEAWSCONNECTIONSESSIONRESPONSE']._serialized_start=1342
  _globals['_CREATEAWSCONNECTIONSESSIONRESPONSE']._serialized_end=1460
  _globals['_DELETEAWSCONNECTIONSESSIONREQUEST']._serialized_start=1462
  _globals['_DELETEAWSCONNECTIONSESSIONREQUEST']._serialized_end=1513
  _globals['_GETINTEGRATIONSCLOUDACCOUNTBYIDREQUEST']._serialized_start=1515
  _globals['_GETINTEGRATIONSCLOUDACCOUNTBYIDREQUEST']._serialized_end=1571
  _globals['_GETINTEGRATIONSCLOUDACCOUNTBYIDRESPONSE']._serialized_start=1573
  _globals['_GETINTEGRATIONSCLOUDACCOUNTBYIDRESPONSE']._serialized_end=1685
  _globals['_GETINTEGRATIONSCLOUDACCOUNTSREQUEST']._serialized_start=1687
  _globals['_GETINTEGRATIONSCLOUDACCOUNTSREQUEST']._serialized_end=1724
  _globals['_GETINTEGRATIONSCLOUDACCOUNTSRESPONSE']._serialized_start=1726
  _globals['_GETINTEGRATIONSCLOUDACCOUNTSRESPONSE']._serialized_end=1837
  _globals['_CREATEGCPCONNECTIONSESSIONREQUEST']._serialized_start=1839
  _globals['_CREATEGCPCONNECTIONSESSIONREQUEST']._serialized_end=1905
  _globals['_CREATEGCPCONNECTIONSESSIONRESPONSE']._serialized_start=1907
  _globals['_CREATEGCPCONNECTIONSESSIONRESPONSE']._serialized_end=1943
  _globals['_DELETEAWSCONNECTIONSESSIONRESPONSE']._serialized_start=1945
  _globals['_DELETEAWSCONNECTIONSESSIONRESPONSE']._serialized_end=1981
  _globals['_GETDATAPLANESTACKSBYCLOUDACCOUNTIDREQUEST']._serialized_start=1983
  _globals['_GETDATAPLANESTACKSBYCLOUDACCOUNTIDREQUEST']._serialized_end=2068
  _globals['_GETDATAPLANESTACKSBYCLOUDACCOUNTIDRESPONSE']._serialized_start=2070
  _globals['_GETDATAPLANESTACKSBYCLOUDACCOUNTIDRESPONSE']._serialized_end=2180
  _globals['_CLOUDSERVICE']._serialized_start=2183
  _globals['_CLOUDSERVICE']._serialized_end=3558
# @@protoc_insertion_point(module_scope)
