# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import integration_app_pb2 as admin_dot_v1_dot_integration__app__pb2


class AppServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.RefreshIntegrationApps = channel.unary_unary(
                '/admin.v1.AppService/RefreshIntegrationApps',
                request_serializer=admin_dot_v1_dot_integration__app__pb2.RefreshIntegrationAppsRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__app__pb2.RefreshIntegrationAppsResponse.FromString,
                )
        self.GetIntegrationApps = channel.unary_unary(
                '/admin.v1.AppService/GetIntegrationApps',
                request_serializer=admin_dot_v1_dot_integration__app__pb2.GetIntegrationAppsRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__app__pb2.GetIntegrationAppsResponse.FromString,
                )
        self.GetIntegrationById = channel.unary_unary(
                '/admin.v1.AppService/GetIntegrationById',
                request_serializer=admin_dot_v1_dot_integration__app__pb2.GetIntegrationByIdRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__app__pb2.GetIntegrationByIdResponse.FromString,
                )
        self.CreateIntegrationApp = channel.unary_unary(
                '/admin.v1.AppService/CreateIntegrationApp',
                request_serializer=admin_dot_v1_dot_integration__app__pb2.CreateIntegrationAppRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__app__pb2.CreateIntegrationAppResponse.FromString,
                )
        self.DeleteIntegrationApp = channel.unary_unary(
                '/admin.v1.AppService/DeleteIntegrationApp',
                request_serializer=admin_dot_v1_dot_integration__app__pb2.DeleteIntegrationAppRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__app__pb2.DeleteIntegrationAppResponse.FromString,
                )


class AppServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def RefreshIntegrationApps(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetIntegrationApps(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetIntegrationById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateIntegrationApp(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteIntegrationApp(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AppServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'RefreshIntegrationApps': grpc.unary_unary_rpc_method_handler(
                    servicer.RefreshIntegrationApps,
                    request_deserializer=admin_dot_v1_dot_integration__app__pb2.RefreshIntegrationAppsRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__app__pb2.RefreshIntegrationAppsResponse.SerializeToString,
            ),
            'GetIntegrationApps': grpc.unary_unary_rpc_method_handler(
                    servicer.GetIntegrationApps,
                    request_deserializer=admin_dot_v1_dot_integration__app__pb2.GetIntegrationAppsRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__app__pb2.GetIntegrationAppsResponse.SerializeToString,
            ),
            'GetIntegrationById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetIntegrationById,
                    request_deserializer=admin_dot_v1_dot_integration__app__pb2.GetIntegrationByIdRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__app__pb2.GetIntegrationByIdResponse.SerializeToString,
            ),
            'CreateIntegrationApp': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateIntegrationApp,
                    request_deserializer=admin_dot_v1_dot_integration__app__pb2.CreateIntegrationAppRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__app__pb2.CreateIntegrationAppResponse.SerializeToString,
            ),
            'DeleteIntegrationApp': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteIntegrationApp,
                    request_deserializer=admin_dot_v1_dot_integration__app__pb2.DeleteIntegrationAppRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__app__pb2.DeleteIntegrationAppResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'admin.v1.AppService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class AppService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def RefreshIntegrationApps(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.AppService/RefreshIntegrationApps',
            admin_dot_v1_dot_integration__app__pb2.RefreshIntegrationAppsRequest.SerializeToString,
            admin_dot_v1_dot_integration__app__pb2.RefreshIntegrationAppsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetIntegrationApps(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.AppService/GetIntegrationApps',
            admin_dot_v1_dot_integration__app__pb2.GetIntegrationAppsRequest.SerializeToString,
            admin_dot_v1_dot_integration__app__pb2.GetIntegrationAppsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetIntegrationById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.AppService/GetIntegrationById',
            admin_dot_v1_dot_integration__app__pb2.GetIntegrationByIdRequest.SerializeToString,
            admin_dot_v1_dot_integration__app__pb2.GetIntegrationByIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateIntegrationApp(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.AppService/CreateIntegrationApp',
            admin_dot_v1_dot_integration__app__pb2.CreateIntegrationAppRequest.SerializeToString,
            admin_dot_v1_dot_integration__app__pb2.CreateIntegrationAppResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteIntegrationApp(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.AppService/DeleteIntegrationApp',
            admin_dot_v1_dot_integration__app__pb2.DeleteIntegrationAppRequest.SerializeToString,
            admin_dot_v1_dot_integration__app__pb2.DeleteIntegrationAppResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
