# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import integration_log_pb2 as admin_dot_v1_dot_integration__log__pb2


class LogsServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateIntegrationLogs = channel.unary_unary(
                '/admin.v1.LogsService/CreateIntegrationLogs',
                request_serializer=admin_dot_v1_dot_integration__log__pb2.CreateIntegrationLogsRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__log__pb2.CreateIntegrationLogsResponse.FromString,
                )
        self.GetIntegrationLogs = channel.unary_unary(
                '/admin.v1.LogsService/GetIntegrationLogs',
                request_serializer=admin_dot_v1_dot_integration__log__pb2.GetIntegrationLogsRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__log__pb2.GetIntegrationLogsResponse.FromString,
                )
        self.GetIntegrationLogById = channel.unary_unary(
                '/admin.v1.LogsService/GetIntegrationLogById',
                request_serializer=admin_dot_v1_dot_integration__log__pb2.GetIntegrationLogByIdRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__log__pb2.GetIntegrationLogByIdResponse.FromString,
                )
        self.DeleteIntegrationLogs = channel.unary_unary(
                '/admin.v1.LogsService/DeleteIntegrationLogs',
                request_serializer=admin_dot_v1_dot_integration__log__pb2.DeleteIntegrationLogsRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__log__pb2.DeleteIntegrationLogsResponse.FromString,
                )
        self.CreateLogsLinkItem = channel.unary_unary(
                '/admin.v1.LogsService/CreateLogsLinkItem',
                request_serializer=admin_dot_v1_dot_integration__log__pb2.CreateLogsLinkItemRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__log__pb2.CreateLogsLinkItemResponse.FromString,
                )
        self.GetLogsLinkItemById = channel.unary_unary(
                '/admin.v1.LogsService/GetLogsLinkItemById',
                request_serializer=admin_dot_v1_dot_integration__log__pb2.GetLogsLinkItemByIdRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__log__pb2.GetLogsLinkItemByIdResponse.FromString,
                )
        self.DeleteLogsLinkItem = channel.unary_unary(
                '/admin.v1.LogsService/DeleteLogsLinkItem',
                request_serializer=admin_dot_v1_dot_integration__log__pb2.DeleteLogsLinkItemRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__log__pb2.DeleteLogsLinkItemResponse.FromString,
                )


class LogsServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateIntegrationLogs(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetIntegrationLogs(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetIntegrationLogById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteIntegrationLogs(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateLogsLinkItem(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLogsLinkItemById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteLogsLinkItem(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_LogsServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateIntegrationLogs': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateIntegrationLogs,
                    request_deserializer=admin_dot_v1_dot_integration__log__pb2.CreateIntegrationLogsRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__log__pb2.CreateIntegrationLogsResponse.SerializeToString,
            ),
            'GetIntegrationLogs': grpc.unary_unary_rpc_method_handler(
                    servicer.GetIntegrationLogs,
                    request_deserializer=admin_dot_v1_dot_integration__log__pb2.GetIntegrationLogsRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__log__pb2.GetIntegrationLogsResponse.SerializeToString,
            ),
            'GetIntegrationLogById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetIntegrationLogById,
                    request_deserializer=admin_dot_v1_dot_integration__log__pb2.GetIntegrationLogByIdRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__log__pb2.GetIntegrationLogByIdResponse.SerializeToString,
            ),
            'DeleteIntegrationLogs': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteIntegrationLogs,
                    request_deserializer=admin_dot_v1_dot_integration__log__pb2.DeleteIntegrationLogsRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__log__pb2.DeleteIntegrationLogsResponse.SerializeToString,
            ),
            'CreateLogsLinkItem': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateLogsLinkItem,
                    request_deserializer=admin_dot_v1_dot_integration__log__pb2.CreateLogsLinkItemRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__log__pb2.CreateLogsLinkItemResponse.SerializeToString,
            ),
            'GetLogsLinkItemById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLogsLinkItemById,
                    request_deserializer=admin_dot_v1_dot_integration__log__pb2.GetLogsLinkItemByIdRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__log__pb2.GetLogsLinkItemByIdResponse.SerializeToString,
            ),
            'DeleteLogsLinkItem': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteLogsLinkItem,
                    request_deserializer=admin_dot_v1_dot_integration__log__pb2.DeleteLogsLinkItemRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__log__pb2.DeleteLogsLinkItemResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'admin.v1.LogsService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class LogsService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateIntegrationLogs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.LogsService/CreateIntegrationLogs',
            admin_dot_v1_dot_integration__log__pb2.CreateIntegrationLogsRequest.SerializeToString,
            admin_dot_v1_dot_integration__log__pb2.CreateIntegrationLogsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetIntegrationLogs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.LogsService/GetIntegrationLogs',
            admin_dot_v1_dot_integration__log__pb2.GetIntegrationLogsRequest.SerializeToString,
            admin_dot_v1_dot_integration__log__pb2.GetIntegrationLogsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetIntegrationLogById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.LogsService/GetIntegrationLogById',
            admin_dot_v1_dot_integration__log__pb2.GetIntegrationLogByIdRequest.SerializeToString,
            admin_dot_v1_dot_integration__log__pb2.GetIntegrationLogByIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteIntegrationLogs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.LogsService/DeleteIntegrationLogs',
            admin_dot_v1_dot_integration__log__pb2.DeleteIntegrationLogsRequest.SerializeToString,
            admin_dot_v1_dot_integration__log__pb2.DeleteIntegrationLogsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateLogsLinkItem(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.LogsService/CreateLogsLinkItem',
            admin_dot_v1_dot_integration__log__pb2.CreateLogsLinkItemRequest.SerializeToString,
            admin_dot_v1_dot_integration__log__pb2.CreateLogsLinkItemResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetLogsLinkItemById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.LogsService/GetLogsLinkItemById',
            admin_dot_v1_dot_integration__log__pb2.GetLogsLinkItemByIdRequest.SerializeToString,
            admin_dot_v1_dot_integration__log__pb2.GetLogsLinkItemByIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteLogsLinkItem(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.LogsService/DeleteLogsLinkItem',
            admin_dot_v1_dot_integration__log__pb2.DeleteLogsLinkItemRequest.SerializeToString,
            admin_dot_v1_dot_integration__log__pb2.DeleteLogsLinkItemResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
