# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import integration_external_api_pb2 as admin_dot_v1_dot_integration__external__api__pb2


class ExternalApiServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateExternalApiIntegration = channel.unary_unary(
                '/admin.v1.ExternalApiService/CreateExternalApiIntegration',
                request_serializer=admin_dot_v1_dot_integration__external__api__pb2.CreateExternalApiIntegrationRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__external__api__pb2.CreateExternalApiIntegrationResponse.FromString,
                )
        self.GetExternalApiIntegration = channel.unary_unary(
                '/admin.v1.ExternalApiService/GetExternalApiIntegration',
                request_serializer=admin_dot_v1_dot_integration__external__api__pb2.GetExternalApiIntegrationRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__external__api__pb2.GetExternalApiIntegrationResponse.FromString,
                )
        self.DeleteExternalApiIntegration = channel.unary_unary(
                '/admin.v1.ExternalApiService/DeleteExternalApiIntegration',
                request_serializer=admin_dot_v1_dot_integration__external__api__pb2.DeleteExternalApiIntegrationRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__external__api__pb2.DeleteExternalApiIntegrationResponse.FromString,
                )
        self.GetExternalApiIntegrations = channel.unary_unary(
                '/admin.v1.ExternalApiService/GetExternalApiIntegrations',
                request_serializer=admin_dot_v1_dot_integration__external__api__pb2.GetExternalApiIntegrationsRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__external__api__pb2.GetExternalApiIntegrationsResponse.FromString,
                )


class ExternalApiServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateExternalApiIntegration(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetExternalApiIntegration(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteExternalApiIntegration(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetExternalApiIntegrations(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ExternalApiServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateExternalApiIntegration': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateExternalApiIntegration,
                    request_deserializer=admin_dot_v1_dot_integration__external__api__pb2.CreateExternalApiIntegrationRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__external__api__pb2.CreateExternalApiIntegrationResponse.SerializeToString,
            ),
            'GetExternalApiIntegration': grpc.unary_unary_rpc_method_handler(
                    servicer.GetExternalApiIntegration,
                    request_deserializer=admin_dot_v1_dot_integration__external__api__pb2.GetExternalApiIntegrationRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__external__api__pb2.GetExternalApiIntegrationResponse.SerializeToString,
            ),
            'DeleteExternalApiIntegration': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteExternalApiIntegration,
                    request_deserializer=admin_dot_v1_dot_integration__external__api__pb2.DeleteExternalApiIntegrationRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__external__api__pb2.DeleteExternalApiIntegrationResponse.SerializeToString,
            ),
            'GetExternalApiIntegrations': grpc.unary_unary_rpc_method_handler(
                    servicer.GetExternalApiIntegrations,
                    request_deserializer=admin_dot_v1_dot_integration__external__api__pb2.GetExternalApiIntegrationsRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__external__api__pb2.GetExternalApiIntegrationsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'admin.v1.ExternalApiService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ExternalApiService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateExternalApiIntegration(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.ExternalApiService/CreateExternalApiIntegration',
            admin_dot_v1_dot_integration__external__api__pb2.CreateExternalApiIntegrationRequest.SerializeToString,
            admin_dot_v1_dot_integration__external__api__pb2.CreateExternalApiIntegrationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetExternalApiIntegration(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.ExternalApiService/GetExternalApiIntegration',
            admin_dot_v1_dot_integration__external__api__pb2.GetExternalApiIntegrationRequest.SerializeToString,
            admin_dot_v1_dot_integration__external__api__pb2.GetExternalApiIntegrationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteExternalApiIntegration(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.ExternalApiService/DeleteExternalApiIntegration',
            admin_dot_v1_dot_integration__external__api__pb2.DeleteExternalApiIntegrationRequest.SerializeToString,
            admin_dot_v1_dot_integration__external__api__pb2.DeleteExternalApiIntegrationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetExternalApiIntegrations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.ExternalApiService/GetExternalApiIntegrations',
            admin_dot_v1_dot_integration__external__api__pb2.GetExternalApiIntegrationsRequest.SerializeToString,
            admin_dot_v1_dot_integration__external__api__pb2.GetExternalApiIntegrationsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
