# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: admin/v1/integration_app.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .types.v1 import app_pb2 as admin_dot_v1_dot_types_dot_v1_dot_app__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x61\x64min/v1/integration_app.proto\x12\x08\x61\x64min.v1\x1a\x1b\x61\x64min/v1/types/v1/app.proto\"\x1f\n\x1dRefreshIntegrationAppsRequest\" \n\x1eRefreshIntegrationAppsResponse\"\x1b\n\x19GetIntegrationAppsRequest\"c\n\x1aGetIntegrationAppsResponse\x12\x45\n\x0cintegrations\x18\x01 \x03(\x0b\x32!.admin.v1.types.v1.IntegrationAppR\x0cintegrations\"+\n\x19GetIntegrationByIdRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"a\n\x1aGetIntegrationByIdResponse\x12\x43\n\x0bintegration\x18\x01 \x01(\x0b\x32!.admin.v1.types.v1.IntegrationAppR\x0bintegration\"\xd1\x02\n\x1b\x43reateIntegrationAppRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x12\n\x04type\x18\x02 \x01(\tR\x04type\x12+\n\x11metabase_hostname\x18\x03 \x01(\tR\x10metabaseHostname\x12+\n\x11metabase_username\x18\x04 \x01(\tR\x10metabaseUsername\x12+\n\x11metabase_password\x18\x05 \x01(\tR\x10metabasePassword\x12)\n\x11linked_db_user_id\x18\x06 \x01(\tR\x0elinkedDbUserId\x12(\n\x10\x66ivetran_api_key\x18\x07 \x01(\tR\x0e\x66ivetranApiKey\x12.\n\x13\x66ivetran_api_secret\x18\x08 \x01(\tR\x11\x66ivetranApiSecret\"c\n\x1c\x43reateIntegrationAppResponse\x12\x43\n\x0bintegration\x18\x01 \x01(\x0b\x32!.admin.v1.types.v1.IntegrationAppR\x0bintegration\"-\n\x1b\x44\x65leteIntegrationAppRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"\x1e\n\x1c\x44\x65leteIntegrationAppResponse2\x89\x04\n\nAppService\x12k\n\x16RefreshIntegrationApps\x12\'.admin.v1.RefreshIntegrationAppsRequest\x1a(.admin.v1.RefreshIntegrationAppsResponse\x12_\n\x12GetIntegrationApps\x12#.admin.v1.GetIntegrationAppsRequest\x1a$.admin.v1.GetIntegrationAppsResponse\x12_\n\x12GetIntegrationById\x12#.admin.v1.GetIntegrationByIdRequest\x1a$.admin.v1.GetIntegrationByIdResponse\x12\x65\n\x14\x43reateIntegrationApp\x12%.admin.v1.CreateIntegrationAppRequest\x1a&.admin.v1.CreateIntegrationAppResponse\x12\x65\n\x14\x44\x65leteIntegrationApp\x12%.admin.v1.DeleteIntegrationAppRequest\x1a&.admin.v1.DeleteIntegrationAppResponseB\xae\x01\n\x0c\x63om.admin.v1B\x13IntegrationAppProtoP\x01ZHgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1;adminv1\xa2\x02\x03\x41XX\xaa\x02\x08\x41\x64min.V1\xca\x02\x08\x41\x64min\\V1\xe2\x02\x14\x41\x64min\\V1\\GPBMetadata\xea\x02\tAdmin::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.integration_app_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\014com.admin.v1B\023IntegrationAppProtoP\001ZHgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1;adminv1\242\002\003AXX\252\002\010Admin.V1\312\002\010Admin\\V1\342\002\024Admin\\V1\\GPBMetadata\352\002\tAdmin::V1'
  _globals['_REFRESHINTEGRATIONAPPSREQUEST']._serialized_start=73
  _globals['_REFRESHINTEGRATIONAPPSREQUEST']._serialized_end=104
  _globals['_REFRESHINTEGRATIONAPPSRESPONSE']._serialized_start=106
  _globals['_REFRESHINTEGRATIONAPPSRESPONSE']._serialized_end=138
  _globals['_GETINTEGRATIONAPPSREQUEST']._serialized_start=140
  _globals['_GETINTEGRATIONAPPSREQUEST']._serialized_end=167
  _globals['_GETINTEGRATIONAPPSRESPONSE']._serialized_start=169
  _globals['_GETINTEGRATIONAPPSRESPONSE']._serialized_end=268
  _globals['_GETINTEGRATIONBYIDREQUEST']._serialized_start=270
  _globals['_GETINTEGRATIONBYIDREQUEST']._serialized_end=313
  _globals['_GETINTEGRATIONBYIDRESPONSE']._serialized_start=315
  _globals['_GETINTEGRATIONBYIDRESPONSE']._serialized_end=412
  _globals['_CREATEINTEGRATIONAPPREQUEST']._serialized_start=415
  _globals['_CREATEINTEGRATIONAPPREQUEST']._serialized_end=752
  _globals['_CREATEINTEGRATIONAPPRESPONSE']._serialized_start=754
  _globals['_CREATEINTEGRATIONAPPRESPONSE']._serialized_end=853
  _globals['_DELETEINTEGRATIONAPPREQUEST']._serialized_start=855
  _globals['_DELETEINTEGRATIONAPPREQUEST']._serialized_end=900
  _globals['_DELETEINTEGRATIONAPPRESPONSE']._serialized_start=902
  _globals['_DELETEINTEGRATIONAPPRESPONSE']._serialized_end=932
  _globals['_APPSERVICE']._serialized_start=935
  _globals['_APPSERVICE']._serialized_end=1456
# @@protoc_insertion_point(module_scope)
