# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import sidecar_pb2 as admin_dot_v1_dot_sidecar__pb2


class SidecarServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListSidecars = channel.unary_unary(
                '/admin.v1.SidecarService/ListSidecars',
                request_serializer=admin_dot_v1_dot_sidecar__pb2.ListSidecarsRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_sidecar__pb2.ListSidecarsResponse.FromString,
                )
        self.GetSidecarVersions = channel.unary_unary(
                '/admin.v1.SidecarService/GetSidecarVersions',
                request_serializer=admin_dot_v1_dot_sidecar__pb2.GetSidecarVersionsRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_sidecar__pb2.GetSidecarVersionsResponse.FromString,
                )
        self.CreateSidecar = channel.unary_unary(
                '/admin.v1.SidecarService/CreateSidecar',
                request_serializer=admin_dot_v1_dot_sidecar__pb2.CreateSidecarRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_sidecar__pb2.CreateSidecarResponse.FromString,
                )
        self.GetSidecarById = channel.unary_unary(
                '/admin.v1.SidecarService/GetSidecarById',
                request_serializer=admin_dot_v1_dot_sidecar__pb2.GetSidecarByIdRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_sidecar__pb2.GetSidecarByIdResponse.FromString,
                )
        self.GetSidecarTlsCertificateById = channel.unary_unary(
                '/admin.v1.SidecarService/GetSidecarTlsCertificateById',
                request_serializer=admin_dot_v1_dot_sidecar__pb2.GetSidecarTlsCertificateByIdRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_sidecar__pb2.GetSidecarTlsCertificateByIdResponse.FromString,
                )
        self.UpdateSidecarName = channel.unary_unary(
                '/admin.v1.SidecarService/UpdateSidecarName',
                request_serializer=admin_dot_v1_dot_sidecar__pb2.UpdateSidecarNameRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_sidecar__pb2.UpdateSidecarNameResponse.FromString,
                )
        self.UpdateSidecarVersion = channel.unary_unary(
                '/admin.v1.SidecarService/UpdateSidecarVersion',
                request_serializer=admin_dot_v1_dot_sidecar__pb2.UpdateSidecarVersionRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_sidecar__pb2.UpdateSidecarVersionResponse.FromString,
                )
        self.UpdateSidecarFormalHostname = channel.unary_unary(
                '/admin.v1.SidecarService/UpdateSidecarFormalHostname',
                request_serializer=admin_dot_v1_dot_sidecar__pb2.UpdateSidecarFormalHostnameRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_sidecar__pb2.UpdateSidecarFormalHostnameResponse.FromString,
                )
        self.UpdateSidecarKmsDecryptPolicy = channel.unary_unary(
                '/admin.v1.SidecarService/UpdateSidecarKmsDecryptPolicy',
                request_serializer=admin_dot_v1_dot_sidecar__pb2.UpdateSidecarKmsDecryptPolicyRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_sidecar__pb2.UpdateSidecarKmsDecryptPolicyResponse.FromString,
                )
        self.DeleteSidecar = channel.unary_unary(
                '/admin.v1.SidecarService/DeleteSidecar',
                request_serializer=admin_dot_v1_dot_sidecar__pb2.DeleteSidecarRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_sidecar__pb2.DeleteSidecarResponse.FromString,
                )
        self.CreateSidecarDatastoreLink = channel.unary_unary(
                '/admin.v1.SidecarService/CreateSidecarDatastoreLink',
                request_serializer=admin_dot_v1_dot_sidecar__pb2.CreateSidecarDatastoreLinkRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_sidecar__pb2.CreateSidecarDatastoreLinkResponse.FromString,
                )
        self.GetLinkById = channel.unary_unary(
                '/admin.v1.SidecarService/GetLinkById',
                request_serializer=admin_dot_v1_dot_sidecar__pb2.GetLinkByIdRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_sidecar__pb2.GetLinkByIdResponse.FromString,
                )
        self.GetLinksBySidecarId = channel.unary_unary(
                '/admin.v1.SidecarService/GetLinksBySidecarId',
                request_serializer=admin_dot_v1_dot_sidecar__pb2.GetLinksBySidecarIdRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_sidecar__pb2.GetLinksBySidecarIdResponse.FromString,
                )
        self.GetLinksByDatastoreId = channel.unary_unary(
                '/admin.v1.SidecarService/GetLinksByDatastoreId',
                request_serializer=admin_dot_v1_dot_sidecar__pb2.GetLinksByDatastoreIdRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_sidecar__pb2.GetLinksByDatastoreIdResponse.FromString,
                )
        self.DeleteSidecarDatastoreLink = channel.unary_unary(
                '/admin.v1.SidecarService/DeleteSidecarDatastoreLink',
                request_serializer=admin_dot_v1_dot_sidecar__pb2.DeleteSidecarDatastoreLinkRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_sidecar__pb2.DeleteSidecarDatastoreLinkResponse.FromString,
                )


class SidecarServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListSidecars(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSidecarVersions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateSidecar(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSidecarById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSidecarTlsCertificateById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateSidecarName(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateSidecarVersion(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateSidecarFormalHostname(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateSidecarKmsDecryptPolicy(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteSidecar(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateSidecarDatastoreLink(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLinkById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLinksBySidecarId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLinksByDatastoreId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteSidecarDatastoreLink(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SidecarServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListSidecars': grpc.unary_unary_rpc_method_handler(
                    servicer.ListSidecars,
                    request_deserializer=admin_dot_v1_dot_sidecar__pb2.ListSidecarsRequest.FromString,
                    response_serializer=admin_dot_v1_dot_sidecar__pb2.ListSidecarsResponse.SerializeToString,
            ),
            'GetSidecarVersions': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSidecarVersions,
                    request_deserializer=admin_dot_v1_dot_sidecar__pb2.GetSidecarVersionsRequest.FromString,
                    response_serializer=admin_dot_v1_dot_sidecar__pb2.GetSidecarVersionsResponse.SerializeToString,
            ),
            'CreateSidecar': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateSidecar,
                    request_deserializer=admin_dot_v1_dot_sidecar__pb2.CreateSidecarRequest.FromString,
                    response_serializer=admin_dot_v1_dot_sidecar__pb2.CreateSidecarResponse.SerializeToString,
            ),
            'GetSidecarById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSidecarById,
                    request_deserializer=admin_dot_v1_dot_sidecar__pb2.GetSidecarByIdRequest.FromString,
                    response_serializer=admin_dot_v1_dot_sidecar__pb2.GetSidecarByIdResponse.SerializeToString,
            ),
            'GetSidecarTlsCertificateById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSidecarTlsCertificateById,
                    request_deserializer=admin_dot_v1_dot_sidecar__pb2.GetSidecarTlsCertificateByIdRequest.FromString,
                    response_serializer=admin_dot_v1_dot_sidecar__pb2.GetSidecarTlsCertificateByIdResponse.SerializeToString,
            ),
            'UpdateSidecarName': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateSidecarName,
                    request_deserializer=admin_dot_v1_dot_sidecar__pb2.UpdateSidecarNameRequest.FromString,
                    response_serializer=admin_dot_v1_dot_sidecar__pb2.UpdateSidecarNameResponse.SerializeToString,
            ),
            'UpdateSidecarVersion': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateSidecarVersion,
                    request_deserializer=admin_dot_v1_dot_sidecar__pb2.UpdateSidecarVersionRequest.FromString,
                    response_serializer=admin_dot_v1_dot_sidecar__pb2.UpdateSidecarVersionResponse.SerializeToString,
            ),
            'UpdateSidecarFormalHostname': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateSidecarFormalHostname,
                    request_deserializer=admin_dot_v1_dot_sidecar__pb2.UpdateSidecarFormalHostnameRequest.FromString,
                    response_serializer=admin_dot_v1_dot_sidecar__pb2.UpdateSidecarFormalHostnameResponse.SerializeToString,
            ),
            'UpdateSidecarKmsDecryptPolicy': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateSidecarKmsDecryptPolicy,
                    request_deserializer=admin_dot_v1_dot_sidecar__pb2.UpdateSidecarKmsDecryptPolicyRequest.FromString,
                    response_serializer=admin_dot_v1_dot_sidecar__pb2.UpdateSidecarKmsDecryptPolicyResponse.SerializeToString,
            ),
            'DeleteSidecar': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteSidecar,
                    request_deserializer=admin_dot_v1_dot_sidecar__pb2.DeleteSidecarRequest.FromString,
                    response_serializer=admin_dot_v1_dot_sidecar__pb2.DeleteSidecarResponse.SerializeToString,
            ),
            'CreateSidecarDatastoreLink': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateSidecarDatastoreLink,
                    request_deserializer=admin_dot_v1_dot_sidecar__pb2.CreateSidecarDatastoreLinkRequest.FromString,
                    response_serializer=admin_dot_v1_dot_sidecar__pb2.CreateSidecarDatastoreLinkResponse.SerializeToString,
            ),
            'GetLinkById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLinkById,
                    request_deserializer=admin_dot_v1_dot_sidecar__pb2.GetLinkByIdRequest.FromString,
                    response_serializer=admin_dot_v1_dot_sidecar__pb2.GetLinkByIdResponse.SerializeToString,
            ),
            'GetLinksBySidecarId': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLinksBySidecarId,
                    request_deserializer=admin_dot_v1_dot_sidecar__pb2.GetLinksBySidecarIdRequest.FromString,
                    response_serializer=admin_dot_v1_dot_sidecar__pb2.GetLinksBySidecarIdResponse.SerializeToString,
            ),
            'GetLinksByDatastoreId': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLinksByDatastoreId,
                    request_deserializer=admin_dot_v1_dot_sidecar__pb2.GetLinksByDatastoreIdRequest.FromString,
                    response_serializer=admin_dot_v1_dot_sidecar__pb2.GetLinksByDatastoreIdResponse.SerializeToString,
            ),
            'DeleteSidecarDatastoreLink': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteSidecarDatastoreLink,
                    request_deserializer=admin_dot_v1_dot_sidecar__pb2.DeleteSidecarDatastoreLinkRequest.FromString,
                    response_serializer=admin_dot_v1_dot_sidecar__pb2.DeleteSidecarDatastoreLinkResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'admin.v1.SidecarService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class SidecarService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListSidecars(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.SidecarService/ListSidecars',
            admin_dot_v1_dot_sidecar__pb2.ListSidecarsRequest.SerializeToString,
            admin_dot_v1_dot_sidecar__pb2.ListSidecarsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSidecarVersions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.SidecarService/GetSidecarVersions',
            admin_dot_v1_dot_sidecar__pb2.GetSidecarVersionsRequest.SerializeToString,
            admin_dot_v1_dot_sidecar__pb2.GetSidecarVersionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateSidecar(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.SidecarService/CreateSidecar',
            admin_dot_v1_dot_sidecar__pb2.CreateSidecarRequest.SerializeToString,
            admin_dot_v1_dot_sidecar__pb2.CreateSidecarResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSidecarById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.SidecarService/GetSidecarById',
            admin_dot_v1_dot_sidecar__pb2.GetSidecarByIdRequest.SerializeToString,
            admin_dot_v1_dot_sidecar__pb2.GetSidecarByIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSidecarTlsCertificateById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.SidecarService/GetSidecarTlsCertificateById',
            admin_dot_v1_dot_sidecar__pb2.GetSidecarTlsCertificateByIdRequest.SerializeToString,
            admin_dot_v1_dot_sidecar__pb2.GetSidecarTlsCertificateByIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateSidecarName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.SidecarService/UpdateSidecarName',
            admin_dot_v1_dot_sidecar__pb2.UpdateSidecarNameRequest.SerializeToString,
            admin_dot_v1_dot_sidecar__pb2.UpdateSidecarNameResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateSidecarVersion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.SidecarService/UpdateSidecarVersion',
            admin_dot_v1_dot_sidecar__pb2.UpdateSidecarVersionRequest.SerializeToString,
            admin_dot_v1_dot_sidecar__pb2.UpdateSidecarVersionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateSidecarFormalHostname(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.SidecarService/UpdateSidecarFormalHostname',
            admin_dot_v1_dot_sidecar__pb2.UpdateSidecarFormalHostnameRequest.SerializeToString,
            admin_dot_v1_dot_sidecar__pb2.UpdateSidecarFormalHostnameResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateSidecarKmsDecryptPolicy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.SidecarService/UpdateSidecarKmsDecryptPolicy',
            admin_dot_v1_dot_sidecar__pb2.UpdateSidecarKmsDecryptPolicyRequest.SerializeToString,
            admin_dot_v1_dot_sidecar__pb2.UpdateSidecarKmsDecryptPolicyResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteSidecar(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.SidecarService/DeleteSidecar',
            admin_dot_v1_dot_sidecar__pb2.DeleteSidecarRequest.SerializeToString,
            admin_dot_v1_dot_sidecar__pb2.DeleteSidecarResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateSidecarDatastoreLink(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.SidecarService/CreateSidecarDatastoreLink',
            admin_dot_v1_dot_sidecar__pb2.CreateSidecarDatastoreLinkRequest.SerializeToString,
            admin_dot_v1_dot_sidecar__pb2.CreateSidecarDatastoreLinkResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetLinkById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.SidecarService/GetLinkById',
            admin_dot_v1_dot_sidecar__pb2.GetLinkByIdRequest.SerializeToString,
            admin_dot_v1_dot_sidecar__pb2.GetLinkByIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetLinksBySidecarId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.SidecarService/GetLinksBySidecarId',
            admin_dot_v1_dot_sidecar__pb2.GetLinksBySidecarIdRequest.SerializeToString,
            admin_dot_v1_dot_sidecar__pb2.GetLinksBySidecarIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetLinksByDatastoreId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.SidecarService/GetLinksByDatastoreId',
            admin_dot_v1_dot_sidecar__pb2.GetLinksByDatastoreIdRequest.SerializeToString,
            admin_dot_v1_dot_sidecar__pb2.GetLinksByDatastoreIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteSidecarDatastoreLink(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.SidecarService/DeleteSidecarDatastoreLink',
            admin_dot_v1_dot_sidecar__pb2.DeleteSidecarDatastoreLinkRequest.SerializeToString,
            admin_dot_v1_dot_sidecar__pb2.DeleteSidecarDatastoreLinkResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
