# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: admin/v1/types/v1/connection.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"admin/v1/types/v1/connection.proto\x12\x11\x61\x64min.v1.types.v1\"\x99\x03\n\nConnection\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12;\n\x06status\x18\x02 \x01(\x0e\x32#.admin.v1.types.v1.ConnectionStatusR\x06status\x12\x38\n\x05state\x18\x03 \x01(\x0e\x32\".admin.v1.types.v1.ConnectionStateR\x05state\x12\x12\n\x04name\x18\x04 \x01(\tR\x04name\x12J\n\x0f\x63onnection_type\x18\x05 \x01(\x0e\x32!.admin.v1.types.v1.ConnectionTypeR\x0e\x63onnectionType\x12\'\n\x0forganization_id\x18\x06 \x01(\tR\x0eorganizationId\x12=\n\x07\x64omains\x18\x07 \x03(\x0b\x32#.admin.v1.types.v1.ConnectionDomainR\x07\x64omains\x12\x1d\n\ncreated_at\x18\x08 \x01(\tR\tcreatedAt\x12\x1d\n\nupdated_at\x18\t \x01(\tR\tupdatedAt\":\n\x10\x43onnectionDomain\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x16\n\x06\x64omain\x18\x02 \x01(\tR\x06\x64omain*\xf3\x07\n\x0e\x43onnectionType\x12\x1f\n\x1b\x43ONNECTION_TYPE_UNSPECIFIED\x10\x00\x12\x1d\n\x19\x43ONNECTION_TYPE_ADFS_SAML\x10\x01\x12\x1c\n\x18\x43ONNECTION_TYPE_ADP_OIDC\x10\x02\x12\x1e\n\x1a\x43ONNECTION_TYPE_AUTH0_SAML\x10\x03\x12\x1e\n\x1a\x43ONNECTION_TYPE_AZURE_SAML\x10\x04\x12\x1c\n\x18\x43ONNECTION_TYPE_CAS_SAML\x10\x05\x12#\n\x1f\x43ONNECTION_TYPE_CLOUDFLARE_SAML\x10\x06\x12#\n\x1f\x43ONNECTION_TYPE_CLASS_LINK_SAML\x10\x07\x12!\n\x1d\x43ONNECTION_TYPE_CYBERARK_SAML\x10\x08\x12\x1c\n\x18\x43ONNECTION_TYPE_DUO_SAML\x10\t\x12 \n\x1c\x43ONNECTION_TYPE_GENERIC_OIDC\x10\n\x12 \n\x1c\x43ONNECTION_TYPE_GENERIC_SAML\x10\x0b\x12 \n\x1c\x43ONNECTION_TYPE_GOOGLE_OAUTH\x10\x0c\x12\x1f\n\x1b\x43ONNECTION_TYPE_GOOGLE_SAML\x10\r\x12#\n\x1f\x43ONNECTION_TYPE_JUMP_CLOUD_SAML\x10\x0e\x12\x1e\n\x1a\x43ONNECTION_TYPE_MAGIC_LINK\x10\x0f\x12#\n\x1f\x43ONNECTION_TYPE_MICROSOFT_OAUTH\x10\x10\x12#\n\x1f\x43ONNECTION_TYPE_MINIORANGE_SAML\x10\x11\x12\x1e\n\x1a\x43ONNECTION_TYPE_NETIQ_SAML\x10\x12\x12\x1d\n\x19\x43ONNECTION_TYPE_OKTA_SAML\x10\x13\x12!\n\x1d\x43ONNECTION_TYPE_ONELOGIN_SAML\x10\x14\x12\x1f\n\x1b\x43ONNECTION_TYPE_ORACLE_SAML\x10\x15\x12&\n\"CONNECTION_TYPE_PING_FEDERATE_SAML\x10\x16\x12!\n\x1d\x43ONNECTION_TYPE_PING_ONE_SAML\x10\x17\x12!\n\x1d\x43ONNECTION_TYPE_RIPPLING_SAML\x10\x18\x12#\n\x1f\x43ONNECTION_TYPE_SALESFORCE_SAML\x10\x19\x12#\n\x1f\x43ONNECTION_TYPE_SHIBBOLETH_SAML\x10\x1a\x12(\n$CONNECTION_TYPE_SIMPLE_SAML_PHP_SAML\x10\x1b\x12\x1f\n\x1b\x43ONNECTION_TYPE_VMWARE_SAML\x10\x1c*s\n\x10\x43onnectionStatus\x12!\n\x1d\x43ONNECTION_STATUS_UNSPECIFIED\x10\x00\x12\x1c\n\x18\x43ONNECTION_STATUS_LINKED\x10\x01\x12\x1e\n\x1a\x43ONNECTION_STATUS_UNLINKED\x10\x02*\x8b\x01\n\x0f\x43onnectionState\x12 \n\x1c\x43ONNECTION_STATE_UNSPECIFIED\x10\x00\x12\x1a\n\x16\x43ONNECTION_STATE_DRAFT\x10\x01\x12\x1b\n\x17\x43ONNECTION_STATE_ACTIVE\x10\x02\x12\x1d\n\x19\x43ONNECTION_STATE_INACTIVE\x10\x03\x42\xe2\x01\n\x15\x63om.admin.v1.types.v1B\x0f\x43onnectionProtoP\x01ZQgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1/types/v1;typesv1\xa2\x02\x03\x41VT\xaa\x02\x11\x41\x64min.V1.Types.V1\xca\x02\x11\x41\x64min\\V1\\Types\\V1\xe2\x02\x1d\x41\x64min\\V1\\Types\\V1\\GPBMetadata\xea\x02\x14\x41\x64min::V1::Types::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.types.v1.connection_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.admin.v1.types.v1B\017ConnectionProtoP\001ZQgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1/types/v1;typesv1\242\002\003AVT\252\002\021Admin.V1.Types.V1\312\002\021Admin\\V1\\Types\\V1\342\002\035Admin\\V1\\Types\\V1\\GPBMetadata\352\002\024Admin::V1::Types::V1'
  _globals['_CONNECTIONTYPE']._serialized_start=530
  _globals['_CONNECTIONTYPE']._serialized_end=1541
  _globals['_CONNECTIONSTATUS']._serialized_start=1543
  _globals['_CONNECTIONSTATUS']._serialized_end=1658
  _globals['_CONNECTIONSTATE']._serialized_start=1661
  _globals['_CONNECTIONSTATE']._serialized_end=1800
  _globals['_CONNECTION']._serialized_start=58
  _globals['_CONNECTION']._serialized_end=467
  _globals['_CONNECTIONDOMAIN']._serialized_start=469
  _globals['_CONNECTIONDOMAIN']._serialized_end=527
# @@protoc_insertion_point(module_scope)
