# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: admin/v1/search.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .types.v1 import search_pb2 as admin_dot_v1_dot_types_dot_v1_dot_search__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15\x61\x64min/v1/search.proto\x12\x08\x61\x64min.v1\x1a\x1e\x61\x64min/v1/types/v1/search.proto\"\xa6\x01\n\rSearchRequest\x12\x1f\n\x0bobject_type\x18\x01 \x01(\tR\nobjectType\x12\x14\n\x05query\x18\x02 \x01(\tR\x05query\x12\x1b\n\tfilter_by\x18\x03 \x01(\tR\x08\x66ilterBy\x12\x17\n\x07sort_by\x18\x04 \x01(\tR\x06sortBy\x12\x12\n\x04page\x18\x05 \x01(\x05R\x04page\x12\x14\n\x05limit\x18\x06 \x01(\x05R\x05limit\"\x98\x04\n\x0eSearchResponse\x12\x33\n\x05users\x18\x01 \x01(\x0b\x32\x1b.admin.v1.WrappedSearchUserH\x00R\x05users\x12\x36\n\x06groups\x18\x02 \x01(\x0b\x32\x1c.admin.v1.WrappedSearchGroupH\x00R\x06groups\x12;\n\x08policies\x18\x03 \x01(\x0b\x32\x1d.admin.v1.WrappedSearchPolicyH\x00R\x08policies\x12\x42\n\ndatastores\x18\x04 \x01(\x0b\x32 .admin.v1.WrappedSearchDatastoreH\x00R\ndatastores\x12<\n\x08sidecars\x18\x05 \x01(\x0b\x32\x1e.admin.v1.WrappedSearchSidecarH\x00R\x08sidecars\x12\x44\n\x0binventories\x18\x06 \x01(\x0b\x32 .admin.v1.WrappedSearchInventoryH\x00R\x0binventories\x12\x14\n\x05\x66ound\x18\x07 \x01(\x05R\x05\x66ound\x12\x12\n\x04page\x18\x08 \x01(\x05R\x04page\x12\x15\n\x06out_of\x18\t \x01(\x05R\x05outOf\x12$\n\x0esearch_time_ms\x18\n \x01(\x05R\x0csearchTimeMs\x12#\n\rsearch_cutoff\x18\x0b \x01(\x08R\x0csearchCutoffB\x08\n\x06result\"F\n\x11WrappedSearchUser\x12\x31\n\x04user\x18\x01 \x03(\x0b\x32\x1d.admin.v1.types.v1.SearchUserR\x04user\"J\n\x12WrappedSearchGroup\x12\x34\n\x05group\x18\x01 \x03(\x0b\x32\x1e.admin.v1.types.v1.SearchGroupR\x05group\"N\n\x13WrappedSearchPolicy\x12\x37\n\x06policy\x18\x01 \x03(\x0b\x32\x1f.admin.v1.types.v1.SearchPolicyR\x06policy\"Z\n\x16WrappedSearchDatastore\x12@\n\tdatastore\x18\x01 \x03(\x0b\x32\".admin.v1.types.v1.SearchDatastoreR\tdatastore\"R\n\x14WrappedSearchSidecar\x12:\n\x07sidecar\x18\x01 \x03(\x0b\x32 .admin.v1.types.v1.SearchSidecarR\x07sidecar\"Z\n\x16WrappedSearchInventory\x12@\n\tinventory\x18\x01 \x03(\x0b\x32\".admin.v1.types.v1.SearchInventoryR\tinventory2N\n\rSearchService\x12=\n\x06Search\x12\x17.admin.v1.SearchRequest\x1a\x18.admin.v1.SearchResponse\"\x00\x42\xa6\x01\n\x0c\x63om.admin.v1B\x0bSearchProtoP\x01ZHgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1;adminv1\xa2\x02\x03\x41XX\xaa\x02\x08\x41\x64min.V1\xca\x02\x08\x41\x64min\\V1\xe2\x02\x14\x41\x64min\\V1\\GPBMetadata\xea\x02\tAdmin::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.search_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\014com.admin.v1B\013SearchProtoP\001ZHgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1;adminv1\242\002\003AXX\252\002\010Admin.V1\312\002\010Admin\\V1\342\002\024Admin\\V1\\GPBMetadata\352\002\tAdmin::V1'
  _globals['_SEARCHREQUEST']._serialized_start=68
  _globals['_SEARCHREQUEST']._serialized_end=234
  _globals['_SEARCHRESPONSE']._serialized_start=237
  _globals['_SEARCHRESPONSE']._serialized_end=773
  _globals['_WRAPPEDSEARCHUSER']._serialized_start=775
  _globals['_WRAPPEDSEARCHUSER']._serialized_end=845
  _globals['_WRAPPEDSEARCHGROUP']._serialized_start=847
  _globals['_WRAPPEDSEARCHGROUP']._serialized_end=921
  _globals['_WRAPPEDSEARCHPOLICY']._serialized_start=923
  _globals['_WRAPPEDSEARCHPOLICY']._serialized_end=1001
  _globals['_WRAPPEDSEARCHDATASTORE']._serialized_start=1003
  _globals['_WRAPPEDSEARCHDATASTORE']._serialized_end=1093
  _globals['_WRAPPEDSEARCHSIDECAR']._serialized_start=1095
  _globals['_WRAPPEDSEARCHSIDECAR']._serialized_end=1177
  _globals['_WRAPPEDSEARCHINVENTORY']._serialized_start=1179
  _globals['_WRAPPEDSEARCHINVENTORY']._serialized_end=1269
  _globals['_SEARCHSERVICE']._serialized_start=1271
  _globals['_SEARCHSERVICE']._serialized_end=1349
# @@protoc_insertion_point(module_scope)
